;;;Draws vport bounds plines from info in HUANDX.TXT which is written by HUANDX.LSP.
;;;Sets current view to match a specified viewport if it has been stored in HUANDX.TXT
;;;(See HUANDX.LSP - the routine that stores sheet and viewport info in HUANDX.TXT)
;;;
;;;Commands: ESBND, erases vport bounds drawn by SHTBND; and
;;;          VIEWSHT, zooms (and dview twists if necessary) the selected
;;;                   sheet vport area in view.
;;;	     PGRT, pages to the next sheet/view in the list
;;;	     PGLT, pages to the previous sheet/view in the list
;;;
;;;	Author:
;;;		Henry C. Francis
;;;		425 N. Ashe St.
;;;		Southern Pines, NC 28387
;;;
;;;	All rights reserved.
;;;
;;;	Copyright: 9/16/99
;;;	   Edited: 1/20/2008
;;;****************************************************************************
(DEFUN C:SHTBND ()
  (IF ukword
    NIL
    (LOAD "ukword" "\nFile UKWORD.LSP not loaded! ")
  ) ;_ end of IF
  (SETQ erase_bnds (ukword 1 "Yes No" "Erase existing sheet boundary information?" "Yes"))
  (SETQ label_shtno_only (ukword 1 "Yes No" "Label with sheet numbers only?" "Yes"))
  (IF proj_dir
    NIL
    (SETQ proj_dir (GETVAR "dwgprefix"))
  ) ;_ end of IF
  (SETQ ndxfil (GETFILED "Select Project Index / Sheet Data File to use" (STRCAT proj_dir "huandx.txt") "txt" 0))
  (PRINC ndxfil)
  (IF getstyle
    nil
    (LOAD "getstyle" "\nFile GETSTYLE.LSP not found! ")
  ) ;_ end of if
  (getstyle "A")
  (IF gvpno
    nil
    (LOAD "gvpno" "\nFile GVPNO.LSP not found! ")
  ) ;_ end of if
  (gvpno)
  (SETVAR "cmdecho" 0)
  (IF ukword
    nil
    (LOAD "ukword" "\nFile UKWORD.LSP not found! ")
  ) ;_ end of if
  (IF ustr
    nil
    (LOAD "ustr" "\nFile USTR.LSP not found! ")
  ) ;_ end of if
  (IF uint
    nil
    (LOAD "uint" "\nFile UINT.LSP not found! ")
  ) ;_ end of if
  (IF ureal
    nil
    (LOAD "ureal" "\nFile UREAL.LSP not found! ")
  ) ;_ end of if
  (IF ndxfil
    (PROGN
           (SETQ fnfilter (ustr 1
                                "File name filter (. for none)"
                                (IF fnfilter
                                  fnfilter
                                  "."
                                ) ;_ end of IF
                                T
                          ) ;_ end of ustr
           ) ;_ end of SETQ
           (SETQ isplottable (ukword 1
                                "No Yes"
                                "Make bounds and text plottable?"
                                (IF isplottable
                                  isplottable
                                  "Yes"
                                ) ;_ end of IF
                          ) ;_ end of ustr
           ) ;_ end of SETQ
           (IF (EQ isplottable "Yes")
             (setq nplot "")
             (setq nplot "-NPLT")
           )
           (make_bnds_lst)
           (IF txtsize
             nil
             (LOAD "txtsize")
           ) ;_ end of if
           (txtsize "120")
           (IF (EQ erase_bnds "Yes")
             (PROGN
               (IF (SETQ oldbnd (SSGET "x"
                                     '((-4 . "<OR")
                                       (8 . "*SBND?FRAM*")
                                       (8 . "*SBND?TEXT*")
                                       (-4 . "OR>")
                                      )
                              ) ;_ end of ssget
                   ) ;_ end of setq
                 (PROGN (SETQ oldlen (SSLENGTH oldbnd))
                        (SETQ ssndx 0)
                        (WHILE (< ssndx oldlen) (ENTDEL (SSNAME oldbnd ssndx)) (SETQ ssndx (1+ ssndx)))
                        (SETQ grp_count 1)
                 ) ;_ end of progn
                 (SETQ grp_count 1)
               )
             ) ;_ end of IF
             (PROGN
               (SETQ xbndtext_ss (SSGET "x" '((8 . "*SBND-TEXT*"))))
               (IF xbndtext_ss
                 (SETQ grp_count (1+ (SSLENGTH xbndtext_ss)))
                 (SETQ grp_count 1)
               )
             )
           ) ;_ end of if
           (SETQ shtbnd_ss (SSADD))
           (FOREACH n bnds
             (ENTMAKE (LIST (CONS 0 "POLYLINE")
                            (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot))
                            (CONS 10 (LIST 0 0 0))
                            (CONS 66 1)
                      ) ;_ end of list
             ) ;_ end of entmake
             (ENTMAKE (LIST (CONS 0 "VERTEX") (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot)) (CONS 10 (NTH 1 n))))
             (ENTMAKE (LIST (CONS 0 "VERTEX") (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot)) (CONS 10 (NTH 2 n))))
             (ENTMAKE (LIST (CONS 0 "VERTEX") (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot)) (CONS 10 (NTH 3 n))))
             (ENTMAKE (LIST (CONS 0 "VERTEX") (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot)) (CONS 10 (NTH 4 n))))
             (ENTMAKE (LIST (CONS 0 "VERTEX") (CONS 8 (STRCAT "G-" prod "-SBND-FRAM" nplot)) (CONS 10 (NTH 1 n))))
             (ENTMAKE (LIST (CONS 0 "SEQEND")))
             (SSADD (ENTLAST) shtbnd_ss)
             (SETQ inspt (POLAR (NTH 1 n) (ANGLE (NTH 1 n) (NTH 3 n)) (/ (DISTANCE (NTH 1 n) (NTH 3 n)) 2)))
             (IF (AND (WCMATCH label_shtno_only "Yes")(WCMATCH (NTH 0 n) "*? ?*"))
               (PROGN
                 (SETQ txtcnt 2)
                 (WHILE (NOT (WCMATCH (SUBSTR (NTH 0 n) txtcnt) " *"))
                   (SETQ txtcnt (1+ txtcnt))
                 )
                 (SETQ shtno_label (SUBSTR (NTH 0 n) 1 (1- txtcnt)))
               )
               (SETQ  shtno_label (NTH 0 n))
             )
             (SETQ txtent (LIST (CONS 0 "TEXT")
                                (CONS 1 shtno_label)
                                (CONS 7 (GETVAR "textstyle"))
                                (CONS 8 (STRCAT "G-" prod "-SBND-TEXT" nplot))
                                (CONS 10 inspt)
                                (CONS 11 inspt)
                                (CONS 40 txtht) ;		 (cons 50 (- 0(getvar"viewtwist")))
                                (CONS 72 1)
                                (CONS 73 2)
                          ) ;_ end of list
             ) ;_ end of setq
             (ENTMAKE txtent)
             (SSADD (ENTLAST) shtbnd_ss)
             (make_shtbnd_group "SHTBND_" shtbnd_ss)
             (SETQ grp_count (1+ grp_count))
             (SETQ shtbnd_ss (SSADD))
           ) ;_ end of foreach
           (COMMAND "-layer" "c" 4 "G-VI##-SBND*" "")
           (IF (EQ nplot "-NPLT")
             (COMMAND "-layer" "p" "n" "G-VI##-SBND*-NPLT" "")
           )
           (PRINC "\nThe command ESBND will erase sheet boundary information created by SHTBND. ")
    ) ;_ end of progn
  ) ;_ end of if
  (txtsize "110")
  (getstyle "")
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN C:VIEWSHT ()
  (SETQ bnds nil)
  (IF proj_dir
    NIL
    (SETQ proj_dir (GETVAR "dwgprefix"))
  ) ;_ end of IF
  (IF ukword
    NIL
    (LOAD "UKWORD" "\nFile UKWORD.LSP not loaded! ")
  ) ;_ end of IF
  (COND ((AND ndxfil (NOT skip_qry))
         (SETQ frsh_ndx (ukword 1 "Yes No" "Do you want to specify the index file?" "No"))
        )
        ((NOT skip_qry) (SETQ frsh_ndx "Yes"))
        (skip_qry (SETQ frsh_ndx "No"))
  ) ;_ end of COND
  (IF (EQ frsh_ndx "Yes")
    (IF (WCMATCH (STRCASE proj_dir) "*0CAD\\*")
      (PROGN (SETQ ndx_dir proj_dir)
             (WHILE (NOT (WCMATCH (STRCASE ndx_dir) "*0CAD\\"))
               (SETQ ndx_dir (SUBSTR ndx_dir 1 (1- (STRLEN ndx_dir))))
             ) ;_ end of WHILE
             (SETQ ndxfil (GETFILED "Select Project Index / Sheet Data File to use" (STRCAT ndx_dir "huandx.txt") "txt" 0))
      ) ;_ end of PROGN
      (SETQ ndxfil (GETFILED "Select Project Index / Sheet Data File to use" (STRCAT proj_dir "huandx.txt") "txt" 0))
    ) ;_ end of IF
  ) ;_ end of IF
  (IF ndxfil
    (PROGN
      (SETQ fnfilter ".")
      (make_bnds_lst)
      (SETQ shtids nil)
      (FOREACH n bnds
        (IF (MEMBER (STRCASE (NTH 0 n)) shtids)
          nil
          (SETQ shtids (APPEND shtids (LIST (STRCASE (NTH 0 n)))))
        ) ;_ end of if
      ) ;_ end of foreach
      (SETQ shtids (ACAD_STRLSORT shtids))
      (IF ustr
        nil
        (LOAD "ustr" "\nFile USTR.LSP not found! ")
      ) ;_ end of IF
      (IF uint
        nil
        (LOAD "uint" "\nFile UINT.LSP not found! ")
      ) ;_ end of IF
      (IF skip_qry
        NIL
        (WHILE (AND (EQ (SETQ sht_to_view
                               (STRCASE (ustr 0
                                              "Enter sheet ID or <?> (<Q>uit to cancel) "
                                              (IF sht_to_view
                                                sht_to_view
                                                nil
                                              ) ;_ end of if
                                              T
                                        ) ;_ end of ustr
                               ) ;_ end of STRCASE
                        ) ;_ end of SETQ
                        "?"
                    ) ;_ end of EQ
                    (/= sht_to_view "Q")
                    (/= sht_to_view "QUIT")
;;;                (/= sht_to_view "q")
;;;                (/= sht_to_view "quit")
               ) ;_ end of AND
          (PRINC "\nAvaiable sheet ID's are: ")
          (FOREACH n shtids (PROGN (PRINC "\n") (PRINC n))) ;_ end of foreach
          (PRINC)
        ) ;_ end of while
      ) ;_ end of IF
      (IF sht_to_view
        (PROGN
          (SETQ view_cnt 0
                view_pts nil
          ) ;_ end of setq
          (SETQ this_sht_to_view sht_to_view
                this_cnt 1
          )
          (IF (WCMATCH this_sht_to_view "*`#*");if literal character # exists in this_sht_to_view make it read literally (# is a wildcard character by default)
            (PROGN
              (WHILE (AND (WCMATCH this_sht_to_view "*`#*")(NOT(WCMATCH (SUBSTR this_sht_to_view this_cnt) "`#*")))
                (SETQ this_cnt (1+ this_cnt))
              )
              (SETQ this_sht_to_view (STRCAT (SUBSTR this_sht_to_view 1 (1- this_cnt))"`"(SUBSTR this_sht_to_view this_cnt)))
            )
          )
          (IF debug_viewsht
            (PROGN
              (PRINC "\n")
              (PRINC (STRCASE this_sht_to_view))
              (PRINC)
            )
          )
          (FOREACH n bnds
            (IF ;(WCMATCH (STRCASE sht_to_view)(STRCASE(STRCAT (NTH 0 n))" *"))
              (WCMATCH (strcase (nth 0 n)) (strcase this_sht_to_view))
              (PROGN (SETQ view_cnt (1+ view_cnt))
                     (IF view_pts
                       (SETQ view_pts (APPEND view_pts (LIST view_cnt (LIST (NTH 1 n) (NTH 2 n) (NTH 3 n) (NTH 4 n)))))
                       (SETQ view_pts (LIST view_cnt (LIST (NTH 1 n) (NTH 2 n) (NTH 3 n) (NTH 4 n))))
                     ) ;_ end of if
              ) ;_ end of progn
            ) ;_ end of if
          ) ;_ end of foreach
          (IF view_pts
            (PROGN (SETQ vno_ndx 0)
                   (WHILE (< vno_ndx view_cnt)
                     (IF skip_qry
                       NIL
                       (PROGN (PRINC "\nView ")
                              (PRINC (1+ vno_ndx))
                              (PRINC " - ")
                              (PRINC (NTH (1+ (* vno_ndx 2)) view_pts))
                       ) ;_ end of PROGN
                     ) ;_ end of IF
                     (SETQ vno_ndx (1+ vno_ndx))
                   ) ;_ end of while
;;;                    (IF (AND view_num (EQ rev_settings "No"))
;;;                      (SETQ view_pts (LIST (CAR (MEMBER view_num view_pts)) (CADR (MEMBER view_num view_pts))))
                   (IF (> view_cnt 1)
                     (PROGN (SETQ view_num (uint 1
                                                 ""
                                                 (STRCAT "Enter number of view on " (STRCASE sht_to_view))
                                                 (IF view_num
                                                   view_num
                                                   1
                                                 ) ;_ end of if
                                           ) ;_ end of uint
                            ) ;_ end of setq
                            (SETQ view_pts (LIST (CAR (MEMBER view_num view_pts)) (CADR (MEMBER view_num view_pts))))
                     ) ;_ end of progn
                   ) ;_ end of if
;;;                    ) ;_ end of IF
                   (SETQ raw_angle  (- (* 2.0 PI)
                                       (ANGLE (POLAR (CADDDR (NTH 1 view_pts)) 0 0) (POLAR (CAR (NTH 1 view_pts)) 0 0))
                                    ) ;_ end of -
                         view_angle (RTOS (* (/ raw_angle PI) 180.0) 2 5) ;_ end of angtos
                   ) ;_ end of setq
                   (SETQ view_window_llur (LIST (CADDDR (NTH 1 view_pts)) (CADR (NTH 1 view_pts))))
                   (IF (OR
                         (NOT from_pageview)
                         (NOT prev_raw_angle)
                         (AND (EQUAL (SIN prev_raw_angle) 0.0 0.0001)(EQUAL (SIN raw_angle) 0.0 0.0001))
                         (AND (NOT (EQUAL (SIN prev_raw_angle) 0.0 0.0001))(NOT (EQUAL (SIN raw_angle) 0.0 0.0001)))
                       )
                     (PROGN
                       (SETQ prev_raw_angle raw_angle)
                       (COMMAND "_.zoom" (CAR view_window_llur) (CADR view_window_llur))
                   (IF (OR skip_qry
                           (EQUAL raw_angle (GETVAR "viewtwist") 0.00001)
                           (EQUAL (+ raw_angle (* 2.0 PI)) (GETVAR "viewtwist") 0.00001)
                           (EQUAL (- raw_angle (* 2.0 PI)) (GETVAR "viewtwist") 0.00001)
                       ) ;_ end of OR
                     NIL
                     (IF (EQ (SETQ do_vtwist (ukword 1
                                                     "Yes No"
                                                     "Match selected sheet Viewtwist?"
                                                     (IF do_vtwist
                                                       do_vtwist
                                                       "Yes"
                                                     ) ;_ end of IF
                                             ) ;_ end of ukword
                             ) ;_ end of SETQ
                             "Yes"
                         ) ;_ end of EQ
                       (PROGN (COMMAND "_.dview" "" "TW" view_angle "CL" "F" 0 "CL" "B" 0 "CL" "O" "")
                              (COMMAND "_.zoom" (CAR view_window_llur) (CADR view_window_llur))
                       ) ;_ end of PROGN
                     ) ;_ end of IF
                   ) ;_ end of IF
                   (IF (AND align_lst c:showgrid (< (CADR (GETVAR "viewctr")) 90000))
                     (c:showgrid)
                   ) ;_ end of IF
                   (GRDRAW (polar (caadr view_pts) (* PI 0.75) 3.0)(polar (cadadr view_pts) (* PI 1.25) 3.0)7)
                   (GRDRAW (polar (cadadr view_pts) (* PI 1.25) 3.0)(polar (car(cddadr view_pts)) (* PI 1.75) 3.0)7)
                   (GRDRAW (polar (car(cddadr view_pts)) (* PI 1.75) 3.0)(polar (cadr(cddadr view_pts)) (* PI 0.25) 3.0)7)
                   (GRDRAW (polar (cadr(cddadr view_pts)) (* PI 0.25) 3.0)(polar (caadr view_pts) (* PI 0.75) 3.0)7)
                   (PRINC "\n")
                   (PRINC sht_to_view)
                   (PRINC)
                   (IF c:tsnap
                     nil
                     (LOAD "tsnap" "\nFile TSNAP.LSP not found! ")
                   ) ;_ end of if
                   (c:tsnap)
                       )
                     )
                (SETQ from_pageview NIL)
            ) ;_ end of progn
            (PRINC "\nNo matching view found! ")
          ) ;_ end of if
        ) ;_ end of progn
      ) ;_ end of if
    ) ;_ end of PROGN
  ) ;_ end of IF
  (SETQ skip_qry NIL)
  (PRINC)
) ;_ end of defun
;;;****************************************************************************
(DEFUN C:PGRT ()
  (IF ndxfil
    NIL
    (PROGN (SETQ ndxfil (GETFILED "Select Project Index / Sheet Data File to use"
                                  (STRCAT (GETVAR "dwgprefix") "huandx.txt")
                                  "txt"
                                  0
                        ) ;_ end of GETFILED
           ) ;_ end of SETQ
           (IF ustr
             nil
             (LOAD "ustr" "\nFile USTR.LSP not found! ")
           ) ;_ end of if
           (SETQ fnfilter (ustr 1
                                "File name filter (. for none)"
                                (IF fnfilter
                                  fnfilter
                                  "."
                                ) ;_ end of IF
                                T
                          ) ;_ end of ustr
           ) ;_ end of SETQ
           (make_bnds_lst)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF ndxfil
    (PROGN (IF ukword
             NIL
             (LOAD "ukword" "\nFile UKWORD.LSP not loaded! ")
           ) ;_ end of IF
           (IF from_gpdgn
             (SETQ rev_settings "No")
             (SETQ rev_settings
                    (ukword 1
                            "Yes No"
                            "Change page view settings <Yes/No>"
                            (IF rev_settings
                              rev_settings
                              "No"
                            ) ;_ end of if
                    ) ;_ end of ukword
             ) ;_ end of SETQ
           )
           (IF (EQ rev_settings "Yes")
             (SETQ skip_qry NIL)
             (SETQ skip_qry T)
           ) ;_ end of IF
           (COND ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-#")(WCMATCH sht_to_view "*@*`.#"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 1))
                                       (ITOA (1+ (ATOI (SUBSTR sht_to_view (STRLEN sht_to_view)))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 1))
                                 (ITOA (1+ (ATOI (SUBSTR sht_to_view (STRLEN sht_to_view)))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-##")(WCMATCH sht_to_view "*@*`.##"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 2))
                                       (ITOA (1+ (ATOI (SUBSTR sht_to_view (1- (STRLEN sht_to_view))))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 2))
                                 (ITOA (1+ (ATOI (SUBSTR sht_to_view (1- (STRLEN sht_to_view))))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-###")(WCMATCH sht_to_view "*@*`.###"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 3))
                                       (ITOA (1+ (ATOI (SUBSTR sht_to_view (- (STRLEN sht_to_view) 2)))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 3))
                                 (ITOA (1+ (ATOI (SUBSTR sht_to_view (- (STRLEN sht_to_view) 2)))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (WCMATCH sht_to_view "*@*")
                       (/= sht_to_view (LAST shtids))
                       (MEMBER sht_to_view shtids)
                  ) ;_ end of AND
                  (SETQ sht_to_view (CADR (MEMBER sht_to_view shtids)))
                 )
                 ((AND sht_to_view (EQ (TYPE (READ sht_to_view)) 'INT))
                  (SETQ sht_to_view (ITOA (1+ (ATOI sht_to_view))))
                 )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 2) (EQ (TYPE (READ (SUBSTR sht_to_view 2))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 1) (ITOA (1+ (ATOI (SUBSTR sht_to_view 2))))))
;;;        )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 3) (EQ (TYPE (READ (SUBSTR sht_to_view 3))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 2) (ITOA (1+ (ATOI (SUBSTR sht_to_view 3))))))
;;;        )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 4) (EQ (TYPE (READ (SUBSTR sht_to_view 4))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 3) (ITOA (1+ (ATOI (SUBSTR sht_to_view 4))))))
;;;        )
;;;        (T (setq skip_qry NIL))
           ) ;_ end of COND
           (SETQ from_pageview T)
           (C:VIEWSHT)
           (SETQ from_pageview NIL)
    ) ;_ end of PROGN
  ) ;_ end of IF
;;;  (SETQ skip_qry NIL)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN C:PGLT ()
  (IF ndxfil
    NIL
    (PROGN (SETQ ndxfil (GETFILED "Select Project Index / Sheet Data File to use"
                                  (STRCAT (GETVAR "dwgprefix") "huandx.txt")
                                  "txt"
                                  0
                        ) ;_ end of GETFILED
           ) ;_ end of SETQ
           (IF ustr
             nil
             (LOAD "ustr" "\nFile USTR.LSP not found! ")
           ) ;_ end of if
           (SETQ fnfilter (ustr 1
                                "File name filter (. for none)"
                                (IF fnfilter
                                  fnfilter
                                  "."
                                ) ;_ end of IF
                                T
                          ) ;_ end of ustr
           ) ;_ end of SETQ
           (make_bnds_lst)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF ndxfil
    (PROGN (IF ukword
             NIL
             (LOAD "ukword" "\nFile UKWORD.LSP not loaded! ")
           ) ;_ end of IF
           (SETQ rev_settings
                  (ukword 1
                          "Yes No"
                          "Change page view settings <Yes/No>"
                          (IF rev_settings
                            rev_settings
                            "No"
                          ) ;_ end of if
                  ) ;_ end of ukword
           ) ;_ end of SETQ
           (IF (EQ rev_settings "Yes")
             (SETQ skip_qry NIL)
             (SETQ skip_qry T)
           ) ;_ end of IF
           (COND ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-#")(WCMATCH sht_to_view "*@*`.#"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 1))
                                       (ITOA (1- (ATOI (SUBSTR sht_to_view (STRLEN sht_to_view)))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 1))
                                 (ITOA (1- (ATOI (SUBSTR sht_to_view (STRLEN sht_to_view)))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-##")(WCMATCH sht_to_view "*@*`.##"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 2))
                                       (ITOA (1- (ATOI (SUBSTR sht_to_view (1- (STRLEN sht_to_view))))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 2))
                                 (ITOA (1- (ATOI (SUBSTR sht_to_view (1- (STRLEN sht_to_view))))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (OR(WCMATCH sht_to_view "*@*-###")(WCMATCH sht_to_view "*@*`.###"))
                       (MEMBER (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 3))
                                       (ITOA (1- (ATOI (SUBSTR sht_to_view (- (STRLEN sht_to_view) 2)))))
                               ) ;_ end of STRCAT
                               shtids
                       ) ;_ end of MEMBER
                  ) ;_ end of AND
                  (SETQ sht_to_view
                         (STRCAT (SUBSTR sht_to_view 1 (- (STRLEN sht_to_view) 3))
                                 (ITOA (1- (ATOI (SUBSTR sht_to_view (- (STRLEN sht_to_view) 2)))))
                         ) ;_ end of STRCAT
                  ) ;_ end of SETQ
                 )
                 ((AND sht_to_view
                       (WCMATCH sht_to_view "*@*")
                       (/= sht_to_view (CAR shtids))
                       (MEMBER sht_to_view shtids)
                  ) ;_ end of AND
                  (SETQ sht_to_view (CADR (MEMBER sht_to_view (REVERSE shtids))))
                 )
                 ((AND sht_to_view (EQ (TYPE (READ sht_to_view)) 'INT))
                  (SETQ sht_to_view (ITOA (1- (ATOI sht_to_view))))
                 )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 2) (EQ (TYPE (READ (SUBSTR sht_to_view 2))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 1) (ITOA (1- (ATOI (SUBSTR sht_to_view 2))))))
;;;        )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 3) (EQ (TYPE (READ (SUBSTR sht_to_view 3))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 2) (ITOA (1- (ATOI (SUBSTR sht_to_view 3))))))
;;;        )
;;;        ((AND sht_to_view (> (STRLEN sht_to_view) 4) (EQ (TYPE (READ (SUBSTR sht_to_view 4))) 'INT))
;;;           (SETQ sht_to_view (STRCAT (SUBSTR sht_to_view 1 3) (ITOA (1- (ATOI (SUBSTR sht_to_view 4))))))
;;;        )
                 (T (SETQ skip_qry NIL))
           ) ;_ end of COND
           (SETQ from_pageview T)
           (C:VIEWSHT)
           (SETQ from_pageview NIL)
    ) ;_ end of PROGN
  ) ;_ end of IF
;;;  (SETQ skip_qry NIL)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN make_bnds_lst (/ ndxlst)
;;;  (IF proj_dir NIL
;;;    (SETQ proj_dir (GETVAR "dwgprefix"))
;;;  )
;;;  (SETQ ndxfil (FINDFILE (STRCAT proj_dir "huandx.txt")))
;;;  (PRINC ndxfil)
  (SETQ opnfil (OPEN ndxfil "r"))
  (WHILE (SETQ ndxlin (READ-LINE opnfil)) (SETQ ndxlst (APPEND ndxlst (LIST ndxlin))))
  (CLOSE opnfil)
  (SETQ bnds nil)
  (FOREACH n ndxlst
    (IF (AND (WCMATCH n (STRCAT "*" (CHR 40) (CHR 40) "*"))
             (OR (AND fnfilter (WCMATCH (STRCASE n) (STRCASE fnfilter))) (EQ fnfilter "."))
        ) ;_ end of AND
      (PROGN
        (SETQ ncnt 3)
        (WHILE (/= (SUBSTR n ncnt 2) (STRCAT (CHR 40) (CHR 40))) (SETQ ncnt (1+ ncnt)))
        (IF (AND (WCMATCH (SUBSTR n ncnt) (STRCAT (CHR 40) (CHR 40) "\"\"*")) (WCMATCH (STRCASE n) "*.DWG*"))
          (PROGN (SETQ nm_ndx 1)
                 (WHILE (AND (NOT (WCMATCH (SUBSTR n (1+ nm_ndx) 1) ".")) (NOT (WCMATCH (SUBSTR n (1+ nm_ndx) 1) " ")))
                   (SETQ nm_ndx (1+ nm_ndx))
                 ) ;_ end of WHILE
                 (SETQ bnds
                        (APPEND bnds
                                (READ (STRCAT (CHR 40) (CHR 40) "\"" (SUBSTR n 1 nm_ndx) "\"" (CHR 40) (SUBSTR n (+ 5 ncnt))))
                        ) ;_ end of APPEND
                 ) ;_ end of SETQ
          ) ;_ end of PROGN
          (SETQ bnds (APPEND bnds (READ (SUBSTR n ncnt))))
        ) ;_ end of IF
      ) ;_ end of progn
    ) ;_ end of if
  ) ;_ end of foreach
  (PRINC)
) ;_ end of defun
;;;****************************************************************************
(DEFUN c:esbnd ()
  (SETQ sbnd_ss (SSGET "x" '((8 . "*SBND*"))))
  (IF sbnd_ss
    (PROGN (SETQ sbnd_len (SSLENGTH sbnd_ss))
           (SETQ sbnd_cnt 0)
           (WHILE (< sbnd_cnt sbnd_len) (ENTDEL (SSNAME sbnd_ss sbnd_cnt)) (SETQ sbnd_cnt (1+ sbnd_cnt)))
    ) ;_ end of PROGN
    (PRINC "\nNothing to erase! ")
  ) ;_ end of IF
  (PRINC)
) ;_ end of defun
;;; The restrained joint function RESJNT (below) requires sheet boundary information (the list whose symbol name is
;;; 'bnds') that SHTBND generates.  This is generated from boundary information saved in HUANDX.TXT by the HUANDX
;;; function.  This information is only saved in HUANDX.TXT under certain circumstances, e.g., the drawing is in
;;; pspace,
;;; a specific title fill-in block exists, etc. HUANDX is only intended to save information for actual sheets as
;;; opposed
;;; to model drawings, XREF's and the like. HUANDX is a subroutine of C:QSAVE, a customized version of QSAVE which is
;;; defined in UNDEFS.LSP.
;;;****************************************************************************
(DEFUN c:resjnt (/ maxsetx minsetx maxsety minsety)
  (IF ndxfil
    (PROGN
      (IF ukword
        NIL
        (LOAD "ukword" "\nFile UKWORD.LSP not loaded! ")
      ) ;_ end of IF
      (IF ustr
        NIL
        (LOAD "ustr" "\nFile USTR.LSP not loaded! ")
      ) ;_ end of IF
      (IF ureal
        NIL
        (LOAD "ureal" "\nFile UREAL.LSP not loaded! ")
      ) ;_ end of IF
      (IF uint
        NIL
        (LOAD "uint" "\nFile UINT.LSP not loaded! ")
      ) ;_ end of IF
      (IF upoint
        NIL
        (LOAD "upoint" "\nFile UPOINT.LSP not loaded! ")
      ) ;_ end of IF
      (SETQ top_txt (USTR 1
                          "Text to be placed above dimension line"
                          (IF top_txt
                            top_txt
                            "RESTRAINED"
                          ) ;_ end of IF
                          T
                    ) ;_ end of USTR
      ) ;_ end of SETQ
      (SETQ bot_txt (USTR 1
                          "Text to be placed below dimension line"
                          (IF bot_txt
                            bot_txt
                            "JOINTS"
                          ) ;_ end of IF
                          T
                    ) ;_ end of USTR
      ) ;_ end of SETQ
      (SETQ v_fact (UREAL 1 "" "Enter vertical scale factor" v_fact))
      (SETQ incl_statxt
             (ukword 1
                     "Yes No"
                     "Label restrained joint begin and end stations? [Yes/No]"
                     (IF incl_statxt
                       incl_statxt
                       "Yes"
                     ) ;_ end of IF
             ) ;_ end of ukword
      ) ;_ end of SETQ
      (IF (EQ incl_statxt "Yes")
        (SETQ rjstaprec (UINT 1 "" "Decimal precision for station labels" rjstaprec))
      ) ;_ end of IF
      (WHILE (AND (/= (SETQ begsta (ureal 1 "Quit" "Beginning station of restrained joints or [Quit]" old_begsta))
                      "Quit"
                  ) ;_ end of /=
                  (/= (SETQ endsta (ureal 1 "Quit" "Ending station of restrained joints or [Quit]" old_endsta))
                      "Quit"
                  ) ;_ end of /=
             ) ;_ end of AND
        (IF (AND align_lst (OR (>= begsta (NTH 1 (NTH 0 align_lst))) (<= endsta (NTH 1 (LAST align_lst)))))
          (PROGN (SETQ cnt 0
                       beg_mhdat NIL
                       end_mhdat NIL
                 ) ;_ end of SETQ
                 (IF (AND (>= begsta (NTH 1 (NTH 0 align_lst))) (<= begsta (NTH 1 (LAST align_lst))))
                   (WHILE (AND (<= (NTH 1 (NTH cnt align_lst)) begsta) (< cnt (LENGTH align_lst)))
                     (SETQ cnt (1+ cnt))
                     (SETQ beg_mhdat (NTH (1- cnt) align_lst))
                   ) ;_ end of WHILE
                 ) ;_ end of IF
                 (IF (AND (>= endsta (NTH 1 (NTH 0 align_lst))) (<= endsta (NTH 1 (LAST align_lst))))
                   (WHILE (AND (<= (NTH 1 (NTH cnt align_lst)) endsta) (< (1+ cnt) (LENGTH align_lst)))
                     (SETQ cnt (1+ cnt))
                     (SETQ end_mhdat (NTH cnt align_lst))
                   ) ;_ end of WHILE
                 ) ;_ end of IF
                 (IF (AND beg_mhdat end_mhdat)
                   (SETQ def_inv (* v_fact (/ (+ (NTH 3 beg_mhdat) (NTH 3 end_mhdat)) 2.0)))
                   (IF beg_mhdat
                     (SETQ def_inv (* v_fact (NTH 3 beg_mhdat)))
                     (IF end_mhdat
                       (SETQ def_inv (* v_fact (NTH 3 end_mhdat)))
                       (SETQ def_inv NIL)
                     ) ;_ end of IF
                   ) ;_ end of IF
                 ) ;_ end of IF
          ) ;_ end of PROGN
        ) ;_ end of IF
        (FOREACH n bnds
          (SETQ boxbndneg nil
                boxbndpos nil
                maxbndx nil
                minbndx nil
                maxbndy nil
                minbndy nil
          ) ;_ end of setq
          (FOREACH o (CDR n)
            (IF maxbndx
              (SETQ maxbndx (MAX (CAR o) maxbndx))
              (SETQ maxbndx (CAR o))
            ) ;_ end of if
            (IF minbndx
              (SETQ minbndx (MIN (CAR o) minbndx))
              (SETQ minbndx (CAR o))
            ) ;_ end of if
            (IF maxbndy
              (SETQ maxbndy (MAX (CADR o) maxbndy))
              (SETQ maxbndy (CADR o))
            ) ;_ end of if
            (IF minbndy
              (SETQ minbndy (MIN (CADR o) minbndy))
              (SETQ minbndy (CADR o))
            ) ;_ end of if
            (COND ((< begsta minbndx)
                   (SETQ beg-lt  T
                         beg-in  NIL
                         dimbegx minbndx
                   ) ;_ end of setq
                  )
                  ((EQ begsta minbndx)
                   (SETQ beg-lt  NIL
                         beg-in  T
                         dimbegx minbndx
                   ) ;_ end of setq
                  )
                  ((> begsta minbndx)
                   (SETQ beg-lt NIL
                         beg-in T
                   ) ;_ end of setq
                   (IF (>= begsta maxbndx)
                     (SETQ dimbegx NIL)
                     (SETQ dimbegx begsta)
                   ) ;_ end of if
                  )
            ) ;_ end of COND
            (COND ((> endsta maxbndx)
                   (SETQ end-rt  T
                         end-in  NIL
                         dimendx maxbndx
                   ) ;_ end of setq
                  )
                  ((EQ endsta maxbndx)
                   (SETQ end-rt  NIL
                         end-in  T
                         dimendx maxbndx
                   ) ;_ end of setq
                  )
                  ((< endsta maxbndx)
                   (SETQ end-rt NIL
                         end-in T
                   ) ;_ end of setq
                   (IF (<= endsta minbndx)
                     (SETQ dimendx NIL)
                     (SETQ dimendx endsta)
                   ) ;_ end of if
                  )
            ) ;_ end of COND
          ) ;_ end of FOREACH
          (IF (AND dimbegx dimendx)
            (PROGN
              (SETQ dimy (- maxbndy (* 0.1 (- maxbndy minbndy))))
              (SETQ maxsety (IF maxsety
                              (MAX maxsety dimy)
                              dimy
                            ) ;_ end of IF
              ) ;_ end of SETQ
              (SETQ minsety (IF minsety
                              (MIN minsety dimy)
                              dimy
                            ) ;_ end of IF
              ) ;_ end of SETQ
              (SETQ minsetx (IF minsetx
                              (MIN minsetx dimbegx)
                              dimbegx
                            ) ;_ end of IF
              ) ;_ end of SETQ
              (SETQ maxsetx (IF maxsetx
                              (MAX maxsetx dimendx)
                              dimendx
                            ) ;_ end of IF
              ) ;_ end of SETQ
              (SETQ midx (+ minsetx (/ (- maxsetx minsetx) 2.0))
                    midy (+ minsety (/ (- maxsety minsety) 2.0))
              ) ;_ end of SETQ
              (IF (AND midx midy)
                (COMMAND ".zoom"
                         "c"
                         (LIST midx
                               (IF def_inv
                                 def_inv
                                 (IF old_dimy
                                   old_dimy
                                   midy
                                 ) ;_ end of IF
                               ) ;_ end of IF
                               0
                         ) ;_ end of LIST
                         ""
                ) ;_ end of COMMAND
              ) ;_ end of IF
              (IF (AND (EQ old_dimbegx dimbegx) (EQ old_dimendx dimendx))
                NIL
                (PROGN
                  (SETQ dimy (CADR (upoint 1
                                           "Key-in"
                                           "Pick \"Y\" for restrained joint label or [Key-in]"
                                           (LIST dimbegx
                                                 (IF old_dimy
                                                   old_dimy
                                                   0
                                                 ) ;_ end of IF
                                                 0
                                           ) ;_ end of LIST
                                           (LIST dimbegx
                                                 (IF old_dimy
                                                   old_dimy
                                                   0
                                                 ) ;_ end of IF
                                                 0
                                           ) ;_ end of LIST
                                   ) ;_ end of upoint
                             ) ;_ end of CADR
                  ) ;_ end of SETQ
                  (IF (EQ dimy "Keyin")
                    (SETQ dimy (ureal 1
                                      ""
                                      "Key-in \"Y\" for restrained joint label"
                                      (IF old_dimy
                                        old_dimy
                                        nil
                                      ) ;_ end of IF
                               ) ;_ end of ureal
                    ) ;_ end of SETQ
                  ) ;_ end of IF
                  (SETQ old_dimy dimy)
                  (IF (AND align_lst (>= dimbegx (NTH 1 (NTH 0 align_lst))) (<= dimbegx (NTH 1 (LAST align_lst))))
                    (PROGN
                      (SETQ cnt 0)
                      (WHILE (AND (< cnt (LENGTH align_lst)) (< (NTH 1 (NTH cnt align_lst)) dimbegx))
                        (SETQ cnt (1+ cnt))
                      ) ;_ end of WHILE
                      (IF (EQ cnt (LENGTH align_lst))
                        (PROGN (SETQ begxlny1 (* v_fact (+ (NTH 3 (LAST align_lst)) (/ (NTH 7 (LAST align_lst)) 24.0))))
                               (when_prev_aln) ;sets endxlny1 with prev_align_lst or none
                        ) ;_ end of PROGN
                        (SETQ segp_sz  (NTH 7
                                            (NTH (IF (EQ cnt 0)
                                                   0
                                                   (1- cnt)
                                                 ) ;_ end of IF
                                                 align_lst
                                            ) ;_ end of NTH
                                       ) ;_ end of NTH
                              lt_sta   (NTH 1
                                            (NTH (IF (EQ cnt 0)
                                                   0
                                                   (1- cnt)
                                                 ) ;_ end of IF
                                                 align_lst
                                            ) ;_ end of NTH
                                       ) ;_ end of NTH
                              rt_sta   (NTH 1
                                            (NTH (IF (EQ cnt 0)
                                                   1
                                                   cnt
                                                 ) ;_ end of IF
                                                 align_lst
                                            ) ;_ end of NTH
                                       ) ;_ end of NTH
                              lt_inv   (NTH 3
                                            (NTH (IF (EQ cnt 0)
                                                   0
                                                   (1- cnt)
                                                 ) ;_ end of IF
                                                 align_lst
                                            ) ;_ end of NTH
                                       ) ;_ end of NTH
                              rt_inv   (NTH 3
                                            (NTH (IF (EQ cnt 0)
                                                   1
                                                   cnt
                                                 ) ;_ end of IF
                                                 align_lst
                                            ) ;_ end of NTH
                                       ) ;_ end of NTH
                              pslope   (/ (- rt_inv lt_inv) (- rt_sta lt_sta))
                              begxlny1 (* v_fact (+ lt_inv (* pslope (- dimbegx lt_sta)) (/ segp_sz 24.0)))
                        ) ;_ end of SETQ
                      ) ;_ end of IF
                    ) ;_ end of PROGN
                    (IF beg-in
                      (SETQ begxlny1 (CADR (upoint 1
                                                   ""
                                                   "Pick elevation for beginning extension line origin"
                                                   (IF (AND midx begxlny1)
                                                     (LIST midx begxlny1 0)
                                                     nil
                                                   ) ;_ end of IF
                                                   (IF dimbegx
                                                     (LIST dimbegx 0 0)
                                                     nil
                                                   ) ;_ end of IF
                                           ) ;_ end of upoint
                                     ) ;_ end of CADR
                      ) ;_ end of SETQ
                    ) ;_ end of IF
                  ) ;_ end of if
                  (IF (AND align_lst (>= dimendx (NTH 1 (NTH 0 align_lst))) (<= dimendx (NTH 1 (LAST align_lst))))
                    (PROGN (SETQ cnt 0)
                           (WHILE (AND (< cnt (LENGTH align_lst)) (< (NTH 1 (NTH cnt align_lst)) dimendx))
                             (SETQ cnt (1+ cnt))
                           ) ;_ end of WHILE
                           (IF (EQ cnt (LENGTH align_lst))
                             (SETQ endxlny1 (* v_fact
                                               (+ (NTH 3 (LAST align_lst))
                                                  (/ (NTH 7 (NTH (- (LENGTH align_lst) 2) align_lst)) 24.0)
                                               ) ;_ end of +
                                            ) ;_ end of *
                             ) ;_ end of SETQ
                             (PROGN (SETQ segp_sz  (NTH 7 (NTH (1- cnt) align_lst))
                                          lt_sta   (NTH 1 (NTH (1- cnt) align_lst))
                                          rt_sta   (NTH 1 (NTH cnt align_lst))
                                          lt_inv   (NTH 3 (NTH (1- cnt) align_lst))
                                          rt_inv   (NTH 3 (NTH cnt align_lst))
                                          pslope   (/ (- rt_inv lt_inv) (- rt_sta lt_sta))
                                          endxlny1 (* v_fact (+ lt_inv (* pslope (- dimendx lt_sta)) (/ segp_sz 24.0)))
                                    ) ;_ end of SETQ
                             ) ;_ end of PROGN
                           ) ;_ end of IF
                    ) ;_ end of PROGN
                    (when_prev_aln) ;sets endxlny1 with prev_align_lst or none
                  ) ;_ end of if
                  (IF beg-in
                    (PROGN (IF (< dimy begxlny1)
                             (SETQ begxlny2 (- dimy (* dimsc 0.1))
                                   bstapt   (POLAR (LIST dimbegx dimy 0) PI (* dimsc 0.05))
                             ) ;_ end of SETQ
                             (SETQ begxlny2 (+ dimy (* dimsc 0.1))
                                   bstapt   (POLAR (POLAR (LIST dimbegx dimy 0) PI (* dimsc 0.05)) (* 1.5 PI) (* 1.25 dimsc))
                             ) ;_ end of SETQ
                           ) ;_ end of IF
                           (ENTMAKE (LIST (CONS 0 "LINE")
                                          (CONS 8
                                                (IF do_cmud
                                                  "C-RJNT2DIMS"
                                                  "C-RJNT1DIMS"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 10 (LIST dimbegx begxlny1 0))
                                          (CONS 11 (LIST dimbegx begxlny2 0))
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                           (ENTMAKE (LIST (CONS 0 "TEXT")
                                          (CONS 1 (STRCAT "STA " (stait dimbegx rjstaprec)))
                                          (CONS 7
                                                (IF do_cmud
                                                  "ROMAND"
                                                  "SIMPLEX"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 8 "C-RJNT2STAS")
                                          (CONS 10 bstapt)
                                          (CONS 40 (* dimsc 0.1))
                                          (CONS 50 (/ PI 2.0))
                                          (CONS 51
                                                (IF do_cmud
                                                  0.261799
                                                  0
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                    ) ;_ end of PROGN
                    (PROGN (SETQ ltldrx (POLAR (LIST dimbegx dimy 0) 0 (* 0.11842 dimsc)))
                           (ENTMAKE (LIST (CONS 0 "INSERT")
                                          (CONS 2 "LDRARO")
                                          (CONS 8
                                                (IF do_cmud
                                                  "C-RJNT2DIMS"
                                                  "C-RJNT1DIMS"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 10 ltldrx)
                                          (CONS 41 dimsc)
                                          (CONS 42 dimsc)
                                          (CONS 43 dimsc)
                                          (CONS 50 0)
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                    ) ;_ end of PROGN
                  ) ;_ end of IF
                  (IF end-in
                    (PROGN (IF (< dimy endxlny1)
                             (SETQ endxlny2 (- dimy (* dimsc 0.1))
                                   estapt   (POLAR (LIST dimendx dimy 0) 0 (* dimsc 0.15))
                             ) ;_ end of SETQ
                             (SETQ endxlny2 (+ dimy (* dimsc 0.1))
                                   estapt   (POLAR (POLAR (LIST dimendx dimy 0) 0 (* dimsc 0.15)) (* 1.5 PI) (* 1.25 dimsc))
                             ) ;_ end of SETQ
                           ) ;_ end of IF
                           (ENTMAKE (LIST (CONS 0 "LINE")
                                          (CONS 8
                                                (IF do_cmud
                                                  "C-RJNT2DIMS"
                                                  "C-RJNT1DIMS"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 10 (LIST dimendx endxlny1 0))
                                          (CONS 11 (LIST dimendx endxlny2 0))
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                           (ENTMAKE (LIST (CONS 0 "TEXT")
                                          (CONS 1 (STRCAT "STA " (stait dimendx rjstaprec)))
                                          (CONS 7
                                                (IF do_cmud
                                                  "ROMAND"
                                                  "SIMPLEX"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 8 "C-RJNT2STAS")
                                          (CONS 10 estapt)
                                          (CONS 40 (* dimsc 0.1))
                                          (CONS 50 (/ PI 2.0))
                                          (CONS 51
                                                (IF do_cmud
                                                  0.261799
                                                  0
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                    ) ;_ end of PROGN
                    (PROGN (SETQ rtldrx (POLAR (LIST dimendx dimy 0) PI (* 0.11842 dimsc)))
                           (ENTMAKE (LIST (CONS 0 "INSERT")
                                          (CONS 2 "LDRARO")
                                          (CONS 8
                                                (IF do_cmud
                                                  "C-RJNT2DIMS"
                                                  "C-RJNT1DIMS"
                                                ) ;_ end of IF
                                          ) ;_ end of CONS
                                          (CONS 10 rtldrx)
                                          (CONS 41 dimsc)
                                          (CONS 42 dimsc)
                                          (CONS 43 dimsc)
                                          (CONS 50 PI)
                                    ) ;_ end of LIST
                           ) ;_ end of ENTMAKE
                    ) ;_ end of PROGN
                  ) ;_ end of IF
                  (ENTMAKE (LIST (CONS 0 "LINE")
                                 (CONS 8
                                       (IF do_cmud
                                         "C-RJNT2DIMS"
                                         "C-RJNT1DIMS"
                                       ) ;_ end of IF
                                 ) ;_ end of CONS
                                 (CONS 10 (LIST dimbegx dimy 0))
                                 (CONS 11 (LIST dimendx dimy 0))
                           ) ;_ end of LIST
                  ) ;_ end of ENTMAKE
                  (ENTMAKE (LIST (CONS 0 "INSERT")
                                 (CONS 2 "LDRARO")
                                 (CONS 8
                                       (IF do_cmud
                                         "C-RJNT2DIMS"
                                         "C-RJNT1DIMS"
                                       ) ;_ end of IF
                                 ) ;_ end of CONS
                                 (CONS 10 (LIST dimbegx dimy 0))
                                 (CONS 41 dimsc)
                                 (CONS 42 dimsc)
                                 (CONS 43 dimsc)
                                 (CONS 50 0)
                           ) ;_ end of LIST
                  ) ;_ end of ENTMAKE
                  (ENTMAKE (LIST (CONS 0 "INSERT")
                                 (CONS 2 "LDRARO")
                                 (CONS 8
                                       (IF do_cmud
                                         "C-RJNT2DIMS"
                                         "C-RJNT1DIMS"
                                       ) ;_ end of IF
                                 ) ;_ end of CONS
                                 (CONS 10 (LIST dimendx dimy 0))
                                 (CONS 41 dimsc)
                                 (CONS 42 dimsc)
                                 (CONS 43 dimsc)
                                 (CONS 50 PI)
                           ) ;_ end of LIST
                  ) ;_ end of ENTMAKE
                  (IF (>= (SETQ dimdist (DISTANCE (LIST dimbegx dimy 0) (LIST dimendx dimy 0))) (* 1.0 dimsc))
                    (PROGN (SETQ ttxtpt (POLAR (POLAR (LIST dimbegx dimy 0) 0 (/ dimdist 2.0)) (* PI 0.5) (* dimsc 0.1)))
                           (SETQ btxtpt (POLAR (POLAR (LIST dimbegx dimy 0) 0 (/ dimdist 2.0)) (* PI 1.5) (* dimsc 0.1)))
                    ) ;_ end of PROGN
                    (IF beg-in
                      (PROGN (SETQ
                               ttxtpt (POLAR (POLAR (LIST dimbegx dimy 0) PI (* 0.5625 dimsc)) (* PI 0.5) (* dimsc 0.1))
               ; _
               ; end
               ; of
               ; POLAR
                             ) ;_ end of setq
                             (SETQ
                               btxtpt (POLAR (POLAR (LIST dimbegx dimy 0) PI (* 0.5625 dimsc)) (* PI 1.5) (* dimsc 0.1))
               ; _
               ; end
               ; of
               ; POLAR
                             ) ;_ end of setq
                      ) ;_ end of PROGN
                      (PROGN (SETQ ttxtpt (POLAR (POLAR (LIST dimendx dimy 0) 0 (* 0.5625 dimsc)) (* PI 0.5) (* dimsc 0.1))
               ; _ end
               ; of
               ; POLAR
                             ) ;_ end of setq
                             (SETQ btxtpt (POLAR (POLAR (LIST dimendx dimy 0) 0 (* 0.5625 dimsc)) (* PI 1.5) (* dimsc 0.1))
               ; _ end
               ; of
               ; POLAR
                             ) ;_ end of setq
                      ) ;_ end of PROGN
                    ) ;_ end of IF
                  ) ;_ end of IF
                  (IF top_txt
                    (ENTMAKE (LIST (CONS 0 "TEXT")
                                   (CONS 1 top_txt)
                                   (CONS 7
                                         (IF do_cmud
                                           "ROMAND"
                                           "SIMPLEX"
                                         ) ;_ end of IF
                                   ) ;_ end of CONS
                                   (CONS 8 "C-RJNT2DIMS")
                                   (CONS 10 ttxtpt)
                                   (CONS 11 ttxtpt)
                                   (CONS 40 (* dimsc 0.1))
                                   (CONS 51
                                         (IF do_cmud
                                           0.261799
                                           0
                                         ) ;_ end of IF
                                   ) ;_ end of CONS
                                   (CONS 72 1)
                                   (CONS 73 2)
                             ) ;_ end of LIST
                    ) ;_ end of ENTMAKE
                  ) ;_ end of IF
                  (IF bot_txt
                    (ENTMAKE (LIST (CONS 0 "TEXT")
                                   (CONS 1 bot_txt)
                                   (CONS 7
                                         (IF do_cmud
                                           "ROMAND"
                                           "SIMPLEX"
                                         ) ;_ end of IF
                                   ) ;_ end of CONS
                                   (CONS 8 "C-RJNT2DIMS")
                                   (CONS 10 btxtpt)
                                   (CONS 11 btxtpt)
                                   (CONS 40 (* dimsc 0.1))
                                   (CONS 51
                                         (IF do_cmud
                                           0.261799
                                           0
                                         ) ;_ end of IF
                                   ) ;_ end of CONS
                                   (CONS 72 1)
                                   (CONS 73 2)
                             ) ;_ end of LIST
                    ) ;_ end of ENTMAKE
                  ) ;_ end of IF
                ) ;_ end of PROGN
              ) ;_ end of IF
              (SETQ old_dimbegx dimbegx
                    old_dimendx dimendx
              ) ;_ end of SETQ
            ) ;_ end of PROGN
          ) ;_ end of if
        ) ;_ end of foreach
        (SETQ maxsetx NIL
              minsetx NIL
              maxsety NIL
              minsety NIL
              dimy NIL
              midy NIL
              midx NIL
              old_begsta begsta
              old_endsta endsta
        ) ;_ end of SETQ
      ) ;_ end of WHILE
      (IF (TBLSEARCH "LAYER" "C-RJNT1DIMS")
        (COMMAND ".layer" "c" "1" "C-RJNT1DIMS" "")
      ) ;_ end of IF
      (IF (TBLSEARCH "LAYER" "C-RJNT2DIMS")
        (COMMAND ".layer" "c" "2" "C-RJNT2DIMS" "")
      ) ;_ end of IF
      (IF (TBLSEARCH "LAYER" "C-RJNT2STAS")
        (COMMAND ".layer" "c" "2" "C-RJNT2STAS" "")
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN when_prev_aln ()
  (IF (AND prev_align_lst
           (>= dimendx (NTH 1 (NTH 0 prev_align_lst)))
           (<= dimendx (NTH 1 (LAST prev_align_lst)))
      ) ;_ end of AND
    (PROGN (SETQ cnt 0)
           (WHILE (AND (< cnt (LENGTH prev_align_lst)) (< (NTH 1 (NTH cnt prev_align_lst)) dimendx))
             (SETQ cnt (1+ cnt))
           ) ;_ end of WHILE
           (IF (EQ cnt (LENGTH prev_align_lst))
             (PROGN (IF end-in
                      (SETQ endxlny1 (CADR (upoint 1
                                                   ""
                                                   "Pick elevation for ending extension line origin"
                                                   (IF (AND midx endxlny1)
                                                     (LIST midx endxlny1 0)
                                                     nil
                                                   ) ;_ end of IF
                                                   (IF dimendx
                                                     (LIST dimendx 0 0)
                                                     nil
                                                   ) ;_ end of IF
                                           ) ;_ end of upoint
                                     ) ;_ end of CADR
                      ) ;_ end of SETQ
                    ) ;_ end of IF
             ) ;_ end of PROGN
             (SETQ segp_sz  (NTH 7 (NTH (1- cnt) prev_align_lst))
                   lt_sta   (NTH 1 (NTH (1- cnt) prev_align_lst))
                   rt_sta   (NTH 1 (NTH cnt prev_align_lst))
                   lt_inv   (NTH 3 (NTH (1- cnt) prev_align_lst))
                   rt_inv   (NTH 3 (NTH cnt prev_align_lst))
                   pslope   (/ (- rt_inv lt_inv) (- rt_sta lt_sta))
                   endxlny1 (* v_fact (+ lt_inv (* pslope (- dimendx lt_sta)) (/ segp_sz 24.0)))
             ) ;_ end of SETQ
           ) ;_ end of IF
    ) ;_ end of PROGN
    (PROGN (IF end-in
             (SETQ endxlny1 (CADR (upoint 1
                                          ""
                                          "Pick elevation for ending extension line origin"
                                          (IF (AND midx endxlny1)
                                            (LIST midx endxlny1 0)
                                            nil
                                          ) ;_ end of IF
                                          (IF dimendx
                                            (LIST dimendx 0 0)
                                            nil
                                          ) ;_ end of IF
                                  ) ;_ end of upoint
                            ) ;_ end of CADR
             ) ;_ end of SETQ
           ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN make_shtbnd_group
       (name alblss / );shtbnd_objdict shtbnd_grpdict grpseq_cnt grp_name_a grp_name_b grp_name_b2 grp_name_c)
    (PROGN
      (SETQ grp_name_a name
            grp_name_b (ITOA grp_count)
      ) ;_ end of setq
      (SETQ shtbnd_objdict (NAMEDOBJDICT))
      (SETQ shtbnd_grpdict (DICTSEARCH shtbnd_objdict "ACAD_GROUP"))
      (SETQ tst_ss alblss)
      (IF (DICTSEARCH (CDAR shtbnd_grpdict) (STRCAT grp_name_a "_" grp_name_b))
        (COMMAND "-group" "create" (STRCAT grp_name_a "_" grp_name_b) "Y" "SHTBND_TAG" alblss "") ;_ end of COMMAND
        (COMMAND "-group" "create" (STRCAT grp_name_a "_" grp_name_b) "SHTBND_TAG" alblss "") ;_ end of COMMAND
      ) ;_ end of if
    ) ;_ end of PROGN
) ;_ end of DEFUN
;;;****************************************************************************


;|Visual LISP Format Options (120 2 15 2 T "end of " 100 9 2 0 nil nil nil T T)
 ***Don't add text below the comment!***|;
