;;;Batch plotting Dialog application.  Creates a script for batch operations.
;;;Script only check box omits plot instructions from script for scripting
;;;anything without plotting.  Requires DOSLIB 2K
;;;
;;;      Author:  Henry C. Francis
;;;               425 N. Ashe Street
;;;               Southern Pines, NC 28387
;;;
;;;     Copyright:  3-13-97
;;;        Edited:  4-3-2007
;;;
;;;      All rights reserved without prejudice.
;;;
;;;Added ability to have DWG name (w/o ext) written for script-only output filename
;;;If (EQ ins_fname 1), DWG name will be written between pre & post script files.
;;;
;;;	1-16-2004:	Fixed prob. in funct. (setone) where long filename
;;;			(< 48 chars w/o path) caused infinite loop.
;;;      3-1-2007:	Added ability to use 2-place precision sheets sizes for making
;;;			Nominal 24"x36" TIFF images that will plot to scale on 36" wide
;;;			Paper w/o rotation. Requires a sheet size of 35.62"x23.62" for
;;;			the HP 1055CM plotter.  The name of the custom paper size for
;;;			the TIFF driver "35.62x23.62 300dpi (10686.00 x 7086 pixels)"
;;;
;;;	 4-3-2007:	Fixed batch layout plot to include pre-plot and post-plot scripts.
;;;			Since batch layout plotting is handled by an autolisp routine 
;;;			batch layout scripts could not be scripts in the normal sense.
;;;			In order to function within autolisp they must contain only
;;;			autolisp statements.
;;;
;;;	1-26-2010:	Added support for automatically converting raster images to the
;;;			correct DPI using IrfanView, a free image editing software.
;;;			AutoCAD ALWAYS creates unspecified DPI images = (default 72 dpi), dang it!
;;;
;;;     9-2-2010:	Removed all "SDI" restrictions.
;;;
;;;****************************************************************************
(DEFUN bplot2k_error (msg /)
  (SETQ *error* old_bp2kerror)
  (PRINC msg)
  (IF img_prvplst
    (PROGN
      (SETQ prvplst img_prvplst)
      (vl-bb-set 'bb-prvplst img_prvplst)
    )
  ) ;_ end of IF
  (IF img_pltlst
    (PROGN
      (SETQ pltlst img_pltlst)
      (vl-bb-set 'bb-pltlst img_pltlst)
    )
  ) ;_ end of IF
  (IF img_pltndx
    (PROGN
      (SETQ pltndx img_pltndx)
      (vl-bb-set 'bb-pltndx img_pltndx)
    )
  ) ;_ end of IF
  (TERM_DIALOG)
  (PRINC)
) ;_ end of defun
;;;****************************************************************************
(DEFUN c:bplot2k (/ cusom-window-llcor cusom-window-urcor fourslist)
;;;  (SETVAR "TILEMODE" 0)
  (IF (AND (NOT prvplst)(vl-bb-ref 'bb-prvplst))
    (SETQ prvplst (vl-bb-ref 'bb-prvplst))
  )
  (IF (AND (NOT pltlst)(vl-bb-ref 'bb-pltlst))
    (SETQ pltlst  (vl-bb-ref 'bb-pltlst))
  )
  (IF (AND (NOT pltndx)(vl-bb-ref 'bb-pltndx))
    (SETQ pltndx  (vl-bb-ref 'bb-pltndx))
  )
  (IF check_for_doslib
    nil
    (LOAD "check_for_doslib"
          "\nFile CHECK_FOR_DOSLIB.LSP not loaded! "
    ) ;_ end of LOAD
  ) ;_ end of IF
  (IF check_for_doslib
    (check_for_doslib)
  ) ;_ end of IF
  (IF myopen_fun
    nil
    (LOAD "myopen_fun"
          "\nFile MYOPEN_FUN.LSP not loaded! "
    ) ;_ end of LOAD
  ) ;_ end of IF
  (SETQ old_bp2kerror *error*)
  (SETQ *error* bplot2k_error)
  (SETQ princprfx (IF debug_princs
                    "[DEBUG]  "
                    ""
                  ) ;_ end of IF
  ) ;_ end of SETQ
  (IF princdebugstrs
    nil
    (LOAD "princdebugstrs"
          "\nFile PRINCDEBUGSTRS.LSP not loaded! "
    ) ;_ end of LOAD
  ) ;_ end of IF
  (IF princdebugstrs
    (princdebugstrs
      (LIST "Begin execution of BPLOT2K function.\n")
    ) ;_ end of princdebugstrs
  ) ;_ end of IF
  (SETQ
    dirini T
    caldir nil
    selndi nil
  ) ;_ end of setq
  (SETQ old_bp2kecho (GETVAR "CMDECHO"))
  (SETVAR "CMDECHO" 0)
  (SETQ old_bp2kexpert (GETVAR "expert"))
  (IF browser_help
    nil
    (LOAD "browser_help" "\nFile BROWSER_HELP not loaded!")
  ) ;_ end of IF
  (COND
                                        ;if DOSLib is already loaded, return true
    ((NOT (NULL DOS_ABOUT))
     (IF (AND (NOT (EQ (GETVAR "SDI") 0))
              (>= (ATOI (SUBSTR (GETVAR "ACADVER") 1 2)) 15)
         ) ;_ end of AND
       (IF
         (AND
           (IF
             (AND (>= (ATOI (SUBSTR (GETVAR "ACADVER") 1 2)) 15)
                  (< (ATOI (SUBSTR (GETVAR "ACADVER") 1 2)) 18)
             )
             (FINDFILE "pagesetup16.dwt")
             (FINDFILE "pagesetup.dwt")
           )
           (FINDFILE "pagesetup.lst")
         )
         (SETQ abort_bplot2k nil)
         (SETQ abort_bplot2k T)
       ) ;_ end of IF
       (PROGN
         (IF acaddoclist NIL (LOAD "acaddoclist" "\nFile ACADDOCLIST.LSP not loaded! "))
         (IF acaddoclist (acaddoclist))
         (IF (OR (NOT thedoclist)(>(LENGTH thedoclist)1))
           (PROGN
             (SETQ abort_bplot2k T)
             (IF (>= (ATOI (SUBSTR (GETVAR "ACADVER") 1 2)) 15)
               (ALERT
                 "SDI value must be compatible with a single document interface"
               ) ;_ end of ALERT
               (ALERT
                 "Bplot2K is not compatible with versions of AutoCAD less than 2004"
               ) ;_ end of ALERT
             )
           ) ;_ end of PROGN
           (SETVAR "SDI" 1)
         )
       )
     ) ;_ end of IF
   )
                                        ;if AutoCAD Release 12, 
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 12)
     (SETQ abort_bplot2k T)
;;;     (XLOAD "doslib12")
    )
                                        ;if AutoCAD Release 13, 
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 13)
     (SETQ abort_bplot2k T)
;;;     (XLOAD "doslib13" nil)
    )
                                        ;if AutoCAD Release 14, 
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 14)
     (SETQ abort_bplot2k T)
;;;     (ARXLOAD "doslib14")
    )
                                        ;if AutoCAD Release 2000, 
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 15)
          (NOT DOS_VER)
     ) ;_ end of and
     (ARXLOAD "doslib15")
    )
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 16)
          (NOT DOS_VER)
     ) ;_ end of and
     (ARXLOAD "doslib16")
    )
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 17)
          (NOT DOS_VER)
     ) ;_ end of and
     (IF (WCMATCH (STRCASE (GETVAR "platform")) "*(X64)*")
       (ARXLOAD "doslib17x64")
       (ARXLOAD "doslib17")
     ) ;_ end of IF
;;;     (IF (EQ (STRCASE (GETVAR "loginname")) "CFRANCIS")
;;;       (ARXLOAD "doslib17x64")
;;;       (ARXLOAD "doslib17")
;;;     )
    )
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 18)
          (NOT DOS_VER)
     ) ;_ end of and
     (IF (WCMATCH (STRCASE (GETVAR "platform")) "*(X64)*")
       (ARXLOAD "doslib18x64")
       (ARXLOAD "doslib18")
     ) ;_ end of IF
    )
                                        ;default message
;;;    (T
;;;     (SETQ abort_bplot2k T)
;;;    )
  ) ;_ end of cond
  (IF abort_bplot2k
    (IF (NOT
          (AND (FINDFILE "pagesetup.dwt") (FINDFILE "pagesetup.lst"))
        ) ;_ end of NOT
      (IF DOS_MSGBOX
        (DOS_MSGBOX
          (STRCAT
            "The AutoCAD template file PAGESETUP.DWT was not found!\n"
            "PAGESETUP.DWT and an ASCII text file named PAGESETUP.LST\n"
            "must both exist in a folder on your AutoCAD Support File\n"
            "Search Path.  PAGESETUP.DWT must contain all the page setups\n"
            "that you want to use with BPLOT2K and PAGESETUP.LST must\n"
            "contain the names of those page setups, one name per line.") ;_ end of STRCAT
 ;_ end of STRCAT
          "ABORTING BPLOT2K"
          1
          5
        ) ;_ end of DOS_MSGBOX
        (ALERT
          (STRCAT
            "The AutoCAD template file PAGESETUP.DWT was not found!\n"
            "PAGESETUP.DWT and an ASCII text file named PAGESETUP.LST\n"
            "must both exist in a folder on your AutoCAD Support File\n"
            "Search Path.  PAGESETUP.DWT must contain all the page setups\n"
            "that you want to use with BPLOT2K and PAGESETUP.LST must\n"
            "contain the names of those page setups, one name per line.") ;_ end of STRCAT
 ;_ end of STRCAT
        ) ;_ end of ALERT
      ) ;_ end of IF
      (IF DOS_MSGBOX
        (DOS_MSGBOX
          "BPLOT2K is designed for use with AutoCAD version 2004 or greater\nin Single Document Interface mode (SDI=1,2,3) only!\n\n                             *** ABORTING ***"
          "ABORTING BPLOT2K"
          1
          5
        ) ;_ end of DOS_MSGBOX
        (ALERT
          "BPLOT2K is designed for use with AutoCAD version 2004 or greater\nin Single Document Interface mode (SDI=1,2,3) only!\n\n                                     *** ABORTING ***"
        ) ;_ end of ALERT
      ) ;_ end of IF
    ) ;_ end of IF
    (PROGN
      (IF ins_fname
        nil
        (SETQ ins_fname "0")
      ) ;_ end of IF
                                        ;  (setq orgdrv (dos_drive))
      (SETQ orgdrv (SUBSTR (GETVAR "dwgprefix") 1 2))
      (IF debug_doslib
        (PRINC "\nDOS_1 ")
      ) ;_ end of IF
      (IF DOS_DRIVE
        (DOS_DRIVE orgdrv)
        (ALERT
          "BPLOT2K requires Robert McNeel & Associates' DOSLIB\nDOSLIB is a free utility for use with AutoCAD.\nPlease visit http://www.mcneel.com/ to get this app."
        ) ;_ end of ALERT
      ) ;_ end of IF
      (IF debug_doslib
        (PRINC "\nDOS_1 ")
      ) ;_ end of IF
                                        ;  (setq orgdir (dos_pwdir))
      (SETQ orgdir (GETVAR "dwgprefix"))
      (IF debug_doslib
        (PRINC "\nDOS_2 ")
      ) ;_ end of IF
      (DOS_CHDIR (SUBSTR orgdir 4))
      (IF debug_doslib
        (PRINC "\nDOS_2 ")
      ) ;_ end of IF
      (SETQ dirstr (STRCAT "Selection path: " (GETVAR "dwgprefix"))
                                        ;(DOS_PWDIR)
            olddir dirstr
      ) ;_ end of setq
;;;      (PRINC "\ndirstr = ")
;;;      (PRINC dirstr)
;;;      (PRINC)
      (IF debug_doslib
        (PRINC "\nDOS_3 ")
      ) ;_ end of IF
      (SETQ d_flst (DOS_DIR (STRCAT (GETVAR "dwgprefix") "*.dwg")))
      (SETQ ddirs (DOS_SUBDIR (GETVAR "dwgprefix")))
      (IF debug_doslib
        (PRINC "\nDOS_3 ")
      ) ;_ end of IF
      (IF (EQ (SUBSTR dirstr (1- (STRLEN dirstr))) ":\\")
        (IF ddirs
          nil
          (SETQ ddirs (LIST ""))
        ) ;_ end of if
        (IF ddirs
          (IF (MEMBER ".." ddirs)
            nil
            (SETQ ddirs (APPEND (LIST "..") ddirs))
          ) ;_ end of if
          (SETQ ddirs (LIST ".."))
        ) ;_ end of if
      ) ;_ end of if
      (IF debug_doslib
        (PRINC "\nDOS_4 ")
      ) ;_ end of IF
      (SETQ ddrvs (DOS_DRIVES))
      (IF debug_doslib
        (PRINC "\nDOS_4 ")
      ) ;_ end of IF
      (IF (MEMBER "A:" ddrvs)
        (SETQ ddrvs (CDR (MEMBER "A:" ddrvs)))
      ) ;_ end of if
      (IF (MEMBER "B:" ddrvs)
        (SETQ ddrvs (CDR (MEMBER "B:" ddrvs)))
      ) ;_ end of if
      (loadpages)
      (SETQ num (LOAD_DIALOG "bplot2k"))
      (NEW_DIALOG "bplot2k" num)
      (SET_TILE "dirtxt" dirstr)
      (drvlst)
      (START_LIST "file_drv")
      (MAPCAR 'ADD_LIST avdrvs)
      (END_LIST)
      (setfdrv)
      (sortfiles)
      (IF sortdate
        nil
        (SETQ sortdate "0")
      ) ;_ end of IF
      (SET_TILE "sortdate" sortdate)
      (IF include_plbl
        nil
        (SETQ include_plbl "0")
      ) ;_ end of IF
      (SET_TILE "include_plbl" include_plbl)
      (IF frepages NIL (SETQ frepages "0"))
      (SET_TILE "frepages" frepages)
      (IF jstscr
        (PROGN
          (SET_TILE "jst_scr" "1")
          (SET_TILE "selnum" "0 Drawings selected for script only:")
          (SET_TILE "Preplot" "Pre-name:")
          (SET_TILE "Postplot" "Post-name:")
          (SET_TILE "ins_fname" ins_fname)
          (MODE_TILE "plotrs" 1)
          (MODE_TILE "pages" 1)
          (MODE_TILE "frepages" 1)
          (MODE_TILE "plotwindow" 1)
          (MODE_TILE "plotwin_llx" 1)
          (MODE_TILE "plotwin_lly" 1)
          (MODE_TILE "plotwin_urx" 1)
          (MODE_TILE "plotwin_ury" 1)
          (MODE_TILE "file_drv" 1)
          (MODE_TILE "forcedim0" 0)
          (MODE_TILE "force_wcs" 0)
          (MODE_TILE "allayplt" 0)
          (MODE_TILE "etrf_scr" 0)
          (MODE_TILE "forcedim0" 0)
          (MODE_TILE "out_to" 1)
          (MODE_TILE "plttobox" 1)
          (MODE_TILE "ins_fname" 0)
          (MODE_TILE "include_plbl" 1)
        ) ;_ end of progn
        (PROGN
          (SET_TILE "jst_scr" "0")
          (SET_TILE "selnum" "0 Drawings selected for plotting:")
          (SET_TILE "Preplot" "Preplot:")
          (SET_TILE "Postplot" "Postplot:")
          (MODE_TILE "plotrs" 0)
          (MODE_TILE "pages" 0)
          (MODE_TILE "frepages" 0)
          (MODE_TILE "plotwindow" 0)
          (IF (EQ plotwindow "1")
            (PROGN
              (MODE_TILE "plotwin_llx" 0)
              (MODE_TILE "plotwin_lly" 0)
              (MODE_TILE "plotwin_urx" 0)
              (MODE_TILE "plotwin_ury" 0)
            ) ;_ end of PROGN
            (PROGN
              (SETQ plotwindow "0")
              (MODE_TILE "plotwin_llx" 1)
              (MODE_TILE "plotwin_lly" 1)
              (MODE_TILE "plotwin_urx" 1)
              (MODE_TILE "plotwin_ury" 1)
            ) ;_ end of PROGN
          ) ;_ end of IF
          (SET_TILE "plotwindow" plotwindow)
          (IF plotwin_llx
            nil
            (SETQ plotwin_llx 0.0)
          ) ;_ end of IF
          (SET_TILE "plotwin_llx" (RTOS plotwin_llx 2 4))
          (IF plotwin_lly
            nil
            (SETQ plotwin_lly 0.0)
          ) ;_ end of IF
          (SET_TILE "plotwin_lly" (RTOS plotwin_lly 2 4))
          (IF plotwin_urx
            nil
            (SETQ plotwin_urx 34.0)
          ) ;_ end of IF
          (SET_TILE "plotwin_urx" (RTOS plotwin_urx 2 4))
          (IF plotwin_ury
            nil
            (SETQ plotwin_ury 22.0)
          ) ;_ end of IF
          (SET_TILE "plotwin_ury" (RTOS plotwin_ury 2 4))
          (MODE_TILE "file_drv" 0)
          (MODE_TILE "forcedim0" 0)
          (MODE_TILE "force_wcs" 0)
          (MODE_TILE "allayplt" 0)
          (MODE_TILE "etrf_scr" 0)
          (MODE_TILE "forcedim0" 0)
          (MODE_TILE "out_to" 0)
          (MODE_TILE "plttobox" 0)
          (MODE_TILE "ins_fname" 1)
          (MODE_TILE "include_plbl" 0)
        ) ;_ end of progn
      ) ;_ end of if
      (IF prestr
        (SET_TILE "pltpre" prestr)
      ) ;_ end of if
      (IF pststr
        (SET_TILE "pltpst" pststr)
      ) ;_ end of if
      (IF force_wcs
        nil
        (SETQ force_wcs "0")
      ) ;_ end of IF
      (SET_TILE "force_wcs" force_wcs)
      (IF allayplt
        nil
        (SETQ allayplt "0")
      ) ;_ end of IF
      (SET_TILE "allayplt" allayplt)
      (IF etrf_scr
        nil
        (SETQ etrf_scr "0")
      ) ;_ end of IF
      (SET_TILE "etrf_scr" etrf_scr)
      (IF forcedim0
        nil
        (SETQ forcedim0 "0")
      ) ;_ end of IF
      (SET_TILE "forcedim0" forcedim0)
;;;      (IF savdwg
;;;        (SET_TILE "savdwg" savdwg)
      (SET_TILE "savdwg" "1")
;;;      ) ;_ end of if
      (IF qitend
        (SET_TILE "qitend" qitend)
      ) ;_ end of if
      (IF out_to
        nil
        (SETQ out_to "Fileout")
      ) ;_ end of IF
      (SET_TILE "out_to" out_to)
      (setout)
      (SETQ curdwg (GETVAR "dwgname"))
      (SETQ curpfx (GETVAR "dwgprefix"))
      (IF debug_doslib
        (PRINC "\nDOS_5 ")
      ) ;_ end of IF
      (SETQ spltpat (DOS_SPLITPATH curdwg))
      (IF debug_doslib
        (PRINC "\nDOS_5 ")
      ) ;_ end of IF
      (IF dos_win
        (IF (EQ (dos_win) "WINNT")
          (SETQ nt_true T)
          (SETQ nt_true nil)
        ) ;_ end of if
        (IF DOS_VER
          (IF (EQ (DOS_VER) "Windows NT Workstation 4.0")
            (SETQ nt_true T)
            (SETQ nt_true nil)
          ) ;_ end of if
          (SETQ nt_true nil)
        ) ;_ end of if
      ) ;_ end of if
      (IF nt_true
        (IF (= (LENGTH spltpat) 4)
          (SETQ curdwg (STRCAT (NTH 2 spltpat) (NTH 3 spltpat)))
        ) ;_ end of if
        (IF (EQ (SUBSTR curdwg 1 2) (SUBSTR curpfx 1 2))
          (SETQ curdwg
                 (STRCAT
                   (SUBSTR curdwg (1+ (STRLEN curpfx)))
                   (IF (WCMATCH (STRCASE curdwg) "*.DWG")
                     ""
                     ".DWG"
                   ) ;_ end of IF
                 ) ;_ end of STRCAT
          ) ;_ end of SETQ
          (SETQ curdwg (STRCAT
                         curdwg
                         (IF (WCMATCH (STRCASE curdwg) "*.DWG")
                           ""
                           ".DWG"
                         ) ;_ end of IF
                       ) ;_ end of STRCAT
          ) ;_ end of SETQ
        ) ;_ end of if
      ) ;_ end of if
      (IF (OR (EQ curdwg "UNNAMED.DWG") (EQ curdwg "DRAWING.DWG"))
        nil
        (IF (MEMBER curdwg d_flst)
          (SET_TILE "fedit" curdwg)
        ) ;_ end of if
      ) ;_ end of if
      (IF (AND page1 (MEMBER page1 psl_lst))
        (PROGN
          (SETQ pagedx (ITOA (- (LENGTH psl_lst)
                                (LENGTH (MEMBER page1 psl_lst))
                             ) ;_ end of -
                       ) ;_ end of ITOA
          ) ;_ end of SETQ
          (SET_TILE "pages" pagedx)
        ) ;_ end of PROGN
      ) ;_ end of IF
      (IF fulldpi
        nil
        (SETQ fulldpi "0")
      ) ;_ end of IF
      (IF halfdpi
        nil
        (SETQ halfdpi "1")
      ) ;_ end of IF
      (IF (>= (ATOI halfdpi) (ATOI fulldpi))
        (SET_TILE "fixdpi" halfdpi)
        (SET_TILE "fixdpi" fulldpi)
      ) ;_ end of IF
      (IF dontfixdpi
        nil
        (SETQ dontfixdpi "0")
      ) ;_ end of IF
      (SET_TILE "dontfixdpi" dontfixdpi)
      (fixdpimode)
      (IF updttl_chk
        nil
        (SETQ updttl_chk "0")
      ) ;_ end of IF
      (SET_TILE "updttl_chk" updttl_chk)
      (show_updttl_chk)
      (MODE_TILE "fedit" 2)
      (ACTION_TILE "jst_scr" "(setfdrv)(setscr)")
      (ACTION_TILE
        "etrf_scr"
        "(SETQ etrf_scr (get_tile \"etrf_scr\"))"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE "dirs" "(setq caldir $reason)(dirlst)")
      (ACTION_TILE
        "fedit"
        "(setq pltndx NIL)(if(eq $reason 2)(SET_TILE \"files\" \"\")(progn(bplot2k_key_search nil)(chkfil pltlst)))"
                                        ;Was (bplot2k_key_search out_filn)
      ) ;_ end of action_tile
      (ACTION_TILE "fixdpi" "(setq halfdpi (get_tile\"fixdpi\"))")
      (ACTION_TILE
        "dontfixdpi"
        "(setq dontfixdpi (get_tile\"dontfixdpi\"))(fixdpimode)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "files"
        "(setq pltndx (get_tile \"files\"))(chkfil pltlst)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "sortdate"
        "(setq sortdate (get_tile\"sortdate\"))(sortfiles)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "selall"
        "(set_tile\"fedit\"\"*\")(bplot2k_key_search out_filn)(chkfil pltlst)"
      ) ;_ end of action_tile
      (ACTION_TILE
        "clear"
        "(setq pltlst nil pltndx nil)(SET_TILE \"files\" \"\")(MODE_TILE \"files\" 2)(MODE_TILE \"fedit\" 2)(setq selndi \"\")(setrem pltlst)(set_tile\"selall\"\"\")(set_tile\"error\"\"\")"
                                        ;did include (set_tile\"fedit\"\"\")
      ) ;_ end of action_tile
      (ACTION_TILE
        "plotrs"
        "(setq pltrdx (get_tile\"plotrs\"))(setplt))"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "pages"
        "(setq pagedx (get_tile\"pages\"))(sel_page)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "frepages"
        "(setq frepages (get_tile\"frepages\"))"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "file_drv"
        "(SETQ fildrv(NTH(READ(GET_TILE\"file_drv\"))avdrvs))(setfdrv)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE "plotwindow" "(setwindow)")
      (ACTION_TILE "plotwin_llx" "(setwin \"llx\")")
      (ACTION_TILE "plotwin_lly" "(setwin \"lly\")")
      (ACTION_TILE "plotwin_urx" "(setwin \"urx\")")
      (ACTION_TILE "plotwin_ury" "(setwin \"ury\")")
      (ACTION_TILE "force_wcs" "(setforcewcs)")
      (ACTION_TILE "allayplt" "(setallay)")
      (ACTION_TILE "forcedim0" "(setdim0)")
      (ACTION_TILE "include_plbl" "(setq include_plbl $value)")
;;;  (ACTION_TILE "pltscl" "(setscl)")
;;;  (ACTION_TILE "pltare" "(setare)")
;;;  (ACTION_TILE "hidplt" "(sethid)")
      (ACTION_TILE "savdwg" "(setsav)")
      (ACTION_TILE "qitend" "(setqit)")
      (ACTION_TILE "out_to" "(setout)")
      (ACTION_TILE "remove" "(setrem pltlst)")
      (ACTION_TILE "reverse" "(revsel)")
      (ACTION_TILE
        "filsel"
        "(setq selndi (get_tile \"filsel\"))(setone)"
      ) ;_ end of action_tile
      (ACTION_TILE "savelst" "(savepltlst)")
      (ACTION_TILE "restorelst" "(restorepltlst)")
      (ACTION_TILE "indexlst" "(indexpltlst)")
      (ACTION_TILE
        "updttl_chk"
        "(setq updttl_chk(itoa(abs(1-(atoi updttl_chk)))))(show_updttl_chk)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE "upd_titlblks" "(update_titleblocks)")
      (ACTION_TILE
        "renumber_dwgs"
        "(setq prvplst pltlst)(SETQ done_fun '(do_rename))(done_dialog)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "ins_fname"
        "(SETQ ins_fname (GET_TILE \"ins_fname\"))"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE "publish_shtlst_in" "(SETQ done_fun '(get_publish_shtlst))(done_dialog)")
      (ACTION_TILE "publish_shtlst_out" "(setq prvplst pltlst pub_only T)(make_publish_shtlst pltlst)(done_dialog)")
      (ACTION_TILE
        "accept"
        "(pltsup)(setq prvplst pltlst)(dclst pltlst)(done_dialog)"
      ) ;_ end of action_tile
      (ACTION_TILE
        "cancel"
        "(setq prvplst pltlst pltlst nil filst nil)(rstdir)(done_dialog)"
      ) ;_ end of action_tile
      (ACTION_TILE
        "help"
        "(browser_help \"Bplot2K\")"
      ) ;_ end of action_tile
      (dirlst)
      (chkfil pltlst)
      (START_LIST "pages")
      (MAPCAR 'ADD_LIST psl_lst)
      (END_LIST)
      (setpage)
      (pltrlst)
      (IF (AND prvplst (NOT (MEMBER nil (MAPCAR 'FINDFILE prvplst))))
        (PROGN
          (SET_TILE "selnum"
                    (STRCAT (ITOA (LENGTH prvplst))
                            " Drawings selected for plotting:"
                    ) ;_ end of strcat
          ) ;_ end of set_tile
          (SETQ pltlst prvplst)
          (START_LIST "filsel")
          (MAPCAR 'ADD_LIST pltlst)
          (END_LIST)
        ) ;_ end of PROGN
        (PROGN
          (IF prvplst
            (PROGN
              (SETQ prvplst nil
                    pltlst nil
              ) ;_ end of SETQ
              (START_LIST "filsel")
              (END_LIST)
              (ALERT
                (STRCAT
                  "Some files in the previous selection no longer exist\n"
                  "under the same name and path included in the selection!"
                  "\nThey must have been moved, renamed, or deleted."
                  "\nThe previous selection list has been cleared."
                  "\n\n\tPlease create a new selection list") ;_ end of STRCAT
              ) ;_ end of ALERT
            ) ;_ end of PROGN
          ) ;_ end of IF
        ) ;_ end of PROGN
      ) ;_ end of IF
      (START_DIALOG)
      (SETQ errtxt nil)
      (IF debug_doslib
        (PROGN
          (PRINC "\nallayplt = ")
          (PRINC allayplt)
          (PRINC)
        ) ;_ end of PROGN
      ) ;_ end of IF
      (COND
        (pub_only (SETQ pub_only NIL))
        (done_fun
          (COND
            ((EQ done_fun '(do_rename))
              (SETQ done_fun nil)
              (IF pltlst
                (PROGN
                  (IF c:renumdwg
                    nil
                    (LOAD "renumdwg" "\nFile RENUMDWG.LSP not loaded! ")
                  ) ;_ end of IF
                  (c:renumdwg)
                ) ;_ end of PROGN
                (ALERT "No files selected for rename!")
              ) ;_ end of IF
            )
            (T (SETQ done_fun nil)
               (get_publish_shtlst)
            )
          )
        )
        (pltlst
         (bplots2k pltlst plotr page1 fildrv savdwg qitend orgdir out_to
                   forcedim0) ;_ end of bplots2k
        )
        (T
         (PROGN
           (IF pltndx
             (PROGN
               (IF jstscr
                 (PRINC "\nBatch Script Only dialog cancelled. ")
                 (PRINC "\nBatch Plot dialog cancelled. ")
               ) ;_ end of if
               (SETQ pltndx nil)
             ) ;_ end of progn
             (IF jstscr
               (PRINC "\nNo files selected for script only. ")
               (PRINC "\nNo files selected for plotting. ")
             ) ;_ end of if
           ) ;_ end of if
           (rstdir)
         ) ;_ end of PROGN
        )
      ) ;_ end of COND
      (UNLOAD_DIALOG num)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF old_bp2kecho
    (SETVAR "CMDECHO" old_bp2kecho)
  ) ;_ end of IF
  (IF old_bp2kexpert
    (SETVAR "expert" old_bp2kexpert)
  ) ;_ end of IF
  (IF princdebugstrs
    (princdebugstrs
      (LIST "End execution of BPLOT2K function.\n")
    ) ;_ end of princdebugstrs
  ) ;_ end of IF
  (SETQ princprfx
         (COND
           ((AND princprfx (WCMATCH princprfx "`[DEBUG`]   *"))
            (SUBSTR princprfx 1 (- (STRLEN princprfx) 2))
           )
           (debug_princs "[DEBUG]  ")
           (T "")
         ) ;_ end of COND
  ) ;_ end of SETQ
  (PRINC)
;;;  (IF prvplst
    (vl-bb-set 'bb-prvplst prvplst)
;;;  ) ;_ end of IF
;;;  (IF pltlst
    (vl-bb-set 'bb-pltlst pltlst)
;;;  ) ;_ end of IF
;;;  (IF pltndx
    (vl-bb-set 'bb-pltndx pltndx)
;;;  ) ;_ end of IF
  (SETQ *error* old_bp2kerror)
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN get_publish_shtlst ( / )
  (setq adsdfile (getfiled "Import Publish List for Plotting" (GETVAR "dwgprefix") "dsd" 0))
  (IF adsdfile
    (PROGN
      (SETQ opendsd (OPEN adsdfile "r"))
      (IF opendsd
        (PROGN
          (SETQ dsdpltlst NIL
                nonpltlst NIL
          )
          (WHILE (SETQ adsdline (READ-LINE opendsd))
            (IF (WCMATCH adsdline "DWG=*")
              (IF (FINDFILE (SUBSTR adsdline 5))
                (SETQ dsdpltlst (APPEND dsdpltlst (LIST (SUBSTR adsdline 5))))
                (SETQ nonpltlst (APPEND nonpltlst (LIST (SUBSTR adsdline 5))))
              )
            )
          )
          (CLOSE opendsd)
          (IF nonpltlst
            (PROGN
              (PRINC "\nThe following files from the Publish List were not found:\n")
              (FOREACH n nonpltlst
                (PRINC "\n")
                (PRINC n)
                (PRINC)
              )
            )
          )
          (IF dsdpltlst (SETQ pltlst dsdpltlst))
          (c:bplot2k)
        )
      )
    )
  )
  (PRINC)
)
;;;********************************************************************
(DEFUN make_publish_shtlst (filenamelist / )
  (setq pagedx (GET_TILE "pages"))
  (sel_page);setq var page1 (page setup name)
  (setq thedsdfile (getfiled "Save Sheet List for Publish" (STRCAT (GETVAR "dwgprefix") "Plots\\Bplot2K-Sheet-Set-" (dos_cdate "%m%d%y")) "dsd" 1))
  (IF (AND pltlst thedsdfile (SETQ opendsd (OPEN thedsdfile "w")))
    (PROGN
      (WRITE-LINE "[DWF6Version]" opendsd)
      (WRITE-LINE "Ver=1" opendsd)
      (WRITE-LINE "[DWF6MinorVersion]" opendsd)
      (WRITE-LINE "MinorVer=1" opendsd)
      (FOREACH n pltlst
        (SETQ thisfilesplit (DOS_SPLITPATH n))
        (WRITE-LINE (STRCAT "[DWF6Sheet:" (NTH 2 thisfilesplit) "]") opendsd)
        (WRITE-LINE (STRCAT "DWG=" n) opendsd)
        (WRITE-LINE "Layout=Layout1" opendsd)
        (WRITE-LINE (STRCAT "Setup=" page1) opendsd)
        (WRITE-LINE (STRCAT "OriginalSheetPath=" n) opendsd)
        (WRITE-LINE "Has Plot Port=0" opendsd)
        (WRITE-LINE "Has3DDWF=0" opendsd)
      )
      (WRITE-LINE "[Target]" opendsd)
      (WRITE-LINE "Type=1" opendsd)
      (WRITE-LINE (STRCAT "DWF=" (GETVAR "dwgprefix") "Plots\\Publish-Sheet-Set-" (dos_cdate "%m%d%y") ".dwf") opendsd)
      (WRITE-LINE (STRCAT "OUT=" (GETVAR "dwgprefix") "Plots\\") opendsd)
      (WRITE-LINE "PWD=" opendsd)
      (WRITE-LINE "[AutoCAD Block Data]" opendsd)
      (WRITE-LINE "IncludeBlockInfo=0" opendsd)
      (WRITE-LINE "BlockTmplFilePath=" opendsd)
      (WRITE-LINE "[SheetSet Properties]" opendsd)
      (WRITE-LINE "IsSheetSet=FALSE" opendsd)
      (WRITE-LINE "IsHomogeneous=FALSE" opendsd)
      (WRITE-LINE "SheetSet Name=" opendsd)
      (WRITE-LINE "NoOfCopies=1" opendsd)
      (WRITE-LINE "PlotStampOn=FALSE" opendsd)
      (WRITE-LINE "JobID=0" opendsd)
      (WRITE-LINE "SelectionSetName=" opendsd)
      (WRITE-LINE "AcadProfile=AutoCAD" opendsd)
      (WRITE-LINE "CategoryName=" opendsd)
      (WRITE-LINE "LogFilePath=" opendsd)
      (WRITE-LINE "IncludeLayer=FALSE" opendsd)
      (WRITE-LINE "PromptForDwfName=TRUE" opendsd)
      (WRITE-LINE "PwdProtectPublishedDWF=FALSE" opendsd)
      (WRITE-LINE "PromptForPwd=FALSE" opendsd)
      (WRITE-LINE "RepublishingMarkups=FALSE" opendsd)
      (WRITE-LINE "PublishSheetSetMetadata=FALSE" opendsd)
      (WRITE-LINE "PublishSheetMetadata=FALSE" opendsd)
      (WRITE-LINE "3DDWFOptions=0 1" opendsd)
      (CLOSE opendsd)
    )
  )
  (PRINC)
)
;;;********************************************************************
(DEFUN show_updttl_chk ()
  (IF (EQ updttl_chk "1")
    (PROGN
      (SETQ image_x (DIMX_TILE "updttl_chk")
            image_y (DIMY_TILE "updttl_chk")
      ) ;_ end of setq
      (START_IMAGE "updttl_chk")
      (FILL_IMAGE 0 0 image_x image_y -2)
      (SLIDE_IMAGE
        0
        0
        (MAX image_x 1)
        (MAX image_y 1)
        "checkbox.sld"
      ) ;_ end of SLIDE_IMAGE
      (END_IMAGE)
      (do_updates T)
      (MODE_TILE "upd_titlblks" 0)
    ) ;_ end of PROGN
    (PROGN
      (SETQ image_x (DIMX_TILE "updttl_chk")
            image_y (DIMY_TILE "updttl_chk")
      ) ;_ end of setq
      (START_IMAGE "updttl_chk")
      (FILL_IMAGE 0 0 (MAX image_x 1) (MAX image_y 1) -2)
      (END_IMAGE)
      (do_updates nil)
      (MODE_TILE "upd_titlblks" 1)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN update_titleblocks ()
  (NEW_DIALOG "update_title" num)
  (SETQ tblblk     (TBLNEXT "BLOCK" T)
        blknamelst nil
  ) ;_ end of SETQ
  (WHILE tblblk
    (IF (AND
          (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 2) 2)
          (NOT
            (OR
;;;                (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 0) 0)
              (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 4) 4)
              (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 8) 8)
              (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 16) 16)
              (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 32) 32)
              (EQ (BOOLE 1 (CDR (ASSOC 70 tblblk)) 64) 64)
            ) ;_ end of OR
          ) ;_ end of NOT
          (SETQ insexists (SSGET "X" (LIST (ASSOC 2 tblblk) (CONS 66 1))))
        ) ;_ end of AND
      (SETQ blknamelst
             (APPEND blknamelst (LIST (CDR (ASSOC 2 tblblk))))
      ) ;_ end of SETQ
      nil
    ) ;_ end of IF
    (SETQ tblblk (TBLNEXT "BLOCK"))
  ) ;_ end of WHILE
  (START_LIST "block_list")
  (MAPCAR 'ADD_LIST blknamelst)
  (END_LIST)
  (START_LIST "sheet_blklst")
  (MAPCAR 'ADD_LIST blknamelst)
  (END_LIST)
  (toggle_usn)
  (IF (AND block_list_ndx
           blknamelst
           (< (ATOI block_list_ndx) (LENGTH blknamelst))
      ) ;_ end of AND
    (PROGN
      (SET_TILE "block_list" block_list_ndx)
      (SETQ curblk_name (NTH (ATOI block_list_ndx) blknamelst))
      (get_attrib_list curblk_name "tag_list")
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (AND tag_list_ndx
           tag_list
           (< (ATOI tag_list_ndx) (LENGTH tag_list))
      ) ;_ end of AND
    (SET_TILE "tag_list" tag_list_ndx)
  ) ;_ end of IF
  (IF (AND sheet_blklst_ndx
           blknamelst
           (< (ATOI sheet_blklst_ndx) (LENGTH blknamelst))
      ) ;_ end of AND
    (PROGN
      (SET_TILE "sheet_blklst" sheet_blklst_ndx)
      (SETQ shtblk_name (NTH (ATOI sheet_blklst_ndx) blknamelst))
      (get_attrib_list shtblk_name "sheet_taglst")
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (AND sheet_taglst_ndx
           sheet_taglst
           (< (ATOI sheet_taglst_ndx) (LENGTH sheet_taglst))
      ) ;_ end of AND
    (SET_TILE "sheet_taglst" sheet_taglst_ndx)
  ) ;_ end of IF
  (display_updates)
  (IF new_value
    (SET_TILE "new_value" new_value)
  ) ;_ end of IF
  (IF sheet_value
    (SET_TILE "sheet_value" sheet_value)
  ) ;_ end of IF
  (IF sheet_prefix
    (SET_TILE "sheet_prefix" sheet_prefix)
  ) ;_ end of IF
  (IF sht_incr_value
    (SET_TILE "sht_incr_value" sht_incr_value)
  ) ;_ end of IF
  (ACTION_TILE
    "block_list"
    "(SETQ block_list_ndx (get_tile\"block_list\"))(get_attrib_list (NTH (ATOI block_list_ndx) blknamelst)\"tag_list\")"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "tag_list"
    "(SETQ tag_list_ndx (get_tile\"tag_list\"))"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "new_value"
    "(SETQ new_value (get_tile \"new_value\"))"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "sheet_blklst"
    "(SETQ sheet_blklst_ndx (get_tile\"sheet_blklst\"))(get_attrib_list (NTH (ATOI sheet_blklst_ndx) blknamelst)\"sheet_taglst\")"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "sheet_taglst"
    "(SETQ sheet_taglst_ndx (get_tile\"sheet_taglst\"))"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "sheet_value"
    "(SETQ sheet_value (get_tile \"sheet_value\"))"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "sheet_prefix"
    "(SETQ sheet_prefix (get_tile \"sheet_prefix\"))"
  ) ;_ end of ACTION_TILE
;;;      (ACTION_TILE "sht_incr_value" "(SETQ sht_incr_value (get_tile \"sht_incr_value\"))")
  (ACTION_TILE
    "update_sht_no"
    "(SETQ update_sht_no (get_tile \"update_sht_no\"))(toggle_usn)"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE
    "add_to_list"
    "(add_updates_lst)(display_updates)"
  ) ;_ end of ACTION_TILE
  (ACTION_TILE "clear_updates" "(clear_updates)")
  (ACTION_TILE
    "accept"
    "(do_updates T)(done_dialog)"
  ) ;_ end of action_tile
  (ACTION_TILE
    "cancel"
    "(do_updates NIL)(done_dialog)"
  ) ;_ end of action_tile
  (ACTION_TILE
    "help"
    "(browser_help \"Bplot2K\")"
  ) ;_ end of action_tile
  (START_DIALOG)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN do_updates (well /)
  (IF (AND well
           (OR
             updates_lst
             (AND
               (EQ update_sht_no "enable_usn")
               sheet_prefix
               sheet_value
             ) ;_ end of AND
           ) ;_ end of OR
      ) ;_ end of AND
    (PROGN
      (IF update_title
        nil
        (LOAD "update_title" "\nFile UPDATE_TITLE.LSP not loaded! ")
      ) ;_ end of IF
      (IF (AND
            (EQ update_sht_no "enable_usn")
            sheet_prefix
            sheet_value
            blknamelst
            sheet_blklst_ndx
            sheet_taglst_ndx
          ) ;_ end of AND
        (SETQ this_block_name (NTH (ATOI sheet_blklst_ndx) blknamelst)
              this_tag_name   (NTH (ATOI sheet_taglst_ndx) blknamelst)
              sht_number      (ATOI sheet_value)
              sht_incr_value  "1"
              update_list
                              (APPEND
                                (LIST (LIST sheet_prefix nil (ATOI sheet_value)))
                                updates_lst
                                (LIST (LIST this_block_name
                                            this_tag_name
                                            '(STRCAT
                                              sht_prefix
                                              (ITOA (1- (SETQ sht_number (1+ sht_number))))
                                             )
                                      ) ;_ end of LIST
                                ) ;_ end of LIST
                              ) ;_ end of APPEND
        ) ;_ end of SETQ
        (SETQ update_list updates_lst)
      ) ;_ end of IF
    ) ;_ end of PROGN
    (PROGN
      (SETQ update_list nil)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN toggle_usn ()
  (IF update_sht_no
    nil
    (SETQ update_sht_no "disable_usn")
  ) ;_ end of IF
  (IF (EQ update_sht_no "enable_usn")
    (PROGN
      (MODE_TILE "sheet_blklst" 0)
      (MODE_TILE "sheet_taglst" 0)
      (MODE_TILE "sheet_value" 0)
      (MODE_TILE "sheet_prefix" 0)
      (MODE_TILE "sht_incr_value" 0)
      (SET_TILE "update_sht_no" update_sht_no)
    ) ;_ end of PROGN
    (PROGN
      (MODE_TILE "sheet_blklst" 1)
      (MODE_TILE "sheet_taglst" 1)
      (MODE_TILE "sheet_value" 1)
      (MODE_TILE "sheet_prefix" 1)
      (MODE_TILE "sht_incr_value" 1)
      (SET_TILE "update_sht_no" update_sht_no)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN add_updates_lst ()
  (IF (AND
        block_list_ndx
        blknamelst
        (SETQ this_block_name (NTH (ATOI block_list_ndx) blknamelst))
        tag_list_ndx
        tag_list
        (SETQ this_tag_name (NTH (ATOI tag_list_ndx) tag_list))
        new_value
      ) ;_ end of AND
    (SETQ updates_lst (APPEND
                        updates_lst
                        (LIST (LIST this_block_name this_tag_name new_value)
                        ) ;_ end of LIST
                      ) ;_ end of APPEND
          updates_txt (APPEND updates_txt
                              (LIST (STRCAT "(\""
                                            this_block_name
                                            "\" \""
                                            this_tag_name
                                            "\" \""
                                            new_value
                                            "\")"
                                           ) ;_ end of STRCAT
                              ) ;_ end of LIST
                      ) ;_ end of APPEND
    ) ;_ end of SETQ
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN clear_updates ()
  (SETQ updates_lst nil
        updates_txt nil
  ) ;_ end of setq
  (display_updates)
;;;  (SETQ cnt 1)
;;;  (REPEAT 12
;;;          (PROGN
;;;            (SET_TILE (STRCAT "script_" (IF (< cnt 10) "0" "") (ITOA cnt)) "")
;;;            (SETQ cnt (1+ cnt))
;;;          )
;;;  )
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN display_updates ()
  (IF updates_txt
    (PROGN
;;;          (IF (<=(LENGTH updates_txt)10)
;;;            (SETQ updates_display updates_txt)
;;;            (SETQ updates_display (REVERSE (MEMBER (NTH (-(LENGTH updates_txt)10) (REVERSE updates_txt))(REVERSE updates_txt))))
;;;          )
;;;          (SETQ cnt 1)
;;;          (FOREACH n updates_display
;;;            (SET_TILE (STRCAT "script_" (IF (< cnt 10) "0" "") (ITOA cnt)) n)
;;;            (SETQ cnt (1+ cnt))
;;;          )
      (START_LIST "attupd_list")
      (MAPCAR 'ADD_LIST updates_txt)
      (END_LIST)
    ) ;_ end of PROGN
    (PROGN
      (START_LIST "attupd_list")
      (END_LIST)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN get_attrib_list (blockname list_name /)
  (SETQ attrib_list nil)
  (SETQ insertis (SSGET "X" (LIST (CONS 2 blockname) (CONS 66 1))))
  (IF insertis
    (PROGN
      (SETQ this_ent (ENTGET (SSNAME insertis 0)))
      (WHILE (/= (CDR (ASSOC 0 this_ent)) "SEQEND")
        (IF (EQ (CDR (ASSOC 0 this_ent)) "ATTRIB")
          (SETQ attrib_list
                 (APPEND attrib_list
                         (LIST (CDR (ASSOC 2 this_ent)))
                 ) ;_ end of APPEND
          ) ;_ end of SETQ
        ) ;_ end of IF
        (SETQ this_ent (ENTGET (ENTNEXT (CDR (ASSOC -1 this_ent)))))
      ) ;_ end of WHILE
      (IF attrib_list
        (PROGN
          (START_LIST list_name)
          (MAPCAR 'ADD_LIST attrib_list)
          (END_LIST)
          (COND
            ((EQ list_name "tag_list")
             (SETQ tag_list attrib_list)
            )
            ((EQ list_name "sheet_taglst")
             (SETQ sheet_taglst attrib_list)
            )
          ) ;_ end of COND
        ) ;_ end of PROGN
        (PROGN
          (START_LIST list_name)
          (MAPCAR 'ADD_LIST (LIST "<none>"))
          (END_LIST)
          (COND
            ((EQ list_name "tag_list")
             (SETQ tag_list nil)
            )
            ((EQ list_name "sheet_taglst")
             (SETQ sheet_taglst nil)
            )
          ) ;_ end of COND
        ) ;_ end of PROGN
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN sortfiles ()
  (IF (AND d_flst DOS_FILE (DOS_FILE (CAR d_flst)))
    (IF (EQ sortdate "1")
      (PROGN
        (SETQ datesorted_flst
               (REVERSE
                 (ACAD_STRLSORT
                   (MAPCAR '(LAMBDA (x)
                              (IF (EQ (TYPE (NTH 2 x)) 'str)
                                (STRCAT (SUBSTR (NTH 2 x) 7 4)
                                        (SUBSTR (NTH 2 x) 4 2)
                                        (SUBSTR (NTH 2 x) 1 2)
                                        (NTH 0 x)
                                ) ;_ end of strcat
                                (STRCAT (SUBSTR (RTOS (NTH 2 x) 2 8) 1 4)
                                        (SUBSTR (RTOS (NTH 2 x) 2 8) 5 2)
                                        (SUBSTR (RTOS (NTH 2 x) 2 8) 8 2)
                                        (NTH 0 x)
                                ) ;_ end of strcat
                              ) ;_ end of IF
                            ) ;_ end of lambda
                           (MAPCAR 'DOS_FILE d_flst)
                   ) ;_ end of mapcar
                 ) ;_ end of acad_strlsort
               ) ;_ end of reverse
        ) ;_ end of setq
        (SETQ filst (MAPCAR '(LAMBDA (x) (SUBSTR x 9)) datesorted_flst))
      ) ;_ end of PROGN
      (SETQ filst (ACAD_STRLSORT d_flst))
    ) ;_ end of IF
    (IF d_flst
      (SETQ filst (ACAD_STRLSORT d_flst))
    ) ;_ end of IF
  ) ;_ end of IF
  (IF filst
    (PROGN
      (START_LIST "files")
      (MAPCAR 'ADD_LIST filst)
      (END_LIST)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN savepltlst ()
  (SETQ edfil (GETFILED "Save Batch Script Drawing List"
                        (GETVAR "dwgprefix")
                        "bsl"
                        1
              ) ;_ end of getfiled
  ) ;_ end of setq
  (IF edfil
    (PROGN
      (SETQ opedfil (OPEN edfil "w"))
      (PRIN1 pltlst opedfil)
      (CLOSE opedfil)
    ) ;_ end of progn
  ) ;_ end of if
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN restorepltlst ()
  (SETQ edfil (GETFILED "Restore Batch Script Drawing List"
                        (GETVAR "dwgprefix")
                        "bsl"
                        8
              ) ;_ end of getfiled
  ) ;_ end of setq
  (IF edfil
    (PROGN
      (SETQ opedfil (OPEN edfil "r"))
      (SETQ pltlst (READ (READ-LINE opedfil)))
      (CLOSE opedfil)
      (SETQ nfpltlst nil)
      (FOREACH n pltlst
        (IF (FINDFILE n)
          nil
          (SETQ nfpltlst (APPEND nfpltlst (LIST n)))
        ) ;_ end of if
      ) ;_ end of foreach
;;;      (princ "\npltlst = ")
;;;      (princ (length pltlst))
;;;      (princ "\nnfpltlst = ")
;;;      (princ (length nfpltlst))
;;;      (princ)
      (IF nfpltlst
        (PROGN
          (IF (EQ (LENGTH pltlst) (LENGTH nfpltlst))
            (PROGN
              (SET_TILE "error"
                        "None of the specified files can be found!"
              ) ;_ end of SET_TILE
              (PRINC
                "\nNone of the specified files can be found.\nMake sure they exist on the specified path before running the script."
              ) ;_ end of PRINC
            ) ;_ end of PROGN
            (PROGN
              (SET_TILE "error"
                        "Some of the specified files cannot be found!"
              ) ;_ end of SET_TILE
              (PRINC
                "\nSome of the specified files cannot be found.\nMake sure they exist on the specified path before running the script."
              ) ;_ end of PRINC
            ) ;_ end of PROGN
          ) ;_ end of IF
          (PRINC "\n\n\tThe following files cannot be found:\n")
          (FOREACH n nfpltlst
            (PRINC "\n")
            (PRINC n)
          ) ;_ end of foreach
          (PRINC "\n")
          (PRINC)
        ) ;_ end of PROGN
      ) ;_ end of if
      (SET_TILE "selnum"
                (STRCAT (ITOA (LENGTH pltlst))
                        (IF jstscr
                          " Drawings selected for script only:"
                          " Drawings selected for plotting:"
                        ) ;_ end of IF
                ) ;_ end of strcat
      ) ;_ end of set_tile
      (START_LIST "filsel")
      (MAPCAR 'ADD_LIST pltlst)
      (END_LIST)
    ) ;_ end of progn
  ) ;_ end of if
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN revsel ()
  (SETQ pltlst (REVERSE pltlst))
  (START_LIST "filsel")
  (MAPCAR 'ADD_LIST pltlst)
  (END_LIST)
  (SETQ prvplst pltlst)
) ;_ end of defun
;;;********************************************************************
(DEFUN drvlst ()
  (IF debug_doslib
    (PRINC "\nDOS_6 ")
  ) ;_ end of IF
  (SETQ avdrvs (DOS_DRIVES))
  (IF debug_doslib
    (PRINC "\nDOS_6 ")
  ) ;_ end of IF
  (IF (MEMBER "A:" avdrvs)
    (SETQ avdrvs (CDR (MEMBER "A:" avdrvs)))
  ) ;_ end of if
  (IF (MEMBER "B:" avdrvs)
    (SETQ avdrvs (CDR (MEMBER "B:" avdrvs)))
  ) ;_ end of if
  (SETQ avdrvs (APPEND (LIST "with DWG") avdrvs))
  (IF avdrvs
    (PROGN
      (START_LIST "file_drv")
      (MAPCAR 'ADD_LIST avdrvs)
      (END_LIST)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN dirlst ()
  (IF (EQ caldir 4)
    (PROGN
      (SETQ chgdir (GET_TILE "dirs"))
      (IF debug_doslib
        (PRINC "\nDOS_7 ")
      ) ;_ end of IF
      (IF (EQ (SUBSTR (NTH (ATOI chgdir) dirs) 1 1) "<")
        (DOS_DRIVE (SUBSTR (NTH (ATOI chgdir) dirs) 2 2))
        (DOS_CHDIR (NTH (ATOI chgdir) dirs))
      ) ;_ end of if
      (SETQ dirstr (STRCAT "Selection path: " (DOS_PWDIR)))
      (IF debug_doslib
        (PRINC "\nDOS_7 ")
      ) ;_ end of IF
      (PRINC "\ndirstr (2) = ")
      (PRINC dirstr)
      (PRINC)
      (SET_TILE "dirtxt" dirstr)
      (IF (/= olddir dirstr)
        (PROGN
          (IF debug_doslib
            (PRINC "\nDOS_8 ")
          ) ;_ end of IF
          (SETQ ddirs (DOS_SUBDIR)
                ddrvs (DOS_DRIVES)
          ) ;_ end of SETQ
          (IF do_setdpi
            (SETQ d_flst (APPEND (DOS_DIR "*.jpg")
                                 (DOS_DIR "*.png")
                                 (DOS_DIR "*.tif")
                         ) ;_ end of APPEND
            ) ;_ end of SETQ
            (SETQ d_flst (DOS_DIR "*.dwg"))
          ) ;_ end of setq
          (IF debug_doslib
            (PRINC "\nDOS_8 ")
          ) ;_ end of IF
          (IF (MEMBER "A:" ddrvs)
            (SETQ ddrvs (CDR (MEMBER "A:" ddrvs)))
          ) ;_ end of if
          (IF (MEMBER "B:" ddrvs)
            (SETQ ddrvs (CDR (MEMBER "B:" ddrvs)))
          ) ;_ end of if
          (IF d_flst
            nil
            (SETQ d_flst (LIST ""))
          ) ;_ end of if
          (IF (EQ (SUBSTR dirstr (1- (STRLEN dirstr))) ":\\")
            (IF ddirs
              nil
              (SETQ ddirs (LIST ""))
            ) ;_ end of if
            (IF ddirs
              (IF (MEMBER ".." ddirs)
                nil
                (SETQ ddirs (APPEND (LIST "..") ddirs))
              ) ;_ end of if
              (SETQ ddirs (LIST ".."))
            ) ;_ end of if
          ) ;_ end of if
        ) ;_ end of progn
      ) ;_ end of if
      (SETQ dirini T)
    ) ;_ end of progn
  ) ;_ end of if
  (IF dirini
    (PROGN
      (SETQ dirs (ACAD_STRLSORT ddirs))
      (SETQ drvs (ACAD_STRLSORT ddrvs))
      (FOREACH n drvs
        (SETQ drvs
               (SUBST (STRCAT "<" n ">")
                      n
                      drvs
               ) ;_ end of subst
        ) ;_ end of setq
      ) ;_ end of foreach
;;;      (IF d_flst
;;;        (PROGN
;;;          (IF (MEMBER curdwg d_flst)
;;;            nil
;;;            (IF (EQ curdwg "UNNAMED.DWG")
;;;              nil
;;;            ) ;_ end of if
;;;          ) ;_ end of if
;;;        ) ;_ end of progn
;;;        (IF (EQ curdwg "UNNAMED.DWG")
;;;          nil
;;;          (SETQ filst (LIST curdwg))
;;;        ) ;_ end of if
;;;      ) ;_ end of if
;;;      (START_LIST "files")
;;;      (MAPCAR 'ADD_LIST filst)
;;;      (END_LIST)
      (sortfiles)
      (SETQ olddir dirstr)
      (SETQ dirs (APPEND dirs drvs))
      (START_LIST "dirs")
      (MAPCAR 'ADD_LIST dirs)
      (END_LIST)
      (SETQ dirini nil)
    ) ;_ end of progn
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN pltrlst ()
  (IF debug_doslib
    (PRINC "\nDOS_9 ")
  ) ;_ end of IF
  (SETQ pwdir_sav (DOS_SPLITPATH (DOS_PWDIR)))
  (IF debug_doslib
    (PRINC "\nDOS_9 ")
  ) ;_ end of IF
  (SETQ acad_locn (FINDFILE "acad.exe"))
  (IF acad_locn
    (PROGN
      (IF debug_doslib
        (PRINC "\nDOS_10 ")
      ) ;_ end of IF
      (SETQ split_locn (DOS_SPLITPATH acad_locn))
      (DOS_DRIVE (CAR split_locn))
      (DOS_CHDIR (CADR split_locn))
      (COND
        ((EQ (SUBSTR (GETVAR "ACADVER") 1 2) "15")
         (SETQ plotrs (DOS_DIR "plotters\\*.pc3"))
        )
        ((>= (ATOI (GETVAR "ACADVER")) 16)
         (SETQ plotrs     (DOS_DIR (STRCAT (GETVAR "roamablerootprefix")
                                           "Plotters\\*.pc3"
                                   ) ;_ end of STRCAT
                          ) ;_ end of DOS_DIR
               plotstyles (DOS_DIR (STRCAT (GETVAR "roamablerootprefix")
                                           "Plot Styles\\*.?tb"
                                   ) ;_ end of STRCAT
                          ) ;_ end of DOS_DIR
         ) ;_ end of SETQ
        )
      ) ;_ end of COND
      (SETQ plt_lst nil)
      (FOREACH n plotrs
        (SETQ plt_lst (APPEND plt_lst
                              (LIST (SUBSTR n 1 (- (STRLEN n) 4)))
                      ) ;_ end of APPEND
        ) ;_ end of SETQ
      ) ;_ end of foreach
      (DOS_DRIVE (SUBSTR (GETVAR "dwgprefix") 1 2))
      (DOS_CHDIR (SUBSTR (GETVAR "dwgprefix") 3))
      (START_LIST "plotrs")
      (MAPCAR 'ADD_LIST plt_lst)
      (END_LIST)
;;;      (START_LIST "pages")
;;;      (MAPCAR 'ADD_LIST psl_lst)
;;;      (END_LIST)
      (setplt)
;;;      (setpage)
      (IF debug_doslib
        (PRINC "\nDOS_10 ")
      ) ;_ end of IF
      (PRINC)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN pltsup ()
  (SETQ prestr (GET_TILE "pltpre"))
  (SETQ pststr (GET_TILE "pltpst"))
  (IF (NOT jstscr)
    (PROGN
      (setplt)
      (IF psl_lst
        (PROGN
          (SETQ page1 (NTH (ATOI (GET_TILE "pages")) psl_lst))
          (IF debug_bplot2k
            (PROGN
              (PRINC "\nPAGE1 (1)= ")
              (PRINC page1)
              (PRINC)
            ) ;_ end of PROGN
          ) ;_ end of IF
        ) ;_ end of PROGN
        (SETQ page1 nil)
      ) ;_ end of IF
      (setfdrv)
      (setsav)
      (setqit)
    ) ;_ end of progn
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN sel_page ()
  (SETQ page1 (NTH (ATOI pagedx) psl_lst))
  (IF plotr
    (PROGN
      (SETQ cnt 1
            len (STRLEN plotr)
      ) ;_ end of setq
      (WHILE (AND (< cnt len) (/= (SUBSTR plotr cnt 1) " "))
        (SETQ cnt (1+ cnt))
      ) ;_ end of while
      (SETQ plt_type (SUBSTR plotr 1 (1- cnt)))
      (IF (WCMATCH (STRCASE page1)(STRCASE (STRCAT "*" plt_type "*")))
        nil
        (PROGN
          (SETQ plt_type_lst nil)
          (COND
            ((WCMATCH (STRCASE page1) "*JPG*")
             (SETQ plt_type "*JPG"
                   imgext "jpg"
                   plot_images T
             ) ;_ end of SETQ
            )
            ((WCMATCH (STRCASE page1) "*TIFF*")
             (SETQ plt_type "TIFF*"
                   imgext "tif"
                   plot_images T
             ) ;_ end of SETQ
            )
            ((WCMATCH (STRCASE page1) "*PNG*")
             (SETQ plt_type "*PNG*"
                   imgext "png"
                   plot_images T
             ) ;_ end of SETQ
            )
            (T plot_images nil)
          ) ;_ end of COND
          (MAPCAR '(LAMBDA (x)
                     (IF (WCMATCH (STRCASE x) (STRCASE plt_type))
                       (SETQ plt_type_lst (APPEND plt_type_lst (LIST x)))
                     ) ;_ end of if
                   ) ;_ end of lambda
                  plt_lst
          ) ;_ end of mapcar
          (SETQ pltrdx nil)
          (setplt)
        ) ;_ end of PROGN
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN setplt ()
  (IF pltrdx
    (SET_TILE "plotrs" pltrdx)
    (PROGN
      (COND
        ((AND plt_type_lst
              (SETQ remlst
                     (MEMBER (NTH 0 plt_type_lst)
                             plt_lst
                     ) ;_ end of MEMBER
              ) ;_ end of SETQ
         ) ;_ end of AND
         (SETQ pltrdx       (ITOA (- (LENGTH plt_lst) (LENGTH remlst)))
               plt_type_lst nil
         ) ;_ end of SETQ
        )
        ((SETQ
           remlst (MEMBER "TIFF Version 6 (CCITT G4 2D Compression)"
                          plt_lst
                  ) ;_ end of MEMBER
         ) ;_ end of SETQ
         (SETQ pltrdx (ITOA (- (LENGTH plt_lst) (LENGTH remlst))))
         (IF (SETQ psl_rem (MEMBER "TIFF 34x22 288dpi PS" psl_lst))
           (SETQ page1 (CAR psl_rem))
         )
        )
        ((SETQ remlst (MEMBER "XEROX" plt_lst))
         (SETQ pltrdx (ITOA (- (LENGTH plt_lst) (LENGTH remlst))))
        )
        ((SETQ remlst (MEMBER "8825" plt_lst))
         (SETQ pltrdx (ITOA (- (LENGTH plt_lst) (LENGTH remlst))))
        )
        (T (SETQ pltrdx "0"))
      ) ;_ end of COND
      (SET_TILE "plotrs" pltrdx)
    ) ;_ end of PROGN
  ) ;_ end of if
  (IF (AND plt_lst
           (EQ (TYPE plt_lst) 'LIST)
           pltrdx
           (EQ (TYPE pltrdx) 'str)
           (EQ (TYPE (READ pltrdx)) 'int)
      ) ;_ end of AND
    (SETQ plotr (NTH (ATOI pltrdx) plt_lst))
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN setfdrv ()
;;;  (IF fdrvndx
  (IF (AND fildrv (MEMBER fildrv avdrvs))
    (PROGN
      (SETQ drvlst_len (LENGTH avdrvs))
      (SETQ fildrv_len (LENGTH (MEMBER fildrv avdrvs)))
      (SETQ fdrvndx (ITOA (- drvlst_len fildrv_len)))
      (SET_TILE "file_drv" fdrvndx)
    ) ;_ end of PROGN
    (PROGN
      (IF (AND (MEMBER "H:" avdrvs)
               (WCMATCH (STRCASE (GETVAR "dwgname")) "DRAWING*.DWG")
          ) ;_ end of AND
        (PROGN
          (SETQ fdrvndx
                 (ITOA (- (LENGTH avdrvs) (LENGTH (MEMBER "H:" avdrvs)))
                 ) ;_ end of ITOA
          ) ;_ end of SETQ
          (SET_TILE "file_drv" fdrvndx)
        ) ;_ end of PROGN
        (IF (MEMBER (SUBSTR (GETVAR "dwgprefix") 1 2) avdrvs)
          (SETQ fdrvndx
                 (ITOA
                   (-
                     (LENGTH avdrvs)
                     (LENGTH (MEMBER (SUBSTR (GETVAR "dwgprefix") 1 2)
                                     avdrvs
                             ) ;_ end of MEMBER
                     ) ;_ end of length
                   ) ;_ end of -
                 ) ;_ end of ITOA
          ) ;_ end of SETQ
        ) ;_ end of IF
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
;;;    (IF (MEMBER (substr(getvar"dwgprefix")1 2) avdrvs)
;;;      (SETQ fdrvndx (ITOA(1-(LENGTH (MEMBER (substr(getvar"dwgprefix")1 2) (REVERSE avdrvs))))))
;;;      (SETQ fdrvndx "0")
;;;    )
;;;  ) ;_ end of if
  (SETQ fildrv (NTH (ATOI fdrvndx) avdrvs))
  (IF fdrvndx
    nil
    (SETQ fdrvndx "1")
  ) ;_ end of IF
  (SET_TILE "file_drv" fdrvndx)
) ;_ end of defun
;;;********************************************************************
(DEFUN setpage ()
;;;  (PRINC "\n\n\t\tpagedx = ")
;;;  (princ pagedx)
;;;  (princ "\n\t\tlength of psl_lst = ")
;;;  (princ (length psl_lst))
;;;  (princ "\n\t\t(CADR split_fp) = ")
;;;  (princ (CADR split_fp))
;;;  (princ)
  (IF debug_doslib
    (PRINC "\nDOS_11 ")
  ) ;_ end of IF
  (SETQ dwg_split_fp (DOS_SPLITPATH (GETVAR "dwgprefix")))
  (IF debug_doslib
    (PRINC "\nDOS_11 ")
  ) ;_ end of IF
  (IF (AND pagedx
           (<= (READ pagedx) (1- (LENGTH psl_lst)))
           (EQ (TYPE pagedx) 'str)
      ) ;_ end of AND
    (SET_TILE "pages" pagedx)
    (COND
      ((AND
         (OR (EQ (SUBSTR (GETVAR "dwgprefix") 4 2) "CL")
             (EQ (SUBSTR (GETVAR "dwgprefix") 4 2) "FB")
         ) ;_ end of OR
         (MEMBER "TIFF 40X28 216dpi PS" (REVERSE psl_lst))
       ) ;_ end of AND
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER "TIFF 40X28 216dpi PS" (REVERSE psl_lst))
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((AND
         (OR (EQ (SUBSTR (GETVAR "dwgprefix") 4 2) "CL")
             (EQ (SUBSTR (GETVAR "dwgprefix") 4 2) "FB")
         ) ;_ end of OR
         (MEMBER "TIFF 40x28 216dpi PS" (REVERSE psl_lst))
       ) ;_ end of AND
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER "TIFF 40x28 216dpi PS" (REVERSE psl_lst))
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((MEMBER (STRCAT "TIFF "
                       (ITOA (FIX (CAR (GETVAR "LIMMAX"))))
                       "X"
                       (ITOA (FIX (CADR (GETVAR "LIMMAX"))))
                       " 288dpi PS"
               ) ;_ end of STRCAT
               (REVERSE psl_lst)
       ) ;_ end of MEMBER
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER
                        (STRCAT "TIFF "
                                (ITOA (FIX (CAR (GETVAR "LIMMAX"))))
                                "X"
                                (ITOA (FIX (CADR (GETVAR "LIMMAX"))))
                                " 288dpi PS"
                        ) ;_ end of STRCAT
                        (REVERSE psl_lst)
                      ) ;_ end of MEMBER
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((MEMBER (STRCAT "TIFF "
                       (ITOA (FIX (CAR (GETVAR "LIMMAX"))))
                       "x"
                       (ITOA (FIX (CADR (GETVAR "LIMMAX"))))
                       " 288dpi PS"
               ) ;_ end of STRCAT
               (REVERSE psl_lst)
       ) ;_ end of MEMBER
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER
                        (STRCAT "TIFF "
                                (ITOA (FIX (CAR (GETVAR "LIMMAX"))))
                                "x"
                                (ITOA (FIX (CADR (GETVAR "LIMMAX"))))
                                " 288dpi PS"
                        ) ;_ end of STRCAT
                        (REVERSE psl_lst)
                      ) ;_ end of MEMBER
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((MEMBER "TIFF 34X22 288dpi PS" (REVERSE psl_lst))
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER "TIFF 34X22 288dpi PS" (REVERSE psl_lst))
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((MEMBER "TIFF 34x22 288dpi PS" (REVERSE psl_lst))
       (SETQ pagedx
              (ITOA
                (1- (LENGTH
                      (MEMBER "TIFF 34x22 288dpi PS" (REVERSE psl_lst))
                    ) ;_ end of LENGTH
                ) ;_ end of 1-
              ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      ((AND dwg_split_fp
            (OR (WCMATCH (CADR dwg_split_fp) "*\\1363\\*")
                (WCMATCH (CADR dwg_split_fp) "\\1363\\*")
                (WCMATCH (CADR dwg_split_fp) "\\1363\\")
            ) ;_ end of OR
       ) ;_ end of AND
       (IF (MEMBER "CMUD 36x24 SHEET" (REVERSE psl_lst))
         (SETQ pagedx
                (ITOA
                  (1- (LENGTH
                        (MEMBER "CMUD 36x24 SHEET" (REVERSE psl_lst))
                      ) ;_ end of LENGTH
                  ) ;_ end of 1-
                ) ;_ end of ITOA
         ) ;_ end of SETQ
         (SETQ pagedx "0")
       ) ;_ end of IF
       (SET_TILE "pages" pagedx)
      )
      ((AND dwg_split_fp
            (OR (WCMATCH (CADR dwg_split_fp) "*\\10302\\*")
                (WCMATCH (CADR dwg_split_fp) "\\10302\\*")
                (WCMATCH (CADR dwg_split_fp) "\\10302\\")
            ) ;_ end of OR
       ) ;_ end of AND
       (IF (MEMBER "CHAR 36x24 SHEET" (REVERSE psl_lst))
         (SETQ pagedx
                (ITOA
                  (1- (LENGTH
                        (MEMBER "CHAR 36x24 SHEET" (REVERSE psl_lst))
                      ) ;_ end of LENGTH
                  ) ;_ end of 1-
                ) ;_ end of ITOA
         ) ;_ end of SETQ
         (SETQ pagedx "0")
       ) ;_ end of IF
       (SET_TILE "pages" pagedx)
      )
      ((MEMBER "HUA 17X11" (REVERSE psl_lst))
       (SETQ
         pagedx (ITOA
                  (1- (LENGTH (MEMBER "HUA 17X11" (REVERSE psl_lst))))
                ) ;_ end of ITOA
       ) ;_ end of SETQ
       (SET_TILE "pages" pagedx)
      )
      (T
       (IF pagedx
         (SET_TILE "pages" pagedx)
         (PROGN
           (SETQ pagedx "0")
           (SET_TILE "pages" pagedx)
         ) ;_ end of PROGN
       ) ;_ end of IF
      )
    ) ;_ end of COND
;;;         (SET_TILE "pages" pagedx))
;;;      (T (SETQ pagedx "4");(ITOA (MIN 4 (1-(LENGTH psl_lst)))))
;;;         (SET_TILE "pages" pagedx))
;;;    ) ;_ end of COND
  ) ;_ end of if
  (IF (< (READ pagedx) 0)
    (SETQ pagedx "0")
  ) ;_ end of IF
  (SETQ page1 (NTH (ATOI pagedx) psl_lst))
  (IF debug_bplot2k
    (PROGN
      (PRINC "\nPAGE1 (2)= ")
      (PRINC page1)
      (PRINC)
    ) ;_ end of PROGN
  ) ;_ end of IF
;;;  (PRINC "\n\n\t\tpagedx = ")
;;;  (princ pagedx)
;;;  (princ "\n\t\tlength of psl_lst = ")
;;;  (princ (length psl_lst))
;;;  (princ "\n\t\t(CADR split_fp) = ")
;;;  (princ (CADR split_fp))
;;;  (princ)
) ;_ end of defun
;;;********************************************************************
(DEFUN setforcewcs ()
  (SETQ force_wcs (GET_TILE "force_wcs"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setallay ()
  (SETQ allayplt (GET_TILE "allayplt"))
  (SETQ prestr (GET_TILE "pltpre"))
  (SETQ pststr (GET_TILE "pltpst"))
  (IF (AND (EQ allayplt "1")
           (OR (AND prestr (/= prestr "")) (AND pststr (/= pststr "")))
      ) ;_ end of AND
    (ALERT
      "\t\t         NOTICE:\nScript(s) must be in an external file that contains only autolisp\nstatements in order to function with batch plots of all layouts."
    ) ;_ end of ALERT
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN setdim0 ()
  (SETQ forcedim0 (GET_TILE "forcedim0"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setscl ()
  (SETQ pltscl (GET_TILE "pltscl"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setare ()
  (SETQ pltare (GET_TILE "pltare"))
) ;_ end of defun
;;;********************************************************************
(DEFUN sethid ()
  (SETQ hidplt (GET_TILE "hidplt"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setsav ()
  (SETQ savdwg (GET_TILE "savdwg"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setqit ()
  (SETQ qitend (GET_TILE "qitend"))
) ;_ end of defun
;;;********************************************************************
(DEFUN setout ()
  (SETQ out_to (GET_TILE "out_to"))
  (IF (OR (EQ out_to "Plotout") jstscr)
    (PROGN
      (MODE_TILE "file_drv" 1)
      (MODE_TILE "fixdpi" 1)
      (MODE_TILE "dontfixdpi" 1)
    ) ;_ end of PROGN
    (PROGN
      (MODE_TILE "file_drv" 0)
      (MODE_TILE "fixdpi" 0)
      (MODE_TILE "dontfixdpi" 0)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN dclst (afilelist / curndx prvndx)
  (SETQ pltlst afilelist)
  (IF debug_doslib
    (PRINC "\nDOS_12 ")
  ) ;_ end of IF
  (IF do_setdpi
    (SETQ pltdir imagedir)
    (SETQ pltdir (DOS_PWDIR))
  ) ;_ end of IF
  (IF debug_doslib
    (PRINC "\nDOS_12 ")
  ) ;_ end of IF
  (IF (AND pltndx filst)
    (PROGN
      (SETQ t_len  (STRLEN pltndx)
            t_cnt  1
            ndxlst nil
            prvndx nil
      ) ;_ end of setq
      (IF (<= t_cnt t_len)
        (SETQ ndxlst (LIST (READ (SUBSTR pltndx 1))))
      ) ;_ end of if
      (WHILE (<= t_cnt t_len)
        (IF (EQ (SUBSTR pltndx
                        (IF (EQ t_cnt 1)
                          1
                          (1- t_cnt)
                        ) ;_ end of if
                        1
                ) ;_ end of substr
                " "
            ) ;_ end of eq
          (PROGN
            (SETQ curndx (READ (SUBSTR pltndx t_cnt)))
            (IF (= curndx prvndx)
              nil
              (SETQ
                ndxlst (APPEND ndxlst
                               (LIST (READ (SUBSTR pltndx t_cnt)))
                       ) ;_ end of append
              ) ;_ end of setq
            ) ;_ end of if
            (SETQ t_cnt (1+ t_cnt))
            (SETQ prvndx curndx)
          ) ;_ end of progn
          (SETQ t_cnt (1+ t_cnt))
        ) ;_ end of if
      ) ;_ end of while
      (FOREACH n ndxlst
        (IF (< n (LENGTH filst))        ; added to fix undetermined error
          (IF pltlst
            (IF (MEMBER (STRCAT pltdir (NTH n filst)) pltlst)
              nil
              (SETQ
                pltlst (APPEND pltlst
                               (LIST (STRCAT pltdir (NTH n filst)))
                       ) ;_ end of append
              ) ;_ end of setq
            ) ;_ end of if
            (IF (MEMBER (STRCAT pltdir (NTH n filst)) pltlst)
              nil
              (SETQ pltlst (LIST (STRCAT pltdir (NTH n filst))))
            ) ;_ end of if
          ) ;_ end of if
        ) ;_ end of IF
      ) ;_ end of foreach
    ) ;_ end of progn
    nil
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN rstdir ()
  (IF debug_doslib
    (PRINC "\nDOS_13 ")
  ) ;_ end of IF
  (IF (EQ (DOS_DRIVE) orgdrv)
    nil
    (DOS_DRIVE orgdrv)
  ) ;_ end of if
  (IF (EQ (DOS_PWDIR) orgdir)
    nil
    (DOS_CHDIR (SUBSTR orgdir 4))
  ) ;_ end of if
  (IF debug_doslib
    (PRINC "\nDOS_13 ")
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN bplot2k_key_search (out_filn / m_indx ksopt)
  (IF out_filn
    (SETQ wc_str out_filn
          out_filn nil
    ) ;_ end of setq
    (SETQ wc_str (STRCASE (GET_TILE "fedit")))
  ) ;_ end of IF
  (IF (> (STRLEN wc_str) 4)
    (IF (/= (STRCASE (SUBSTR wc_str (- (STRLEN wc_str) 3) 4))
            ".DWG"
        ) ;_ end of /=
      (SETQ wc_str (STRCAT wc_str ".DWG"))
      nil
    ) ;_ end of if
  ) ;_ end of if
  (dclst pltlst)
  (FOREACH n d_flst
    (IF pltlst
      (IF (MEMBER (STRCAT pltdir n) pltlst)
        nil
        (IF (WCMATCH (STRCASE n) (STRCASE wc_str))
          (SETQ pltlst (APPEND pltlst (LIST (STRCAT pltdir n))))
        ) ;_ end of if
      ) ;_ end of if
      (IF (WCMATCH (STRCASE n) (STRCASE wc_str))
        (SETQ pltlst (LIST (STRCAT pltdir n)))
      ) ;_ end of if
    ) ;_ end of if
  ) ;_ end of foreach
) ;_ end of defun
;;;********************************************************************
(DEFUN indexpltlst (/)                  ;ndxdwg_lst
  (SETQ thisdwg_lst nil
        ndxdwg_lst  nil
        rawdwg_lst  nil
  ) ;_ end of setq
  (SETQ this_ndx (FINDFILE (STRCAT pltdir "huandx.txt")))
  (SETQ this_openndx (OPEN this_ndx "r"))
  (WHILE (SETQ this_line (READ-LINE this_openndx))
    (SETQ ndxdwg_lst (APPEND ndxdwg_lst (LIST this_line)))
  ) ;_ end of while
  (CLOSE this_openndx)
  (FOREACH n ndxdwg_lst
    (SETQ count 1)
    (WHILE
      (AND (NOT (WCMATCH (SUBSTR n count) "\t*"))
           (< count (STRLEN n))
      ) ;_ end of and
       (SETQ count (1+ count))
    ) ;_ end of while
    (SETQ this_dwgname (SUBSTR n 1 (1- count)))
    (SETQ rawdwg_lst (APPEND rawdwg_lst (LIST this_dwgname)))
    (COND
      ((WCMATCH (STRCASE this_dwgname) "*-LAYOUT#.DWG")
       (SETQ this_dwgname
              (STRCAT (SUBSTR this_dwgname
                              1
                              (- (STRLEN this_dwgname) 12)
                      ) ;_ end of substr
                      ".dwg"
              ) ;_ end of strcat
       ) ;_ end of setq
      )
      ((WCMATCH (STRCASE this_dwgname) "*-LAYOUT##.DWG")
       (SETQ this_dwgname
              (STRCAT (SUBSTR this_dwgname
                              1
                              (- (STRLEN this_dwgname) 13)
                      ) ;_ end of substr
                      ".dwg"
              ) ;_ end of strcat
       ) ;_ end of setq
      )
      ((WCMATCH (STRCASE this_dwgname) "*-LAYOUT###.DWG")
       (SETQ this_dwgname
              (STRCAT (SUBSTR this_dwgname
                              1
                              (- (STRLEN this_dwgname) 14)
                      ) ;_ end of substr
                      ".dwg"
              ) ;_ end of strcat
       ) ;_ end of setq
      )
      (T (SETQ this_dwgname nil))
    ) ;_ end of COND
    (IF this_dwgname
      (PROGN
        (SETQ thisdwg_lst (APPEND thisdwg_lst (LIST this_dwgname)))
      ) ;_ end of PROGN
    ) ;_ end of IF
    (FOREACH n thisdwg_lst
      (IF pltlst
        (IF (MEMBER (STRCAT pltdir n) pltlst)
          nil
          (SETQ pltlst (APPEND pltlst (LIST (STRCAT pltdir n))))
        ) ;_ end of if
        (SETQ pltlst (LIST (STRCAT pltdir n)))
      ) ;_ end of if
    ) ;_ end of foreach
    (chkfil pltlst)
  ) ;_ end of foreach
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN chkfil (afilelist /)
  (SETQ pltlst afilelist)
                                        ;  (SETQ pltndx (GET_TILE "files"))
  (IF pltndx
    (PROGN
      (SETQ fnxlen (STRLEN pltndx))
      (IF (= fnxlen 256)
        (PROGN
          (SET_TILE
            "error"
            "Selection exceeds maximum usable. Unselect some files."
          ) ;_ end of set_tile
        ) ;_ end of progn
        (PROGN
          (SET_TILE "error" "")
        ) ;_ end of progn
      ) ;_ end of if
    ) ;_ end of PROGN
  ) ;_ end of IF
  (dclst pltlst)
  (IF pltlst
    (PROGN
      (SETQ fsslen (LENGTH pltlst))
      (SET_TILE "selnum"
                (STRCAT (ITOA fsslen)
                        (IF jstscr
                          " Drawings selected for script only:"
                          " Drawings selected for plotting:"
                        ) ;_ end of if
                ) ;_ end of strcat
      ) ;_ end of set_tile
      (START_LIST "filsel")
      (MAPCAR 'ADD_LIST pltlst)
      (END_LIST)
    ) ;_ end of progn
    (PROGN
      (SET_TILE "selnum"
                (IF jstscr
                  "0 Drawings selected for script only:"
                  "0 Drawings selected for plotting:"
                ) ;_ end of if
      ) ;_ end of set_tile
      (SET_TILE "choice" "")
      (START_LIST "filsel")
      (MAPCAR 'ADD_LIST (LIST ""))
      (END_LIST)
    ) ;_ end of progn
  ) ;_ end of if
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN setrem (afilelist /)
  (IF afilelist
    (SETQ pltlst afilelist)
  )
  (IF pltlst
    (PROGN
      (IF (AND selndi (/= selndi ""))
        (SETQ selndx (ATOI selndi))
        (SETQ selndx nil)
      ) ;_ end of if
      (IF selndx
        (COND
          ((AND (< selndx (1- (LENGTH pltlst))) (> selndx 0))
           (SETQ pltlst
                  (APPEND
                    (REVERSE
                      (CDR (MEMBER (NTH selndx pltlst) (REVERSE pltlst)))
                    ) ;_ end of reverse
                    (CDR (MEMBER (NTH selndx pltlst) pltlst))
                  ) ;_ end of append
           ) ;_ end of setq
          )
          ((EQ selndx 0)
           (SETQ pltlst (CDR pltlst))
          )
          ((EQ selndx (1- (LENGTH pltlst)))
           (SETQ pltlst (REVERSE (CDR (REVERSE pltlst))))
          )
        ) ;_ end of cond
      ) ;_ end of if
      (SETQ fsslen (LENGTH pltlst))
      (IF (> selndx (1- fsslen))
        (IF (AND (> fsslen 1) (> selndx 0))
          (SETQ selndi (ITOA (1- selndx)))
          (SETQ selndi "0")
        ) ;_ end of if
      ) ;_ end of if
      (SET_TILE "selnum"
                (STRCAT (ITOA fsslen)
                        (IF jstscr
                          " Drawings selected for script only:"
                          " Drawings selected for plotting:"
                        ) ;_ end of if
                ) ;_ end of strcat
      ) ;_ end of set_tile
      (START_LIST "filsel")
      (MAPCAR 'ADD_LIST pltlst)
      (END_LIST)
    ) ;_ end of progn
    (PROGN
      (SET_TILE "selnum"
                (IF jstscr
                  "0 Drawings selected for script only:"
                  "0 Drawings selected for plotting:"
                ) ;_ end of if
      ) ;_ end of set_tile
      (START_LIST "filsel")
      (MAPCAR 'ADD_LIST (LIST ""))
      (END_LIST)
    ) ;_ end of progn
  ) ;_ end of if
  (IF pltlst
    (setone)
  ) ;_ end of if
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN setone ()
  (IF (AND selndi (/= selndi "") pltlst)
    (PROGN
      (SETQ selndx (ATOI selndi))
      (SETQ onefile (NTH selndx pltlst))
      (IF (> (STRLEN onefile) 47)
        (PROGN
          (SETQ
            onetxt
             (STRCAT "..."
                     (SUBSTR onefile (- (STRLEN onefile) 44))
             ) ;_ end of strcat
          ) ;_ end of setq
          (IF (NOT (WCMATCH onetxt "*\\*"))
            (SETQ onetxt onefile)
            (PROGN
              (WHILE (/= (SUBSTR onetxt 1 1) "\\")
                (SETQ onetxt (SUBSTR onetxt 2))
              ) ;_ end of while
              (SETQ onetxt (STRCAT (SUBSTR onefile 1 3) "..." onetxt))
            ) ;_ end of PROGN
          ) ;_ end of IF
          (SET_TILE "choice" onetxt)
        ) ;_ end of progn
        (SET_TILE "choice" "")
      ) ;_ end of if
      (SET_TILE "filsel" selndi)
    ) ;_ end of progn
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN setwindow ()
  (SETQ plotwindow (GET_TILE "plotwindow"))
  (IF (OR (NOT plotwindow) (WCMATCH plotwindow "0") jstscr)
    (PROGN
      (MODE_TILE "plotwin_llx" 1)
      (MODE_TILE "plotwin_lly" 1)
      (MODE_TILE "plotwin_urx" 1)
      (MODE_TILE "plotwin_ury" 1)
    ) ;_ end of PROGN
    (PROGN
      (MODE_TILE "plotwin_llx" 0)
      (MODE_TILE "plotwin_lly" 0)
      (MODE_TILE "plotwin_urx" 0)
      (MODE_TILE "plotwin_ury" 0)
    ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN setwin (cooref /)
  (COND
    ((WCMATCH cooref "llx")
     (IF (OR
           (EQ (TYPE (READ (GET_TILE "plotwin_llx"))) 'real)
           (EQ (TYPE (READ (GET_TILE "plotwin_llx"))) 'int)
         ) ;_ end of or
       (SETQ plotwin_llx (READ (GET_TILE "plotwin_llx")))
       (PROGN
         (SET_TILE "error" "Enter a Real number or Integer value")
         (SET_TILE "plotwin_llx" "")
       ) ;_ end of progn
     ) ;_ end of if
    )
    ((WCMATCH cooref "lly")
     (IF (OR
           (EQ (TYPE (READ (GET_TILE "plotwin_lly"))) 'real)
           (EQ (TYPE (READ (GET_TILE "plotwin_lly"))) 'int)
         ) ;_ end of or
       (SETQ plotwin_lly (READ (GET_TILE "plotwin_lly")))
       (PROGN
         (SET_TILE "error" "Enter a Real number or Integer value")
         (SET_TILE "plotwin_lly" "")
       ) ;_ end of progn
     ) ;_ end of if
    )
    ((WCMATCH cooref "urx")
     (IF (OR
           (EQ (TYPE (READ (GET_TILE "plotwin_urx"))) 'real)
           (EQ (TYPE (READ (GET_TILE "plotwin_urx"))) 'int)
         ) ;_ end of or
       (SETQ plotwin_urx (READ (GET_TILE "plotwin_urx")))
       (PROGN
         (SET_TILE "error" "Enter a Real number or Integer value")
         (SET_TILE "plotwin_urx" "")
       ) ;_ end of progn
     ) ;_ end of if
    )
    ((WCMATCH cooref "ury")
     (IF (OR
           (EQ (TYPE (READ (GET_TILE "plotwin_ury"))) 'real)
           (EQ (TYPE (READ (GET_TILE "plotwin_ury"))) 'int)
         ) ;_ end of or
       (SETQ plotwin_ury (READ (GET_TILE "plotwin_ury")))
       (PROGN
         (SET_TILE "error" "Enter a Real number or Integer value")
         (SET_TILE "plotwin_ury" "")
       ) ;_ end of progn
     ) ;_ end of if
    )
  ) ;_ end of cond
) ;_ end of defun
;;;********************************************************************
(DEFUN setscr ()
  (IF jstscr                            ;(eq (get_tile "jst_scr") 0)
    (PROGN ;NOTE: THIS FUNCTION TOGGLES THE SETTINGS THEREFORE WHEN (EQ jstscr T)
           ;	  jstscr IS SET TO NIL AND THE DISPLAY IS SET ACCORDINGLY
      (SETQ jstscr nil)
      (SET_TILE "files" "")
      (IF pltlst
        (SETQ fsslen (LENGTH pltlst))
        (SETQ fsslen 0)
      ) ;_ end of if
      (SET_TILE "selnum"
                (STRCAT (ITOA fsslen)
                        " Drawings selected for plotting:"
                ) ;_ end of strcat
      ) ;_ end of set_tile
;;;      (SETQ ins_fname (GET_TILE "ins_fname"))
      (MODE_TILE "ins_fname" 1)
      (MODE_TILE "plotrs" 0)
      (MODE_TILE "pages" 0)
      (MODE_TILE "frepages" 0)
      (MODE_TILE "plotwindow" 0)
      (setwindow)
      (IF (EQ (GET_TILE "Plotout") "1")
        (PROGN
          (MODE_TILE "fixdpi" 1)
          (MODE_TILE "dontfixdpi" 1)
        )
        (PROGN
          (MODE_TILE "fixdpi" 0)
          (MODE_TILE "dontfixdpi" 0)
        )
      )
      (IF (OR (EQ out_to "Plotout") jstscr)
        (MODE_TILE "file_drv" 1)
        (MODE_TILE "file_drv" 0)
      ) ;_ end of IF
      (MODE_TILE "force_wcs" 0)
      (MODE_TILE "allayplt" 0)
      (MODE_TILE "out_to" 0)
      (MODE_TILE "include_plbl" 0)
      (SET_TILE "Preplot" "Preplot:")
      (SET_TILE "Postplot" "Postplot:")
    ) ;_ end of progn
    (PROGN
      (SETQ jstscr T)
      (SET_TILE "files" "")
      (IF pltlst
        (SETQ fsslen (LENGTH pltlst))
        (SETQ fsslen 0)
      ) ;_ end of if
      (SET_TILE "selnum"
                (STRCAT (ITOA fsslen)
                        " Drawings selected for script only:"
                ) ;_ end of strcat
      ) ;_ end of set_tile
;;;      (SETQ ins_fname (GET_TILE "ins_fname"))
      (MODE_TILE "ins_fname" 0)
      (MODE_TILE "plotrs" 1)
      (MODE_TILE "pages" 1)
      (MODE_TILE "frepages" 1)
      (MODE_TILE "plotwindow" 1)
      (setwindow)
      (MODE_TILE "fixdpi" 1)
      (MODE_TILE "dontfixdpi" 1)
      (MODE_TILE "file_drv" 1)
      (MODE_TILE "force_wcs" 0)
      (MODE_TILE "allayplt" 0)
      (MODE_TILE "out_to" 1)
      (MODE_TILE "include_plbl" 1)
;;;      (SET_TILE "Preplot" "Pre-name:")
;;;      (SET_TILE "Postplot" "Post-name:")
    ) ;_ end of progn
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN loadpages (/ pageanswers)
  (SETQ pages_old_expert (GETVAR "EXPERT"))
  (SETVAR "EXPERT" 5)
  (IF (SETQ pagefil (FINDFILE "pagesetup.lst"))
                                        ;Only page setups in this file AND in PAGESETUP.DWT are available
    (PROGN                              ;Add setups to PAGESETUP.LST AND PAGESETUPS.DWT to customize your setups
      (SETQ openpage (OPEN pagefil "r"))
      (SETQ setupslst nil)
      (WHILE
        (SETQ readpage (READ-LINE openpage))
         (IF (/= readpage "")
           (SETQ setupslst (APPEND setupslst (LIST readpage)))
         ) ;_ end of IF
      ) ;_ end of WHILE
      (CLOSE openpage)
    ) ;_ end of PROGN
    (PRINC "\nFile PAGESETUP.LST not found! ")
  ) ;_ end of IF
  (IF (AND
        (IF (<(ATOI(SUBSTR(GETVAR "ACADVER")1 2))17)
          (FINDFILE "pagesetup16.dwt")
          (FINDFILE "pagesetup.dwt")
        )
        setupslst
      )
    (PROGN
      (SETQ alert_str "")
      (FOREACH n setupslst
        (SETQ alert_str (STRCAT alert_str n "\n"))
        (IF (AND (getpages n)(OR (NOT frepages)(WCMATCH frepages "0")))
          (IF debug_bplot2k
            (PROGN
              (PRINC (STRCAT "\nPage setup " n " already loaded! "))
              (PRINC)
            ) ;_ end of PROGN
          ) ;_ end of IF
          (PROGN
 ;;;            (PRINC (STRCAT "\nLoading page setup " n ".\n"))
 ;;;            (PRINC)
            (SETVAR "CMDECHO" 0)
            (IF (<(ATOI(SUBSTR(GETVAR "ACADVER")1 2))17)
              (COMMAND "-psetupin" (FINDFILE "pagesetup16.dwt") n)
              (COMMAND "-psetupin" (FINDFILE "pagesetup.dwt") n)
            )
            (COMMAND nil "'resume")
            (IF old_bp2kecho
              (SETVAR "CMDECHO" old_bp2kecho)
            ) ;_ end of IF
          ) ;_ end of PROGN
        ) ;_ end of IF
      ) ;_ end of FOREACH
;;;      (SETQ alert_str
;;;             (STRCAT
;;;               "Currently available page setups:\n\n"
;;;               alert_str
;;;               "\n\nAdd/Edit page setups in template PAGESETUP.DWT\n\t\tAND\nAdd/Edit identical page setup names in text file PAGESETUP.LST"
;;;             ) ;_ end of STRCAT
;;;      ) ;_ end of SETQ
;;;      (IF debug_doslib
;;;        (PRINC "\nDOS_14 ")
;;;      ) ;_ end of IF
;;;      (IF (OR done_psalert (EQ (DOS_USERNAME) "CFrancis"))
;;;        nil
;;;        (ALERT alert_str)
;;;      ) ;_ end of IF
;;;      (IF debug_doslib
;;;        (PRINC "\nDOS_14 ")
;;;      ) ;_ end of IF
;;;      (SETQ done_psalert T)
      (PRINC)
      (SETQ psl_lst setupslst)
    ) ;_ end of progn
    (PROGN
      (SETQ psl_lst (LIST ""))
      (IF (<(ATOI(SUBSTR(GETVAR "ACADVER")1 2))17)
        (PRINC "\nFile PAGESETUP16.DWT not found! ")
        (PRINC "\nFile PAGESETUP.DWT not found! ")
      )
    ) ;_ end of PROGN
  ) ;_ end of if
  (SETVAR "EXPERT" pages_old_expert)
  (PRINC)
) ;_ end of defun
;;;******************************************************************************
;;;Checks to see if a page setup already exists in the drawing.
(DEFUN getpages (name_to_check / pagesetuplst)
  (SETQ laylist (DICTSEARCH (NAMEDOBJDICT) "ACAD_LAYOUT"))
  (SETQ kickopnt (ASSOC 102 laylist))
  (SETQ pltsets (ENTGET (CDADR (MEMBER kickopnt laylist))))
  (SETQ assocnt 0)
  (WHILE (< assocnt (LENGTH pltsets))
    (IF (EQ (CDR (NTH assocnt pltsets)) "ACAD_PLOTSETTINGS")
      (SETQ setupdict (ENTGET (CDR (NTH (1+ assocnt) pltsets))))
    ) ;_ end of if
    (SETQ assocnt (1+ assocnt))
  ) ;_ end of while
  (SETQ assocnt 0)
  (WHILE (< assocnt (LENGTH setupdict))
    (COND ((EQ (CAR (NTH assocnt setupdict)) 3)
           (SETQ pagesetuplst
                  (APPEND pagesetuplst
                          (LIST (STRCASE (CDR (NTH assocnt setupdict))))
                  ) ;_ end of append
           ) ;_ end of setq
          )
    ) ;_ end of cond
    (SETQ assocnt (1+ assocnt))
  ) ;_ end of while
;;;  (PRINC "\npagesetuplst = ")
;;;  (PRINC pagesetuplst)
  (PRINC)
  (IF (MEMBER (STRCASE name_to_check) pagesetuplst)
    T
    nil
  ) ;_ end of if
) ;_ end of defun
;;;********************************************************************
(DEFUN bplots2k_error (msg /)
  (PRINC msg)
  (TERM_DIALOG)
  (IF bplots2k_luprec
    (SETVAR "luprec" bplots2k_luprec)
  ) ;_ end of if
  (IF bplots2k_cmdecho
    (SETVAR "cmdecho" bplots2k_cmdecho)
  ) ;_ end of if
  (IF bplots2k_expert
    (SETVAR "expert" bplots2k_expert)
  ) ;_ end of if
  (IF bplots2k_filedia
    (SETVAR "filedia" bplots2k_filedia)
  ) ;_ end of if
  (IF bplots2k_osmode
    (SETVAR "osmode" bplots2k_osmode)
  ) ;_ end of if
  (GRAPHSCR)
  (IF pre_bplots2k_error
    (SETQ *error* pre_bplots2k_error)
    (SETQ *error* nil)
  ) ;_ end of if
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN bplots2k (pltlst   plotr    page1    fildrv   savdwg   qitend
                 orgdir   out_to   forcedim0         /        fp1
                 str01    str1     str2     str3     count
                )
  (IF debug_doslib
    (PRINC "\nDOS_15 ")
  ) ;_ end of IF
  (IF (WCMATCH (DOS_COMPUTER) "RAL*")
    (SETQ confirm_acct T)
    (SETQ confirm_acct nil)
  ) ;_ end of if
  (IF debug_doslib
    (PRINC "\nDOS_15 ")
  ) ;_ end of IF
  (SETQ pre_bplots2k_error *error*)
  (IF jstscr
    (SETQ goplt nil)
    (SETQ goplt T)
  ) ;_ end of if
  (SETQ bplots2k_luprec (GETVAR "luprec"))
  (SETVAR "luprec" 4)
  (SETQ bplots2k_cmdecho (GETVAR "CMDECHO"))
  (SETVAR "cmdecho" 0)
  (SETQ bplots2k_expert (GETVAR "EXPERT"))
  (SETVAR "expert" 1)
  (SETQ bplots2k_filedia (GETVAR "FILEDIA"))
  (SETVAR "filedia" 0)
  (SETQ bplots2k_osmode (GETVAR "osmode"))
  (SETVAR "osmode" 0)
  (SETQ dwgp (GETVAR "dwgprefix"))
  (SETQ dwgn (GETVAR "dwgname"))
  (SETQ dwgnl (STRLEN dwgn))
  (IF debug_doslib
    (PRINC "\nDOS_16 ")
  ) ;_ end of IF
  (IF DOS_USERNAME
    (SETQ lognm (DOS_USERNAME))
    (IF (GETENV "LGN")
      (SETQ lognm (GETENV "LGN"))
      (SETQ lognm "NN")
    ) ;_ end of if
  ) ;_ end of if
  (IF debug_doslib
    (PRINC "\nDOS_16 ")
  ) ;_ end of IF
  (IF (EQ (SUBSTR dwgn 1 6) (SUBSTR dwgp 1 6))
    (SETQ cdwg dwgn)
    (SETQ cdwg (STRCAT orgdir dwgn))
  ) ;_ end of if
  (SETQ oldscr (FINDFILE (STRCAT pltdir lognm "bplot2k.scr")))
  (IF debug_doslib
    (PRINC "\nDOS_17 ")
  ) ;_ end of IF
  (IF oldscr
    (DOS_DELETE oldscr)
  ) ;_ end of if
  (SETQ oldbat (FINDFILE (STRCAT pltdir lognm "ImageDPI.bat")))
  (IF oldbat
    (DOS_DELETE oldbat)
  ) ;_ end of if
  (IF debug_doslib
    (PRINC "\nDOS_17 ")
  ) ;_ end of IF
  (IF (= savdwg "1")
    (SETQ svqt "Yes")
    (SETQ svqt "No")
  ) ;_ end of if
  (IF (= qitend "1")
    (SETQ qtdn "Yes")
    (SETQ qtdn "no")
  ) ;_ end of if
  (IF (AND (WCMATCH plotwindow "1")
           (NOT jstscr)
           plotwin_llx
           plotwin_lly
           plotwin_urx
           plotwin_ury
      ) ;_ end of AND
    (SETQ custom-window-llcor
           (STRCAT (RTOS plotwin_llx 2 3)
                   ","
                   (RTOS plotwin_lly 2 3)
           ) ;_ end of STRCAT
          custom-window-urcor
           (STRCAT (RTOS plotwin_urx 2 3)
                   ","
                   (RTOS plotwin_ury 2 3)
           ) ;_ end of STRCAT
    ) ;_ end of SETQ
  ) ;_ end of IF
;;;First line written if just a script, Second line written if a plot script
;;;  (SETQ str0 ".OPEN")
;;;  (SETQ str01 "(if(eq(getvar\"dbmod\")0)(princ)(command \"Y\"))")
  (IF (= include_plbl "1")
    (SETQ str1
           (STRCAT                      ;"(setq ftscl \""
             "(setq pltout_fn NIL)(if c:plbl nil (load\"plbl\"))(if c:plbl (c:plbl))"
           ) ;_ end of strcat
    ) ;_ end of setq
    (SETQ str1
           (STRCAT                      ;"(setq ftscl \""
             "(setq pltout_fn NIL)"
           ) ;_ end of strcat
    ) ;_ end of setq
  ) ;_ end of IF
  (IF (> (STRLEN (STRCAT pltdir lognm "BPLOT2K.SCR")) 126)
    (PROGN
      (IF debug_doslib
        (PRINC "\nDOS_18 ")
      ) ;_ end of IF
      (SETQ
        scr_fname (STRCAT (DOS_SHORTPATH pltdir) lognm "BPLOT2K.SCR")
      ) ;_ end of SETQ
      (IF debug_doslib
        (PRINC "\nDOS_18 ")
      ) ;_ end of IF
    ) ;_ end of PROGN
    (SETQ scr_fname (STRCAT pltdir lognm "BPLOT2K.SCR"))
  ) ;_ end of IF
  (IF (> (STRLEN (STRCAT pltdir lognm "ImageDPI.BAT")) 126)
    (SETQ
      bat_fname (STRCAT (DOS_SHORTPATH pltdir) lognm "ImageDPI.BAT")
    ) ;_ end of SETQ
    (SETQ bat_fname (STRCAT pltdir lognm "ImageDPI.BAT"))
  ) ;_ end of IF
  (SETQ bf1 (OPEN bat_fname "w"))
  (SETQ fp1 (OPEN scr_fname "w"))
  (IF job_number
    nil
    (PROGN
      (IF debug_doslib
        (PRINC "\nDOS_19 ")
      ) ;_ end of IF
      (SETQ subdirlst (DOS_SUBDIR))
      (DOS_CHDIR "..")
      (IF (MEMBER (DOS_SUBDIR) subdirlst)
        nil
        (SETQ subdirlst (APPEND subdirlst (DOS_SUBDIR)))
      ) ;_ end of IF
      (DOS_CHDIR "..")
      (IF (MEMBER (DOS_SUBDIR) subdirlst)
        nil
        (SETQ subdirlst (APPEND subdirlst (DOS_SUBDIR)))
      ) ;_ end of IF
      (DOS_CHDIR "..")
      (IF (MEMBER (DOS_SUBDIR) subdirlst)
        nil
        (SETQ subdirlst (APPEND subdirlst (DOS_SUBDIR)))
      ) ;_ end of IF
      (DOS_CHDIR pltdir)
      (IF debug_doslib
        (PRINC "\nDOS_19 ")
      ) ;_ end of IF
      (FOREACH n subdirlst
        (IF (AND (WCMATCH pltdir (STRCAT "*\\" n "\\*"))
                 (NOT (WCMATCH pltdir (STRCAT "*:\\" n "\\*")))
            ) ;_ end of AND
          (COND
            ((AND (EQ (STRLEN n) 5) (EQ (TYPE (READ n)) 'int))
             (SETQ job_number (READ n)
                   subtsk#    (IF subtsk#
                                subtsk#
                                0.1
                              ) ;_ end of IF
             ) ;_ end of SETQ
            )
            ((AND (> (STRLEN n) 5)
                  (EQ (TYPE (READ (SUBSTR n 1 5))) 'int)
             ) ;_ end of AND
             (SETQ job_number (READ (SUBSTR n 1 5))
                   subtsk#    (IF subtsk#
                                subtsk#
                                0.1
                              ) ;_ end of IF
             ) ;_ end of SETQ
            )
          ) ;_ end of COND
        ) ;_ end of IF
      ) ;_ end of FOREACH
      (IF job_number
        (SETQ job_number
               (+ job_number
                  (IF subtsk#
                    subtsk#
                    0.1
                  ) ;_ end of IF
               ) ;_ end of +
        ) ;_ end of SETQ
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (AND (OR (WCMATCH plotr "*8825*") (WCMATCH plotr "*8830*"))
           (NOT jstscr)
      ) ;_ end of AND
    (PROGN
      (IF ureal
        nil
        (LOAD "ureal")
      ) ;_ end of if
      (SETQ job_number
             (ureal 1
                    ""
                    "Job Account.SubTask Number?"
                    (IF job_number
                      job_number
                      nil
                    ) ;_ end of IF
             ) ;_ end of ureal
      ) ;_ end of SETQ
      (SETQ job_account (ITOA (FIX job_number)))
      (SETQ job_subtask
             (STRCAT
               (SUBSTR (RTOS (REM job_number (FIX job_number))) 3 1)
               (IF
                 (ZEROP
                   (ATOI (SUBSTR (RTOS (REM job_number (FIX job_number))) 4 1)
                   ) ;_ end of atoi
                 ) ;_ end of zerop
                  ""
                  (SUBSTR (RTOS (REM job_number (FIX job_number))) 4 1)
               ) ;_ end of if
               (IF
                 (ZEROP
                   (ATOI (SUBSTR (RTOS (REM job_number (FIX job_number))) 5 1)
                   ) ;_ end of atoi
                 ) ;_ end of zerop
                  ""
                  (SUBSTR (RTOS (REM job_number (FIX job_number))) 5 1)
               ) ;_ end of if
               (IF
                 (ZEROP
                   (ATOI (SUBSTR (RTOS (REM job_number (FIX job_number))) 6 1)
                   ) ;_ end of atoi
                 ) ;_ end of zerop
                  ""
                  (SUBSTR (RTOS (REM job_number (FIX job_number))) 6 1)
               ) ;_ end of if
             ) ;_ end of strcat
      ) ;_ end of setq
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (AND (EQ svqt "Yes")
           (/= (GETVAR "dwgname") "UNNAMED")
           (/= (GETVAR "dwgname") "DRAWING.DWG")
           (NOT (WCMATCH (GETVAR "dwgname") " .DWG"))
      ) ;_ end of and
    (PROGN
      (IF (EQ force_wcs "1")
        (IF (EQ (GETVAR "WORLDUCS") 1)
          nil
          (COMMAND "UCS" "W")
        ) ;_ end of IF
      ) ;_ end of IF
      (IF c:qsave
        (c:qsave)
        (COMMAND ".qsave")
      ) ;_ end of IF
    ) ;_ end of PROGN
  )                                     ;if
  (PRINC (STRCAT "\nCreating "
                 pltdir
                 lognm
                 "BPLOT2K.SCR, please wait...  "
         ) ;_ end of strcat
  ) ;_ end of princ
  (SETQ waitic "|"
        ticsid 1
        pltcnt 0
  ) ;_ end of setq
  (IF (AND prestr (/= prestr ""))
    (IF (EQ (SUBSTR prestr 1 8) "filename")
      (PROGN
        (SETQ prefil (FINDFILE (SUBSTR prestr 10)))
        (IF prefil
          nil
          (ALERT
            (STRCAT
              (SUBSTR prestr 10)
              "\nFile not found! It will not be included\nin the batch script you have created."
            ) ;_ end of strcat
          ) ;_ end of alert
        ) ;_ end of if
      ) ;_ end of progn
    ) ;_ end of if
  ) ;_ end of if
  (IF (AND pststr (/= pststr ""))
    (IF (EQ (SUBSTR pststr 1 8) "filename")
      (PROGN
        (SETQ pstfil (FINDFILE (SUBSTR pststr 10)))
        (IF pstfil
          nil
          (ALERT
            (STRCAT
              (SUBSTR pststr 10)
              "\nFile not found! It will not be included\nin the batch script you have created."
            ) ;_ end of strcat
          ) ;_ end of alert
        ) ;_ end of if
      ) ;_ end of progn
    ) ;_ end of if
  ) ;_ end of if
  (mkpage2)
  (IF (AND (NOT jstscr) (NOT (EQ allayplt "1")))
    (PROGN
      (ALERT
        "Existing plot files for the selected drawings are about to be deleted!\nIf you wish to preserve them you should do that now\nBefore dismissing this message!"
      ) ;_ end of ALERT
    ) ;_ end of PROGN
  ) ;_ end of IF
  (SETQ debug_pltlst pltlst)
;;;  (WRITE-LINE "(SETVAR \"PLQUIET\" 1)" fp1)
  (IF quotepaths
    nil
    (LOAD "acaddoclist" "\nFile ACADDOCLIST.LSP not loaded! ")
  ) ;_ end of IF
  (FOREACH n pltlst
    (IF debug_doslib
      (PRINC "\nDOS_20 ")
    ) ;_ end of IF
    (SETQ split_fp (DOS_SPLITPATH n))
    (IF debug_doslib
      (PRINC "\nDOS_20 ")
    ) ;_ end of IF
    (IF (EQ fildrv "with DWG")
      (SETQ plt_drv (CAR split_fp))
      (SETQ plt_drv fildrv)
    ) ;_ end of IF
    (IF (NOT jstscr)
      (SETQ oldplt1
                    (STRCAT plt_drv
                            (CADR split_fp)
                            "Plots\\"
                            frst_dir
                            (CADDR split_fp)
;;;                   "-"
;;;                   (GETVAR "CTAB")
                            (COND
                              ((AND plotr (WCMATCH (STRCASE plotr) "*TIFF*"))
                               ".*tif"
                              )
                              ((AND plotr (WCMATCH (STRCASE plotr) "*JPG*"))
                               ".*jpg"
                              )
                              ((AND plotr (WCMATCH (STRCASE plotr) "*PNG*"))
                               ".*png"
                              )
                              (T ".plt*")
                            ) ;_ end of COND
                    ) ;_ end of strcat
            oldplt2
                    (STRCAT plt_drv
                            (CADR split_fp)
                            "Plots\\"
                            frst_dir
                            (CADDR split_fp)
                            "-"
                            (GETVAR "CTAB")
                            (COND
                              ((AND plotr (WCMATCH (STRCASE plotr) "*TIFF*"))
                               ".*tif"
                              )
                              ((AND plotr (WCMATCH (STRCASE plotr) "*JPG*"))
                               ".*jpg"
                              )
                              ((AND plotr (WCMATCH (STRCASE plotr) "*PNG*"))
                               ".*png"
                              )
                              (T ".plt*")
                            ) ;_ end of COND
                    ) ;_ end of strcat
      ) ;_ end of setq
    ) ;_ end of IF
    (IF (AND (NOT jstscr)
             (EQ out_to "Fileout")
        ) ;_ end of and
      (IF (EQ allayplt "1")
        (PROGN
          (IF debug_doslib
            (PRINC "\nDOS_21 ")
          ) ;_ end of IF
          (IF (AND (NOT jstscr) (NOT (EQ allayplt "1")))
            (PROGN
              (DOS_DELETE
                (STRCAT plt_drv
                        (CADR split_fp)
                        "Plots\\"
                        frst_dir
                        (CADDR split_fp)
                        (COND
                          ((AND plotr (WCMATCH (STRCASE plotr) "*TIFF*"))
                           ".*tif"
                          )
                          ((AND plotr (WCMATCH (STRCASE plotr) "*JPG*"))
                           ".*jpg"
                          )
                          ((AND plotr (WCMATCH (STRCASE plotr) "*PNG*"))
                           ".*png"
                          )
                          (T "*.plt*")
                        ) ;_ end of COND
                ) ;_ end of STRCAT
              ) ;_ end of dos_delete
            ) ;_ end of PROGN
          ) ;_ end of IF
          (IF debug_doslib
            (PROGN
              (PRINC "\nallayplt = ")
              (PRINC allayplt)
              (PRINC
                (STRCAT "\n(DOS_DELETE "
                        plt_drv
                        (CADR split_fp)
                        "Plots\\"
                        frst_dir
                        (CADDR split_fp)
                        "*.plt*"
                        ")"
                ) ;_ end of STRCAT
              ) ;_ end of PRINC
            ) ;_ end of PROGN
            (PRINC)
          ) ;_ end of IF
        ) ;_ end of PROGN
        (PROGN
          (IF debug_doslib
            (PRINC "\nDOS_22 ")
          ) ;_ end of IF
          (IF (AND (NOT jstscr) (NOT (EQ allayplt "1")))
            (PROGN
              (DOS_DELETE oldplt1)
              (DOS_DELETE oldplt2)
            ) ;_ end of PROGN
          ) ;_ end of IF
          (IF debug_doslib
            (PRINC "\nDOS_22 ")
          ) ;_ end of IF
          (IF debug_doslib
            (PROGN
              (PRINC "\nallayplt = ")
              (PRINC allayplt)
              (PRINC "\noldplt1=")
              (PRINC oldplt1)
              (PRINC "\noldplt2=")
              (PRINC oldplt2)
              (PRINC
                (STRCAT "\n(DOS_DELETE "
                        plt_drv
                        (CADR split_fp)
                        "Plots\\"
                        frst_dir
                        (CADDR split_fp)
                        "*.plt*"
                        ")"
                ) ;_ end of STRCAT
              ) ;_ end of PRINC
              (PRINC)
            ) ;_ end of PROGN
          ) ;_ end of IF
        ) ;_ end of PROGN
      ) ;_ end of IF
    ) ;_ end of if
    (IF debug_doslib
      (PRINC "\nDOS_23 ")
    ) ;_ end of IF
    (IF debug_doslib
      (PRINC "\nDOS_24 ")
    ) ;_ end of IF
;;;    (IF	(AND oldplt oldplth)
;;;      NIL
    (IF jstscr
      (wait_spin)
      (mkpltdirs)
    ) ;_ end of IF
;;;    ) ;_ end of IF
    (SETQ output_fn
           (IF (OR (WCMATCH (CADR split_fp) "* *")
                   (WCMATCH (CADDR split_fp) "* *")
               ) ;_ end of OR
             (STRCAT "\""
                     plt_drv
                     (CADR split_fp)
                     "Plots\\"
                     (IF frst_dir
                       frst_dir
                       "A\\"
                     ) ;_ end of IF
                     (CADDR split_fp)
;;;                     ".plt\""
             ) ;_ end of strcat
             (STRCAT plt_drv
                     (CADR split_fp)
                     "Plots\\"
                     (IF frst_dir
                       frst_dir
                       "A\\"
                     ) ;_ end of IF
                     (CADDR split_fp)
;;;                     ".plt"
             ) ;_ end of strcat
           ) ;_ end of IF
    ) ;_ end of setq
    (IF (EQ out_to "Fileout")
      (PROGN
        (SETQ fnstepcnt 1
              plot_fn
               (IF (>= (STRLEN output_fn) 132)
                 (STRCAT
                   (DOS_SHORTPATH
                     (STRCAT
                       (CAR
                         (DOS_SPLITPATH (STRCAT (SUBSTR output_fn 2) ".dwg"))
                       ) ;_ end of CAR
                       (CADR
                         (DOS_SPLITPATH (STRCAT (SUBSTR output_fn 2) ".dwg"))
                       ) ;_ end of CADR
                     ) ;_ end of STRCAT
                   ) ;_ end of DOS_SHORTPATH
                   (CADDR (DOS_SPLITPATH (STRCAT (SUBSTR output_fn 2) ".dwg"))
                   ) ;_ end of CADDR
                 ) ;_ end of STRCAT
                 (STRCAT output_fn "\\")
               ) ;_ end of IF
;;;              plot_fn   (STRCAT output_fn "\\") ;output filename
        ) ;_ end of setq
        (WHILE
          (AND (WCMATCH plot_fn "*[~\\]\\[~\\]*")
               (IF (>= fnstepcnt (1- (STRLEN plot_fn)))
                 (NOT (WCMATCH (SUBSTR plot_fn (1- (STRLEN plot_fn)) 2)
                               "\\\\"
                      ) ;_ end of wcmatch
                 ) ;_ end of not
                 T
               ) ;_ end of if
          ) ;_ end of and
           (IF (WCMATCH (SUBSTR plot_fn fnstepcnt) "\\[~\\]*")
             (SETQ plot_fn   (STRCAT (SUBSTR plot_fn 1 (1- fnstepcnt))
                                     "\\"
                                     (SUBSTR plot_fn fnstepcnt)
                             ) ;_ end of strcat
                   fnstepcnt (+ fnstepcnt 2)
             ) ;_ end of setq
             (SETQ fnstepcnt (1+ fnstepcnt))
           ) ;_ end of if
           (IF debug_bplot2k
             (PROGN
               (PRINC (STRCAT "\nplot_fn(" (ITOA fnstepcnt) ")="))
               (PRINC plot_fn)
               (PRINC "\nplot_fn_a=")
               (PRINC (SUBSTR plot_fn 1 (- (STRLEN plot_fn) 5)))
               (PRINC "\n")
               (PRINC)
             ) ;_ end of PROGN
           ) ;_ end of IF
        ) ;_ end of while
        (IF (EQ (SUBSTR plot_fn 1 1) "\"")
          nil
          (SETQ plot_fn (STRCAT "\"" plot_fn))
        ) ;_ end of IF
;;;        (IF (EQ (SUBSTR plot_fn (STRLEN plot_fn)) "\"")
;;;          (SETQ plot_fn_a (SUBSTR plot_fn 1 (- (STRLEN plot_fn) 5)))
;;;          (SETQ plot_fn_a (SUBSTR plot_fn 1 (- (STRLEN plot_fn) 4)))
;;;        ) ;_ end of IF
        (WHILE (EQ (SUBSTR plot_fn (STRLEN plot_fn)) "\\")
          (SETQ plot_fn (SUBSTR plot_fn 1 (1- (STRLEN plot_fn))))
        ) ;_ end of WHILE
        (SETQ plot_fn_a plot_fn)
        (SETQ plot_fn
               (STRCAT
                 "(STRCAT "
                 plot_fn_a
                 "-\""
;;;                 "(IF(EQ allayplt \"1\")(CAR(LAYOUTLIST))(GETVAR \"ctab\")) \".plt\")"
                 "(IF(EQ allayplt \"1\")(CAR(LAYOUTLIST))(GETVAR \"ctab\")))"
               ) ;_ end of STRCAT
        ) ;_ end of SETQ
        (IF (= include_plbl "1")
          (SETQ str1
                 (STRCAT                ;"(setq ftscl \"" output_fn
                   "(setq pltoutfn "
                   plot_fn
                   ") (if c:plbl nil (load\"plbl\"))(if c:plbl (c:plbl))"
                 ) ;_ end of strcat
          ) ;_ end of setq
          (SETQ str1
                 (STRCAT                ;"(setq ftscl \"" output_fn
                   "(setq pltoutfn "
                   plot_fn
                   ")"
                 ) ;_ end of strcat
          ) ;_ end of setq
        ) ;_ end of IF
      ) ;_ end of progn
    ) ;_ end of if
    (SETQ oldplt1 nil
          oldplt2 nil
          oldplth nil
    ) ;_ end of SETQ
    (SETQ pltcnt (1+ pltcnt))
    (wait_spin)
    (IF goplt
      (IF
        (>= (- (STRLEN (GETVAR "dwgname")) (- (STRLEN n) 5)) 1)
         (IF
           (OR
;;;             (EQ n (FINDFILE (CAR d_flst)))
             (AND
               (EQ n (CAR pltlst))
               (EQ
                 (STRCASE n)
                 (STRCASE (STRCAT (GETVAR "dwgprefix") (GETVAR "dwgname"))
                 ) ;_ end of STRCASE
               ) ;_ end of EQ
             ) ;_ end of AND
;;;             (EQ
;;;               (STRCASE (STRCAT (GETVAR "dwgprefix")
;;;                                (IF (WCMATCH dwgn "*\\*")
;;;                                  (WHILE (WCMATCH dwgn "*\\*")
;;;                                    (SETQ dwgn (SUBSTR dwgn 2))
;;;                                  ) ;_ end of while
;;;                                  dwgn
;;;                                ) ;_ end of if
;;;                                        ;		     ".DWG"
;;;                        ) ;_ end of strcat
;;;               ) ;_ end of strcase
;;;               (STRCASE n)
;;;             ) ;_ end of eq
           ) ;_ end of or
            nil
            (PROGN
;;;              (princ "\n\t\t************************************************************")
;;;              (princ n)
;;;              (princ "\n\t\t************************************************************")
;;;              (princ (findfile (car d_flst)))
;;;              (princ "\n\t\t************************************************************")
;;;              (princ)
;;;              (WRITE-LINE
;;;                "(IF (EQ (GETVAR \"SDI\") 0) (COMMAND \".Close\" (IF (NOT (EQ (GETVAR \"DBMOD\") 0))\"No\" (PRINC)))(PRINC))"
;;;                fp1
;;;              ) ;_ end of WRITE-LINE
;;;              (WRITE-LINE str0 fp1)
;;;	      (if (/= (getvar "dbmod") 0)
;;;Second line written if just a script, Third if a plot script
;;;Only written if drawing has been modified.
;;;Responds "Yes" to discard changes
;;;              (WRITE-LINE str01 fp1)
              ;;	      )				;if
              (WRITE-LINE
                "(if myopen_fun nil (load \"myopen_fun\" \"\\nFile MYOPEN_FUN.LSP not loaded! \"))"
                fp1
              ) ;_ end of WRITE-LINE
;;;              (IF (WCMATCH n "* *")
              (SETQ fnamew    (quotepaths (fourslash n) T)
                    fourslist (APPEND fourslist (LIST (CONS "n1" n)))
              ) ;_ end of SETQ
              (WRITE-LINE
                (STRCAT "(myopen_fun (findfile \"" fnamew "\"))")
                fp1
              ) ;_ end of WRITE-LINE
;;;                (WRITE-LINE (STRCAT "(myopen_fun " n ")") fp1)
;;;                (WRITE-LINE (STRCAT "\"" n "\"") fp1)
;;;                (WRITE-LINE n fp1)
;;;              ) ;_ end of if
            )                           ;progn
         )                              ;if
         (IF
           (AND
             (EQ n (CAR pltlst))
             (EQ
               (STRCASE n)
               (STRCASE (STRCAT (GETVAR "dwgprefix") (GETVAR "dwgname")))
             ) ;_ end of EQ
           ) ;_ end of AND
            nil
            (PROGN
;;;              (WRITE-LINE
;;;                "(IF (EQ (GETVAR \"SDI\") 0) (COMMAND \".Close\" (IF (NOT (EQ (GETVAR \"DBMOD\") 0))\"No\" (PRINC)))(PRINC))"
;;;                fp1
;;;              ) ;_ end of WRITE-LINE
;;;              (WRITE-LINE str0 fp1)
;;;              (WRITE-LINE str01 fp1)
              (WRITE-LINE
                "(if myopen_fun nil (load \"myopen_fun\" \"\\nFile MYOPEN_FUN.LSP not loaded! \"))"
                fp1
              ) ;_ end of WRITE-LINE
              (SETQ fnamew    (quotepaths (fourslash n) T)
                    fourslist (APPEND fourslist (LIST (CONS "n2" n)))
              ) ;_ end of SETQ
;;;              (IF (WCMATCH n "* *")
              (WRITE-LINE (STRCAT "(myopen_fun \"" fnamew "\")") fp1)
;;;                (WRITE-LINE (STRCAT "(myopen_fun " n ")") fp1)
;;;                (WRITE-LINE (STRCAT "\"" n "\"") fp1)
;;;                (WRITE-LINE n fp1)
;;;              ) ;_ end of if
              (WRITE-LINE
                "(PROGN(IF dlog nil(LOAD \"dlog\"))(SETQ ostr \"  Opened for editing....:  \" ONAM NIL)(if dlog(dlog)))"
                fp1
              ) ;_ end of write-line
            ) ;_ end of progn
         ) ;_ end of if
      ) ;_ end of if
;;;      (if
;;;        (or
;;;          (eq n (FINDFILE (CAR d_flst)))
;;;          (eq n (strcat (getvar "dwgprefix") (getvar "dwgname")))
;;;        )
;;;        nil
      (IF
        (AND
          (EQ n (CAR pltlst))
          (EQ (STRCASE n)
              (STRCASE (STRCAT (GETVAR "dwgprefix") (GETVAR "dwgname")))
          ) ;_ end of EQ
        ) ;_ end of AND
         nil
         (PROGN
;;;           (WRITE-LINE
;;;             "(IF (EQ (GETVAR \"SDI\") 0) (COMMAND \".Close\" (IF (NOT (EQ (GETVAR \"DBMOD\") 0))\"No\" (PRINC)))(PRINC))"
;;;             fp1
;;;           ) ;_ end of WRITE-LINE
;;;           (WRITE-LINE str0 fp1)
;;;           (WRITE-LINE str01 fp1)
           (WRITE-LINE
             "(if myopen_fun nil (load \"myopen_fun\" \"\\nFile MYOPEN_FUN.LSP not loaded! \"))"
             fp1
           ) ;_ end of WRITE-LINE
;;;           (IF (WCMATCH n "* *")
           (SETQ fnamew    (quotepaths (fourslash n) T)
                 fourslist (APPEND fourslist (LIST (CONS "n3" n)))
           ) ;_ end of SETQ
           (WRITE-LINE (STRCAT "(myopen_fun \"" fnamew "\")") fp1)
;;;             (WRITE-LINE (STRCAT "(myopen_fun " n ")") fp1)
;;;             (WRITE-LINE (STRCAT "\"" n "\"") fp1)
;;;Write filename to open
;;;             (WRITE-LINE n fp1)
;;;           ) ;_ end of if
           (WRITE-LINE
             "(PROGN(IF dlog nil(LOAD \"dlog\"))(SETQ ostr \"  Opened for editing....:  \" ONAM NIL)(if dlog(dlog)))"
             fp1
           ) ;_ end of write-line
         ) ;_ end of progn
      ) ;_ end of IF
;;;      )
    ) ;_ end of if
    (IF (EQ forcedim0 "1")
      (PROGN
        (WRITE-LINE "dimscale" fp1)
        (IF (WCMATCH (STRCASE page1) "* MS")
          (WRITE-LINE "1" fp1)
          (WRITE-LINE "0" fp1)
        ) ;_ end of IF
      ) ;_ end of PROGN
    ) ;_ end of if
    (IF (AND prestr (/= prestr ""))
      (IF (EQ (SUBSTR prestr 1 8) "filename")
        (PROGN
          (SETQ prefil (FINDFILE (SUBSTR prestr 10)))
          (IF (AND prefil (/= allayplt "1"))
            (PROGN
              (SETQ opref (OPEN prefil "r"))
              (WHILE
                (SETQ pflin (READ-LINE opref))
;;;Write contents of specified pre-plot script file
                 (WRITE-LINE pflin fp1)
              ) ;_ end of while
              (CLOSE opref)
            ) ;_ end of progn
          ) ;_ end of if
        ) ;_ end of progn
;;;Or, Write contents of Bplot's pre-plot script edit box
        (WRITE-LINE prestr fp1)
      ) ;_ end of if
    ) ;_ end of if
;;;    (PRINC "\nins_fname=")
;;;    (princ ins_fname)
;;;    (princ "\nn=")
;;;    (princ n)
;;;    (princ)
;;;Write etransmit-folder script if requested
    (IF (EQ etrf_scr "1")
      (PROGN
        (WRITE-LINE
          "(if etransfiles nil (load \"etransfiles\" \"FIle ETRANSFILES.LSP not loaded! \"))"
          fp1
        ) ;_ end of WRITE-LINE
        (WRITE-LINE
          "(IF(EQ(GETVAR\"tilemode\")0)(COMMAND \".pspace\"))"
          fp1
        ) ;_ end of WRITE-LINE
        (WRITE-LINE ".zoom" fp1)
        (WRITE-LINE "e" fp1)
        (WRITE-LINE "(c:qsave)" fp1)
        (WRITE-LINE "(etransmkdir)" fp1)
        (WRITE-LINE "(etransdelete)" fp1)
        (WRITE-LINE "-etransmit" fp1)
        (WRITE-LINE "Folder" fp1)
        (WRITE-LINE
          (STRCAT (DOS_FULLPATH "..\\") "815 Submittals\\Temp\\")
          fp1
        ) ;_ end of WRITE-LINE
        (WRITE-LINE "" fp1)
        (WRITE-LINE "Yes" fp1)
        (WRITE-LINE "No" fp1)
        (WRITE-LINE "No" fp1)
        (WRITE-LINE "Yes" fp1)
        (WRITE-LINE "No" fp1)
        (WRITE-LINE "(etransfiles)" fp1)
      ) ;_ end of PROGN
    ) ;_ end of IF
    (IF jstscr
      (IF (EQ ins_fname "1")
        (WRITE-LINE
          (STRCAT "\"" (SUBSTR n 1 (- (STRLEN n) 4)) "\"")
          fp1
        ) ;_ end of write-line
      ) ;_ end of if
;;;Write lisp string for calculating drawing scale
      (PROGN
;;;Write lisp string for forcing PSTYLEMODE=1
        (WRITE-LINE
          "(if c:psty2ctb nil (load \"psty2ctb\" \"\\nFile PSTY2CTB.LSP not loaded! \"))"
          fp1
        ) ;_ end of write-line
        (WRITE-LINE "(if c:psty2ctb (c:psty2ctb))" fp1)
        (IF (WCMATCH (STRCASE page1) "* MS*")
          (WRITE-LINE "(SETVAR \"TILEMODE\" 1)" fp1)
          (WRITE-LINE "(SETVAR \"TILEMODE\" 0)" fp1)
        ) ;_ end of IF
        (WRITE-LINE
          (STRCAT
            "(COND((AND(WCMATCH\""
            (SUBSTR page1 6)
            "\"\"##*MS\")
            (EQ(GETVAR\"DIMSCALE\")0))(SETVAR\"DIMSCALE\"(/(-(CADR(GETVAR\"LIMMAX\"))(CADR(GETVAR\"LIMMIN\")))(ATOI\""
            (SUBSTR page1 9 2)
            "\")))))"
          ) ;_ end of strcat
          fp1
        ) ;_ end of write-line
        (IF (AND custom-window-llcor
                 custom-window-urcor
                 (WCMATCH plotwindow "1")
            ) ;_ end of AND
          (IF (< (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 17.0)
            (PROGN
;;;            (WRITE-LINE "LIMITS" fp1)
;;;            (WRITE-LINE custom-window-llcor fp1)
;;;            (WRITE-LINE custom-window-urcor fp1)
              (WRITE-LINE
                (STRCAT "(grdraw (list "
                        (RTOS plotwin_llx 2 2)
                        " "
                        (RTOS plotwin_lly 2 2)
                        " 0.0)(list "
                        (RTOS plotwin_urx 2 2)
                        " "
                        (RTOS plotwin_lly 2 2)
                        " 0.0) 1 1)"
                ) ;_ end of STRCAT
;;;              "(grdraw (list plotwin_llx plotwin_lly 0)(list plotwin_urx plotwin_lly 0) 1 1)"
                fp1
              ) ;_ end of WRITE-LINE
              (WRITE-LINE
                (STRCAT "(grdraw (list "
                        (RTOS plotwin_urx 2 2)
                        " "
                        (RTOS plotwin_lly 2 2)
                        " 0.0)(list "
                        (RTOS plotwin_urx 2 2)
                        " "
                        (RTOS plotwin_ury 2 2)
                        " 0.0) 1 1)"
                ) ;_ end of STRCAT
                fp1
              ) ;_ end of WRITE-LINE
              (WRITE-LINE
                (STRCAT "(grdraw (list "
                        (RTOS plotwin_urx 2 2)
                        " "
                        (RTOS plotwin_ury 2 2)
                        " 0.0)(list "
                        (RTOS plotwin_llx 2 2)
                        " "
                        (RTOS plotwin_ury 2 2)
                        " 0.0) 1 1)"
                ) ;_ end of STRCAT
;;;              "(grdraw (list plotwin_urx plotwin_ury 0)(list plotwin_llx plotwin_ury 0) 1 1)"
                fp1
              ) ;_ end of WRITE-LINE
              (WRITE-LINE
                (STRCAT "(grdraw (list "
                        (RTOS plotwin_llx 2 2)
                        " "
                        (RTOS plotwin_ury 2 2)
                        " 0.0)(list "
                        (RTOS plotwin_llx 2 2)
                        " "
                        (RTOS plotwin_lly 2 2)
                        " 0.0) 1 1)"
                ) ;_ end of STRCAT
;;;              "(grdraw (list plotwin_llx plotwin_ury 0)(list plotwin_llx plotwin_lly 0) 1 1)"
                fp1
              ) ;_ end of WRITE-LINE
            ) ;_ end of PROGN
          ) ;_ end of IF
          (PROGN
            (WRITE-LINE
              "(grdraw (list (car(getvar\"limmin\")) (cadr(getvar\"limmin\")))(list (car(getvar\"limmax\")) (cadr(getvar\"limmin\"))) 1 1)"
              fp1
            ) ;_ end of WRITE-LINE
            (WRITE-LINE
              "(grdraw (list (car(getvar\"limmax\")) (cadr(getvar\"limmin\")))(list (car(getvar\"limmax\")) (cadr(getvar\"limmax\"))) 1 1)"
              fp1
            ) ;_ end of WRITE-LINE
            (WRITE-LINE
              "(grdraw (list (car(getvar\"limmax\")) (cadr(getvar\"limmax\")))(list (car(getvar\"limmin\")) (cadr(getvar\"limmax\"))) 1 1)"
              fp1
            ) ;_ end of WRITE-LINE
            (WRITE-LINE
              "(grdraw (list (car(getvar\"limmin\")) (cadr(getvar\"limmax\")))(list (car(getvar\"limmin\")) (cadr(getvar\"limmin\"))) 1 1)"
              fp1
            ) ;_ end of WRITE-LINE
          ) ;_ end of PROGN
        ) ;_ end of IF
        (WRITE-LINE str1 fp1)
      ) ;_ end of progn
    ) ;_ end of if
    (IF (NOT jstscr)
      (PROGN
        (mkpage2)
        (WRITE-LINE
          "(if loadpages nil (load \"bplot2k\" \"\\nFile BPLOT2K.LSP not loaded! \"))"
          fp1
        ) ;_ end of write-line
        (WRITE-LINE "(if loadpages (loadpages))" fp1)
        (WRITE-LINE
          "(if c:fiximagevars nil (load \"fiximagevars\" \"\\nFile FIXIMAGEVARS.LSP not loaded! \"))(c:fiximagevars)"
          fp1
        ) ;_ end of WRITE-LINE


;;;        (WRITE-LINE (STRCAT "(DOS_DELETE " pltdir ")") fp1)

;;;        (IF (EQ allayplt "1")
;;;          (PROGN
;;;            (SETQ plot_device plotr)
;;;          )
;;;          (PROGN
        (IF (OR
              (DOS_DIRP (STRCAT plt_drv
                                (CADR split_fp)
                                "Plots\\"
                                (IF frst_dir
                                  frst_dir
                                  "A\\"
                                ) ;_ end of IF
                        ) ;_ end of STRCAT
              ) ;_ end of DOS_DIRP
              (DOS_MKDIR (STRCAT plt_drv
                                 (CADR split_fp)
                                 "Plots\\"
                                 (IF frst_dir
                                   frst_dir
                                   "A\\"
                                 ) ;_ end of IF
                         ) ;_ end of STRCAT
              ) ;_ end of DOS_MKDIR
            ) ;_ end of OR
          nil
          (ALERT "Output folder does not exist! ")
        ) ;_ end of IF
        (IF (NOT (EQ allayplt "1"))
          (PROGN
            (COND
              ((WCMATCH (STRCASE page1) "*JPG*") (SETQ imgext "jpg"))
              ((WCMATCH (STRCASE page1) "*TIFF*") (SETQ imgext "tif"))
              ((WCMATCH (STRCASE page1) "*PNG*") (SETQ imgext "png"))
            ) ;_ end of COND
            (IF (EQ force_wcs "1")
              (WRITE-LINE
                "(IF (EQ (GETVAR \"WORLDUCS\") 1) NIL (COMMAND \"UCS\" \"W\"))"
                fp1
              ) ;_ end of WRITE-LINE
            ) ;_ end of IF
            (IF (AND imgext pltdir)
              (PROGN
                (WRITE-LINE
                  "(if autodpifix nil (load \"autodpifix\"))"
                  fp1
                ) ;_ end of WRITE-LINE
                (WRITE-LINE
                  "(if check_for_doslib nil (load \"check_for_doslib\"))"
                  fp1
                ) ;_ end of WRITE-LINE
                (WRITE-LINE "(check_for_doslib)" fp1)
                (SETQ my_plot_fn plot_fn)
                (SETQ my_pltdir this_pltdir)
                (SETQ fnstepcnt 1
                      this_pltdir
                       pltdir
                ) ;_ end of setq
                (WHILE
                  (WCMATCH this_pltdir "*\\*")
                   (COND
                     ((WCMATCH (SUBSTR this_pltdir fnstepcnt) "\\\\*")
                      (SETQ this_pltdir (STRCAT (SUBSTR this_pltdir
                                                        1
                                                        (- fnstepcnt 1)
                                                ) ;_ end of SUBSTR
                                                "/"
                                                (SUBSTR this_pltdir
                                                        (+ fnstepcnt 2)
                                                ) ;_ end of SUBSTR
                                        ) ;_ end of strcat
                            fnstepcnt   (+ fnstepcnt 2)
                      ) ;_ end of SETQ
                     )
                     ((WCMATCH (SUBSTR this_pltdir fnstepcnt) "\\*")
                      (SETQ this_pltdir (STRCAT (SUBSTR this_pltdir
                                                        1
                                                        (- fnstepcnt 1)
                                                ) ;_ end of SUBSTR
                                                "/"
                                                (SUBSTR this_pltdir
                                                        (+ fnstepcnt 1)
                                                ) ;_ end of SUBSTR
                                        ) ;_ end of strcat
                            fnstepcnt   (+ fnstepcnt 1)
                      ) ;_ end of SETQ
                     )
                     (T (SETQ fnstepcnt (1+ fnstepcnt)))
                   ) ;_ end of COND
                   (IF debug_bplot2k
                     (PROGN
                       (PRINC
                         (STRCAT "\nthis_pltdir(" (ITOA fnstepcnt) ")=")
                       ) ;_ end of PRINC
                       (PRINC this_pltdir)
                       (PRINC "\nthis_pltdir_a=")
                       (PRINC (SUBSTR this_pltdir
                                      1
                                      (- (STRLEN this_pltdir) 5)
                              ) ;_ end of SUBSTR
                       ) ;_ end of PRINC
                       (PRINC "\n")
                       (PRINC)
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                ) ;_ end of WHILE
                (SETQ fnstepcnt 1
                      this_pltfn
                       output_fn
                ) ;_ end of setq
                (WHILE
                  (WCMATCH this_pltfn "*\\*")
                   (COND
                     ((WCMATCH (SUBSTR this_pltfn fnstepcnt) "\\\\*")
                      (SETQ this_pltfn (STRCAT
                                         (SUBSTR this_pltfn
                                                 1
                                                 (- fnstepcnt 1)
                                         ) ;_ end of SUBSTR
                                         "/"
                                         (SUBSTR this_pltfn (+ fnstepcnt 2))
                                       ) ;_ end of strcat
                            fnstepcnt  (+ fnstepcnt 2)
                      ) ;_ end of SETQ
                     )
                     ((WCMATCH (SUBSTR this_pltfn fnstepcnt) "\\*")
                      (SETQ this_pltfn (STRCAT
                                         (SUBSTR this_pltfn
                                                 1
                                                 (- fnstepcnt 1)
                                         ) ;_ end of SUBSTR
                                         "/"
                                         (SUBSTR this_pltfn (+ fnstepcnt 1))
                                       ) ;_ end of strcat
                            fnstepcnt  (+ fnstepcnt 1)
                      ) ;_ end of SETQ
                     )
                     (T (SETQ fnstepcnt (1+ fnstepcnt)))
                   ) ;_ end of COND
                   (IF debug_bplot2k
                     (PROGN
                       (PRINC
                         (STRCAT "\nthis_pltfn(" (ITOA fnstepcnt) ")=")
                       ) ;_ end of PRINC
                       (PRINC this_pltfn)
                       (PRINC "\nthis_pltfn_a=")
                       (PRINC
                         (SUBSTR this_pltfn 1 (- (STRLEN this_pltfn) 5))
                       ) ;_ end of PRINC
                       (PRINC "\n")
                       (PRINC)
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                ) ;_ end of WHILE
;;;                (WRITE-LINE
;;;                  (STRCAT
;;;                    "(put_dpibat \""    ;(put_dpibat lognm bplotscriptdir name dpiresstr ishalf)
;;;                    lognm         "\" \""     this_pltdir
;;;                    "\" (STRCAT "             this_pltfn
;;;                    "\" \"."      imgext        "\") "
;;;                    "\"288\""           ;dpiresstr
;;;                    ishalf
;;;                    ")"
;;;                   ) ;_ end of STRCAT
;;;                  fp1
;;;                ) ;_ end of WRITE-LINE
              ) ;_ end of PROGN
            ) ;_ end of IF
            (IF (AND update_title
                     (OR (EQ (TYPE update_title) 'usubr)
                         (EQ (TYPE update_title) 'subr)
                     ) ;_ end of OR
                ) ;_ end of AND
              (WRITE-LINE
                "(IF update_title NIL (LOAD \"update_title\" \"\nFile UPDATE_TITLE.LSP not loaded! \"))(update_title)"
                fp1
              ) ;_ end of WRITE-LINE
            ) ;_ end of IF
            (IF (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[9]")
                                        ;was"1[678]"
              nil
              (PROGN
                (IF
                  (AND (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[678]")
                       (NOT (WCMATCH (STRCASE page1) "*HP*"))
                  ) ;_ end of and
                   (WRITE-LINE "(COMMAND \"-PLOT\" \"Yes\")" fp1)
                   (WRITE-LINE "(COMMAND \"-PLOT\" \"\")" fp1)
                ) ;_ end of if
                (IF (WCMATCH (STRCASE page1) "* MS*")		;Layout Name
                  (WRITE-LINE "Model" fp1)
                  (WRITE-LINE
                    "(IF(EQ(getvar \"ctab\")\"Model\")(car (layoutlist))(getvar \"ctab\"))"
                    fp1
                  ) ;_ end of write-line
                ) ;_ end of IF
                (IF
                  (AND (WCMATCH (SUBSTR (GETVAR "ACADVER") 1 2) "1[678]")
                       (NOT (WCMATCH (STRCASE page1) "*HP*"))
                  ) ;_ end of AND
                   nil
                   (WRITE-LINE page1 fp1)			;Page Setup Name (for NON-detailed plot configuration)
                ) ;_ end of IF
                                        ;        (write-line (strcat plotr ".pc3") fp1)
              ) ;_ end of PROGN
            ) ;_ end of IF
            (SETQ plot_device plotr)
            (IF (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[9]")
                                        ;was"1[678]"
              nil
              (IF (NOT (EQ allayplt "1"))
                (PROGN
                  (WRITE-LINE plotr fp1)			;Output Device Name (for detailed plot configuration)
                ) ;_ end of PROGN
              ) ;_ end of IF
            ) ;_ end of IF
;;;The following is all the code needed if using a pagesetup to plot will actually work as intended:
            (IF (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[9]");was"1[678]"
              (PROGN
                (WRITE-LINE "(COMMAND \".PLOT\" \"NO\")" fp1);use a page setup and not a detailed plot configuration
                (WRITE-LINE
                  "(IF(EQ(getvar \"ctab\")\"Model\")(car (layoutlist))(getvar \"ctab\"))"
                  fp1
                )                       ;the layout to plot
                (WRITE-LINE page1 fp1)  ;the page setup name
                (WRITE-LINE plot_device fp1) ;the plot device name
                (WRITE-LINE "!pltoutfn" fp1) ;the plot filename quoted to allow spaces in name
                (WRITE-LINE "N" fp1)
                (WRITE-LINE "Y" fp1)
              ) ;_ end of PROGN
;;;The next code section is a detailed plot configuration which cannot use a page setup.  It is to work around the
;;;"invalid media configuration" bug associated with using page setups with command-line plots (scripts) in R16.
;;;Use page setups without detailed configuration of command-line plots whenever possible.
              (IF
                (AND (WCMATCH (SUBSTR (GETVAR "ACADVER") 1 2) "1[678]")
                                        ;was"1[678]"
                     (NOT (WCMATCH (STRCASE page1) "*HP*"))
                ) ;_ end of AND
                 (PROGN
                   (IF debug_bplot2k
                     (PROGN
                       (PRINC "\nPAGE1 (3)= ")
                       (PRINC page1)
                       (PRINC)
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                   (COND
                     ((WCMATCH (STRCASE page1) "*##X## ###DPI*")
                      (PROGN
                        (SETQ strcnt 1)
                        (WHILE
                          (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt)
                                        "##X## ###DPI*"
                               ) ;_ end of WCMATCH
                          ) ;_ end of NOT
                           (SETQ strcnt (1+ strcnt))
                        ) ;_ end of WHILE
                        (SETQ pagesize1s (SUBSTR page1 strcnt 2)
                              pagesize2s (SUBSTR page1 (+ strcnt 3) 2)
                              dpiresstr  (SUBSTR page1 (+ strcnt 6) 3)
                              pagesize1i (ATOI pagesize1s)
                              pagesize2i (ATOI pagesize2s)
                              dpiresint  (ATOI dpiresstr)
                        ) ;_ end of SETQ
                        (IF (EQ pagesize1i 85)
                          (SETQ pagesize1i 8.5)
                        ) ;_ end of IF
                        (IF (EQ pagesize2i 85)
                          (SETQ pagesize2i 8.5)
                        ) ;_ end of IF
                      ) ;_ end of PROGN
                     )
                     ((WCMATCH (STRCASE page1) "*##.##X##.## ###DPI*")
                      (PROGN
                        (SETQ strcnt 1)
                        (WHILE
                          (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt)
                                        "##.##X##.## ###DPI*"
                               ) ;_ end of WCMATCH
                          ) ;_ end of NOT
                           (SETQ strcnt (1+ strcnt))
                        ) ;_ end of WHILE
                        (SETQ pagesize1s (SUBSTR page1 strcnt 5)
                              pagesize2s (SUBSTR page1 (+ strcnt 6) 5)
                              dpiresstr  (SUBSTR page1 (+ strcnt 12) 3)
                              pagesize1i (ATOF pagesize1s)
                              pagesize2i (ATOF pagesize2s)
                              dpiresint  (ATOI dpiresstr)
                        ) ;_ end of SETQ
                        (IF (EQ pagesize1i 85)
                          (SETQ pagesize1i 8.5)
                        ) ;_ end of IF
                        (IF (EQ pagesize2i 85)
                          (SETQ pagesize2i 8.5)
                        ) ;_ end of IF
                      ) ;_ end of PROGN
                     ) ;_ end of IF
                     ((WCMATCH (STRCASE page1) "*##.#X##.# ###DPI*")
                      (PROGN
                        (SETQ strcnt 1)
                        (WHILE
                          (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt)
                                        "##.#X##.# ###DPI*"
                               ) ;_ end of WCMATCH
                          ) ;_ end of NOT
                           (SETQ strcnt (1+ strcnt))
                        ) ;_ end of WHILE
                        (SETQ pagesize1s (SUBSTR page1 strcnt 4)
                              pagesize2s (SUBSTR page1 (+ strcnt 5) 4)
                              dpiresstr  (SUBSTR page1 (+ strcnt 10) 3)
                              pagesize1i (ATOF pagesize1s)
                              pagesize2i (ATOF pagesize2s)
                              dpiresint  (ATOI dpiresstr)
                        ) ;_ end of SETQ
                        (IF (EQ pagesize1i 85)
                          (SETQ pagesize1i 8.5)
                        ) ;_ end of IF
                        (IF (EQ pagesize2i 85)
                          (SETQ pagesize2i 8.5)
                        ) ;_ end of IF
                      ) ;_ end of PROGN
                     ) ;_ end of IF
                     ((WCMATCH (STRCASE page1) "*#.#X#.# ###DPI*")
                      (PROGN
                        (SETQ strcnt 1)
                        (WHILE
                          (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt)
                                        "#.#X#.# ###DPI*"
                               ) ;_ end of WCMATCH
                          ) ;_ end of NOT
                           (SETQ strcnt (1+ strcnt))
                        ) ;_ end of WHILE
                        (SETQ pagesize1s (SUBSTR page1 strcnt 3)
                              pagesize2s (SUBSTR page1 (+ strcnt 4) 3)
                              dpiresstr  (SUBSTR page1 (+ strcnt 8) 3)
                              pagesize1i (ATOF pagesize1s)
                              pagesize2i (ATOF pagesize2s)
                              dpiresint  (ATOI dpiresstr)
                        ) ;_ end of SETQ
                        (IF (EQ pagesize1i 85)
                          (SETQ pagesize1i 8.5)
                        ) ;_ end of IF
                        (IF (EQ pagesize2i 85)
                          (SETQ pagesize2i 8.5)
                        ) ;_ end of IF
                      ) ;_ end of PROGN
                     ) ;_ end of IF
                     ((WCMATCH (STRCASE page1) "*##X## EX MS*")
                      (PROGN
                        (SETQ strcnt 1)
                        (WHILE
                          (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt)
                                        "##X## EX MS*"
                               ) ;_ end of WCMATCH
                          ) ;_ end of NOT
                           (SETQ strcnt (1+ strcnt))
                        ) ;_ end of WHILE
                        (SETQ pagesize1s (SUBSTR page1 strcnt 2)
                              pagesize2s (SUBSTR page1 (+ strcnt 3) 2)
                              dpiresstr  "300"
                              pagesize1i (ATOI pagesize1s)
                              pagesize2i (ATOI pagesize2s)
                              dpiresint  (ATOI dpiresstr)
                        ) ;_ end of SETQ
                        (IF (EQ pagesize1i 85)
                          (SETQ pagesize1i 8.5)
                        ) ;_ end of IF
                        (IF (EQ pagesize2i 85)
                          (SETQ pagesize2i 8.5)
                        ) ;_ end of IF
                      ) ;_ end of PROGN
                     )
                     (T
                      (PROGN
                        (SETQ pagesize1s
                               nil
                              pagesize2s
                               nil
                              dpiresstr nil
                              pagesize1i
                               nil
                              pagesize2i
                               nil
                              dpiresint nil
                        ) ;_ end of SETQ
                      ) ;_ end of PROGN
                     )
                   ) ;_ end of COND
                   (COND
                     ((AND pagesize1i
                           pagesize2i
                           dpiresint
                           (OR (WCMATCH plotr "TIFF*")
                               (WCMATCH plotr "PublishToWeb JPG")
                               (WCMATCH plotr "*PNG*")
                           ) ;_ end of or
                      ) ;_ end of AND
                      (SETQ bppaperwidth  (COND
                                            (T
                                             (RTOS (* pagesize1i dpiresint)
                                                   2
                                                   2
                                             ) ;_ end of RTOS
                                            )
                                          ) ;_ end of COND
                            bppaperwidth  (COND
                                            ((WCMATCH bppaperwidth "*#.##")
                                             bppaperwidth
                                            )
                                            ((WCMATCH bppaperwidth "*#.#")
                                             (STRCAT bppaperwidth "0")
                                            )
                                            ((WCMATCH bppaperwidth "*#")
                                             (STRCAT bppaperwidth ".00")
                                            )
                                          ) ;_ end of COND
                            bppaperheight (COND
                                            (T
                                             (RTOS (* pagesize2i dpiresint)
                                                   2
                                                   2
                                             ) ;_ end of RTOS
                                            )
                                          ) ;_ end of COND
                            bppaperheight (COND
                                            ((WCMATCH bppaperheight "*#.##")
                                             bppaperheight
                                            )
                                            ((WCMATCH bppaperheight "*#.#")
                                             (STRCAT bppaperheight "0")
                                            )
                                            ((WCMATCH bppaperheight "*#")
                                             (STRCAT bppaperheight ".00")
                                            )
                                          ) ;_ end of COND
                      ) ;_ end of SETQ
                      (SETQ plot_paper_size
                             (STRCAT pagesize1s
                                     "X"
                                     pagesize2s
                                     " "
                                     dpiresstr
                                     "dpi "
                                     (CHR 040)
                                     bppaperwidth
                                     " x "
                                     bppaperheight
                                     " Pixels"
                                     (CHR 041)
                             ) ;_ end of STRCAT
                      ) ;_ end of SETQ
                      (IF (NOT (EQ allayplt "1"))
                        (PROGN
                          (WRITE-LINE plot_paper_size fp1)		;Custom Raster Paper Size (for detailed plot configuration).
                          						;The exact name as constructed here must have been added to the plot device prior to running BPlot2K
                        ) ;_ end of PROGN
                      ) ;_ end of IF
                     )
                     ((WCMATCH plotr "Adobe PDF")
                      (COND
                        ((WCMATCH (STRCASE page1) "PDF 34X22 PS")
                         (SETQ
                           plot_paper_size
                            "PostScript Custom Page Size"
                         ) ;_ end of SETQ
                         (SETQ plot_units "Inches")
                        )
                        ((WCMATCH (STRCASE page1) "PDF 40X28 PS")
                         (SETQ plot_paper_size "ANSI F - 2")
                         (SETQ plot_units "Inches")
                        )
                      ) ;_ end of COND
                      (WRITE-LINE plot_paper_size fp1)
                      (WRITE-LINE plot_units fp1)
                     )
                     (T
                      (SETQ plot_paper_size
                             "34x22 288dpi (9792.00 x 6336.00 Pixels)"
                      ) ;_ end of SETQ
                      (SETQ             ;page1      plot_paper_size
                        pagesize1s (SUBSTR plot_paper_size 1 2)
                        pagesize2s (SUBSTR plot_paper_size 4 2)
                        dpiresstr  (SUBSTR plot_paper_size 7 3)
                        pagesize1i (ATOI pagesize1s)
                        pagesize2i (ATOI pagesize2s)
                        dpiresint  (ATOI dpiresstr)
                      ) ;_ end of SETQ
                      (SETQ bppaperwidth  (COND
;;;                                    ((EQ pagesize1i 42)
;;;                                      (RTOS(*(- pagesize1i 0.5) dpiresint)2 2))
;;;                                    ((EQ pagesize1i 36)
;;;                                      (RTOS(*(- pagesize1i 0.5) dpiresint)2 2))
                                            (T
                                             (RTOS (* pagesize1i dpiresint)
                                                   2
                                                   2
                                             ) ;_ end of RTOS
                                            )
                                          ) ;_ end of COND
                            bppaperwidth  (COND
                                            ((WCMATCH bppaperwidth "*#.##")
                                             bppaperwidth
                                            )
                                            ((WCMATCH bppaperwidth "*#.#")
                                             (STRCAT bppaperwidth "0")
                                            )
                                            ((WCMATCH bppaperwidth "*#")
                                             (STRCAT bppaperwidth ".00")
                                            )
                                          ) ;_ end of COND
                            bppaperheight (COND
;;;                                     ((EQ pagesize2i 30)
;;;                                       (RTOS(*(- pagesize2i 0.6) dpiresint)2 2))
;;;                                     ((EQ pagesize2i 24)
;;;                                       (RTOS(*(- pagesize2i 0.75) dpiresint)2 2))
                                            (T
                                             (RTOS (* pagesize2i dpiresint)
                                                   2
                                                   2
                                             ) ;_ end of RTOS
                                            )
                                          ) ;_ end of COND
                            bppaperheight (COND
                                            ((WCMATCH bppaperheight "*#.##")
                                             bppaperheight
                                            )
                                            ((WCMATCH bppaperheight "*#.#")
                                             (STRCAT bppaperheight "0")
                                            )
                                            ((WCMATCH bppaperheight "*#")
                                             (STRCAT bppaperheight ".00")
                                            )
                                          ) ;_ end of COND
                      ) ;_ end of SETQ
                      (IF (NOT (EQ allayplt "1"))
                        (PROGN
                          (WRITE-LINE plot_paper_size fp1)
                        ) ;_ end of PROGN
                      ) ;_ end of IF
                     )
                   ) ;_ end of COND
                   (COND						;Plot Orientation (for detailed plot configuration)
                     ((<= pagesize1i pagesize2i)
                      (SETQ plot_orientation "Portrait")
                     )
;;;            ((OR
;;;               (EQUAL(GETVAR "limmax")(LIST 30.0 42.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 28.0 40.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 24.0 36.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 22.0 34.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 17.0 22.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 11.0 17.0) 0.01)
;;;               (EQUAL(GETVAR "limmax")(LIST 8.5 11.0) 0.01)
;;;               )
;;;              (SETQ plot_orientation "Portrait"))
                     (T
                      (SETQ plot_orientation "Landscape")
                     )
                   ) ;_ end of COND
                   (SETQ plot_upside_down "No")				;Plot upside down? answer (for detailed plot configuration)
                   (IF (WCMATCH (STRCASE page1) "* MS*")		;Plot area (for detailed plot configuration)
                     (SETQ plot_area "Extents")
                     (PROGN
                       (SETQ plot_area "Window")
                       (IF (EQ bppaperwidth "10686.00")
                         (SETQ plot_window_llcor "0.125,0.19")
                         (IF
                           (AND custom-window-llcor
                                (WCMATCH plotwindow "1")
                           ) ;_ end of AND
                            (SETQ plot_window_llcor custom-window-llcor)
                            (SETQ plot_window_llcor
                                   "(IF(EQUAL(GETVAR \"limmin\")(LIST 0.0 0.0)0.1) \"0.0,0.0\" (GETVAR \"limmin\"))"
                            ) ;_ end of SETQ
                         ) ;_ end of IF
                       ) ;_ end of IF
;;;              (SETQ plot_window_llcor "(getvar\"limmin\")")
                       (SETQ window_urcor
                              (STRCAT (RTOS pagesize1i 2 2)
                                      ","
                                      (RTOS pagesize2i 2 2)
                              ) ;_ end of STRCAT
                       ) ;_ end of SETQ
                       (IF (EQ bppaperwidth "10686.00")
                         (SETQ plot_window_urcor "35.745,23.81")
                         (IF
                           (AND custom-window-urcor
                                (WCMATCH plotwindow "1")
                           ) ;_ end of AND
                            (SETQ plot_window_urcor custom-window-urcor)
                            (IF (> (ATOI (SUBSTR (GETVAR "ACADVER") 1 2))
                                   17
                                ) ;_ end of >
                              (SETQ plot_window_urcor
                                     "(IF(EQUAL(GETVAR \"limmax\")(LIST 34.0 22.0)0.1) \"34.0,22.0\" (GETVAR \"limmax\"))"
                              ) ;_ end of SETQ
                              (SETQ plot_window_urcor
                                     (STRCAT
                                       "(IF(AND pagesize1i pagesize2i(OR(EQ(GETVAR\"DIMSCALE\")0)(EQ(GETVAR\"DIMSCALE\")1)))"
                                       "(STRCAT(RTOS(+ pagesize1i(CAR(GETVAR \"limmin\")))2 2)\",\"(RTOS(+ pagesize2i(CADR(GETVAR \"limmin\")))2 2))"
                                       "(STRCAT(RTOS(CAR(GETVAR\"limmax\"))2 2)\",\"(RTOS(CADR(GETVAR\"limmax\"))2 2))"
                                       ")"
                                     ) ;_ end of STRCAT
                              ) ;_ end of SETQ
                            ) ;_ end of IF
                         ) ;_ end of IF
                       ) ;_ end of IF
;;;              (SETQ plot_window_urcor "(getvar\"limmax\")")
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                   (IF (NOT (EQ allayplt "1"))
                     (PROGN
                       (WRITE-LINE plot_orientation fp1)
                       (WRITE-LINE plot_upside_down fp1)
                       (WRITE-LINE plot_area fp1)
                       (IF (WCMATCH (STRCASE page1) "* MS*")
                         nil
                         (PROGN
                           (WRITE-LINE plot_window_llcor fp1)
                           (WRITE-LINE plot_window_urcor fp1)
                         ) ;_ end of PROGN
                       ) ;_ end of IF
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                   (COND						;Enter plot scale (Plotted pixels=drawing units) (for detailed plot configuration)
                     ((WCMATCH plotr "Adobe PDF")
                      (SETQ plot_scale "1=1")
                     )
                     (dpiresstr
                      (IF (WCMATCH page1 "*#scl *")
                        (PROGN
                          (COND
                            ((WCMATCH page1 "* ####scl *")
                             (SETQ pgstrcnt 2)
                             (WHILE
                               (NOT
                                 (WCMATCH (SUBSTR page1 pgstrcnt)
                                          "####scl *"
                                 ) ;_ end of WCMATCH
                               ) ;_ end of NOT
                                (SETQ pgstrcnt (1+ pgstrcnt))
                             ) ;_ end of WHILE
                             (SETQ
                               sclfactor
                                (ATOI (SUBSTR page1 pgstrcnt 4))
                             ) ;_ end of SETQ
                            )
                            ((WCMATCH page1 "* ###scl *")
                             (SETQ pgstrcnt 2)
                             (WHILE
                               (NOT (WCMATCH (SUBSTR page1 pgstrcnt)
                                             "###scl *"
                                    ) ;_ end of WCMATCH
                               ) ;_ end of NOT
                                (SETQ pgstrcnt (1+ pgstrcnt))
                             ) ;_ end of WHILE
                             (SETQ
                               sclfactor
                                (ATOI (SUBSTR page1 pgstrcnt 3))
                             ) ;_ end of SETQ
                            )
                            ((WCMATCH page1 "* ##scl *")
                             (SETQ pgstrcnt 2)
                             (WHILE
                               (NOT (WCMATCH (SUBSTR page1 pgstrcnt)
                                             "##scl *"
                                    ) ;_ end of WCMATCH
                               ) ;_ end of NOT
                                (SETQ pgstrcnt (1+ pgstrcnt))
                             ) ;_ end of WHILE
                             (SETQ
                               sclfactor
                                (ATOI (SUBSTR page1 pgstrcnt 2))
                             ) ;_ end of SETQ
                            )
                            ((WCMATCH page1 "* #scl *")
                             (SETQ pgstrcnt 2)
                             (WHILE
                               (NOT
                                 (WCMATCH (SUBSTR page1 pgstrcnt)
                                          "#scl *"
                                 ) ;_ end of WCMATCH
                               ) ;_ end of NOT
                                (SETQ pgstrcnt (1+ pgstrcnt))
                             ) ;_ end of WHILE
                             (SETQ
                               sclfactor
                                (ATOI (SUBSTR page1 pgstrcnt 1))
                             ) ;_ end of SETQ
                            )
                          ) ;_ end of COND
                          (SETQ plot_scale
                                 (STRCAT
                                   (ITOA (/ (ATOI dpiresstr) sclfactor))
                                   "=1"
                                 ) ;_ end of STRCAT
                          ) ;_ end of SETQ
                        ) ;_ end of PROGN
;;;                 (IF (AND (= pagesize1i 9.0)(= pagesize2i 9.0))
;;;                   (SETQ plot_scale "Fit")
                        (SETQ plot_scale (STRCAT dpiresstr "=1"))
;;;                 )
                      ) ;_ end of IF
                     )
;;;              ((AND (= pagesize1i 9.0)(= pagesize2i 9.0))
;;;                (SETQ plot_scale "Fit")
;;;              )
                     ((WCMATCH (STRCASE page1) "*400DPI*")
                      (SETQ plot_scale "400=1")
                     )
                     ((WCMATCH (STRCASE page1) "*288DPI*")
                      (SETQ plot_scale "288=1")
                     )
                     (T
                      (SETQ plot_scale "288=1")
                     )
                   ) ;_ end of COND
                   (SETQ plot_offset "Center")				;Enter plot offset (x,y) (for detailed plot configuration)
                   (SETQ plot_with_style "Yes")				;Plot with plot styles? (for detailed plot configuration)
                   (COND						;Enter plot style table name  (for detailed plot configuration)
                     ((WCMATCH plotr "Adobe PDF")
                      (SETQ plot_table_file "Standard.ctb")
                     )
;;;              ((WCMATCH (STRCASE page1) "*300DPI*")
;;;               (SETQ plot_table_file "TIFF 300dpi.ctb")
;;;              )
;;;              ((WCMATCH (STRCASE page1) "*400DPI*")
;;;               (SETQ plot_table_file "TIFF 400dpi.ctb")
;;;              )
                     (dpiresstr
                      (IF (WCMATCH plotr "PublishToWeb JPG")
                        (COND
                          ((WCMATCH page1
                                    (STRCAT "*" dpiresstr "dpi ML*")
                           ) ;_ end of WCMATCH
                           (SETQ plot_table_file
                                  (STRCAT "" ;"JPG "
                                          dpiresstr
                                          "dpi for McCracken and Lopez.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                          ((WCMATCH page1
                                    (STRCAT "*" dpiresstr "dpi MB*")
                           ) ;_ end of WCMATCH
                           (SETQ plot_table_file
                                  (STRCAT "" ;"JPG "
                                          dpiresstr
                                          "dpi for Myrtle Beach.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                          (T
                           (SETQ plot_table_file
                                  (STRCAT "" ;"JPG "
                                          dpiresstr
                                          "dpi.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                        ) ;_ end of COND
                        (COND
                          ((WCMATCH page1
                                    (STRCAT "*" dpiresstr "dpi ML*")
                           ) ;_ end of WCMATCH
                           (SETQ plot_table_file
                                  (STRCAT "" ;"TIFF "
                                          dpiresstr
                                          "dpi for McCracken and Lopez.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                          ((WCMATCH page1
                                    (STRCAT "*" dpiresstr "dpi MB*")
                           ) ;_ end of WCMATCH
                           (SETQ plot_table_file
                                  (STRCAT "" ;"TIFF "
                                          dpiresstr
                                          "dpi for Myrtle Beach.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                          (T
                           (SETQ plot_table_file
                                  (STRCAT "" ;"TIFF "
                                          dpiresstr
                                          "dpi.ctb"
                                  ) ;_ end of STRCAT
                           ) ;_ end of SETQ
                          )
                        ) ;_ end of COND
                      ) ;_ end of IF
                     )
                   ) ;_ end of COND
                   (COND						;Plot with lineweights? (for detailed plot configuration)
                     ((WCMATCH plotr "Adobe PDF")
                      (SETQ             ;plot_std_answers "Yes No No No"
                        plot_with_lineweights
                         "Yes"
                      ) ;_ end of SETQ
                     )
                     ((WCMATCH (STRCASE page1) "* MS")
                      (SETQ             ;plot_std_answers "Yes W"
                        plot_with_lineweights
                         "Yes"
                      ) ;_ end of SETQ
                     )
                     ((WCMATCH plotr "PublishToWeb JPG")
                      (SETQ             ;plot_std_answers "Yes No No No"
                        plot_with_lineweights
                         "Yes"
                      ) ;_ end of SETQ
                     )
                     (T
                      (SETQ             ;plot_std_answers "Yes No Yes No"
                        plot_with_lineweights
                         "Yes"
                      ) ;_ end of SETQ
                     )
                   ) ;_ end of COND
                   (SETQ plot_scale_lineweights "No")			;Scale lineweights with plot scale? (for detailed plot configuration)
                   (IF (WCMATCH (STRCASE page1) "*PPSL")		;Plot paperspace first? (for detailed plot configuration)
                     (PROGN
                       (IF debug_bplot2k
                         (ALERT (STRCAT "plot_paper_first = No\npage1 = "
                                        page1
                                ) ;_ end of STRCAT
                         ) ;_ end of ALERT
                       ) ;_ end of IF
                       (SETQ plot_paper_first "No")
                     ) ;_ end of PROGN
                     (PROGN
                       (IF debug_bplot2k
                         (ALERT
                           (STRCAT "plot_paper_first = Yes\npage1 = "
                                   page1
                           ) ;_ end of STRCAT
                         ) ;_ end of ALERT
                       ) ;_ end of IF
                       (SETQ plot_paper_first "Yes")
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                   (SETQ plot_hide_paper "No")				;Hide paperspace objects? (for detailed plot configuration)
                   (IF (NOT (EQ allayplt "1"))
                     (PROGN
                       (IF (WCMATCH (STRCASE page1) "*EX MS*")		;Enter plot scale (Plotted pixels=drawing units) (for detailed plot configuration)
                         (WRITE-LINE "fit" fp1)
                         (WRITE-LINE plot_scale fp1)
                       ) ;_ end of IF
                       (WRITE-LINE plot_offset fp1)			;Enter plot offset (x,y) (for detailed plot configuration)
                       (WRITE-LINE plot_with_style fp1)			;Plot with plot styles? (for detailed plot configuration)
                       (WRITE-LINE plot_table_file fp1)			;Enter plot style table name  (for detailed plot configuration)
                       (WRITE-LINE plot_with_lineweights fp1)		;Plot with lineweights? (for detailed plot configuration)
                       (WRITE-LINE plot_scale_lineweights fp1)		;Scale lineweights with plot scale? (for detailed plot configuration)
                       (IF (WCMATCH (STRCASE page1) "* MS*")
                         nil
                         (PROGN
                           (WRITE-LINE plot_paper_first fp1)		;Plot paperspace first? (for detailed plot configuration)
                           (WRITE-LINE plot_hide_paper fp1)		;Hide paperspace objects? (for detailed plot configuration)
                         ) ;_ end of PROGN
                       ) ;_ end of IF
                     ) ;_ end of PROGN
                   ) ;_ end of IF
                 ) ;_ end of PROGN
              ) ;_ end of IF
            ) ;_ end of IF
;;;End of work around
;;;        (setq output_fn
;;;              (IF (OR (WCMATCH (CADR split_fp) "* *")(WCMATCH (CADDR split_fp) "* *"))
;;;	        (strcat "\""
;;;                        plt_drv
;;;		        (CADR split_fp)
;;;		        "Plots\\"
;;;                        (IF frst_dir
;;;                          frst_dir
;;;                          "A\\"
;;;                        )
;;;		        (CADDR split_fp)
;;;		        ".plt\""
;;;	        ) ;_ end of strcat
;;;	        (strcat plt_drv
;;;		        (CADR split_fp)
;;;		        "Plots\\"
;;;                        (IF frst_dir
;;;                          frst_dir
;;;                          "A\\"
;;;                        )
;;;		        (CADDR split_fp)
;;;		        ".plt"
;;;	        ) ;_ end of strcat
;;;              )
;;;        )
            (SETQ plot_dwgfilepath plot_fn)
            (IF (AND (NOT (EQ allayplt "1"))
                     (NOT (WCMATCH (STRCASE plotr) "*SPOOL*"))
                ) ;_ end of AND
              (IF (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[9]")
                NIL
                (IF (EQ out_to "Fileout")
                  (PROGN
                    (IF (> (ATOI (GETVAR "ACADVER")) 15.05)
                      (PROGN
                        (WRITE-LINE
                          plot_fn
                          fp1
                        ) ;_ end of write-line
                      ) ;_ end of PROGN
                      (PROGN
                        (WRITE-LINE "Yes" fp1)
                        (WRITE-LINE
                          plot_fn
                          fp1
                        ) ;_ end of write-line
                      ) ;_ end of PROGN
                    ) ;_ end of IF
                  ) ;_ end of PROGN
                  (WRITE-LINE "No" fp1)
                ) ;_ end of if
              ) ;_ end of PROGN
            ) ;_ end of IF
            (SETQ plot_save_setup "Yes")
            (SETQ plot_proceed "Yes")
            (IF (AND (NOT (EQ allayplt "1"))(NOT (WCMATCH (SUBSTR (GETVAR "acadver") 1 2) "1[9]")))
              (PROGN
                (WRITE-LINE plot_save_setup fp1)
                (WRITE-LINE plot_proceed fp1)
              ) ;_ end of PROGN
            ) ;_ end of IF
            (IF (EQ allayplt "1")
              (PROGN
                (WRITE-LINE "(batlayplt)" fp1)
              ) ;_ end of PROGN
            ) ;_ end of IF
;;;	(pst_scr)
            (COND
              ((>= (STRLEN plotr) 14)
               (WRITE-LINE
                 (STRCAT
                   "(PROGN (IF dlog nil (load \"dlog\"))(setq fstr \"  "
                   plotr
                   " Plotted:  \")(if dlog (dlog)))"
                 ) ;_ end of strcat
                 fp1
               ) ;_ end of write-line
              )
              ((< (STRLEN plotr) 14)
               (SETQ pltdstr " Plotted")
               (WHILE
                 (< (STRLEN (STRCAT "  " plotr pltdstr ":  \"")) 28)
                  (SETQ pltdstr (STRCAT pltdstr "."))
               ) ;_ end of WHILE
               (WRITE-LINE
                 (STRCAT
                   "(PROGN (IF dlog nil (load \"dlog\"))(setq fstr \"  "
                   plotr
                   pltdstr
                   ":  \")(if dlog (dlog)))"
                 ) ;_ end of strcat
                 fp1
               ) ;_ end of write-line
              )
            ) ;_ end of COND
            (pst_scr)                   ;AUTOMATIC DPI RESOLUTION FIX (autodpifix name dpiresstr ishalf nil) is at the end of (pst_scr)
          ) ;_ end of progn
          (PROGN
            (IF (EQ allayplt "1")
              (PROGN
                (WRITE-LINE "(batlayplt)" fp1)
              ) ;_ end of PROGN
              (pst_scr)
            ) ;_ end of IF
          ) ;_ end of progn
        ) ;_ end of if
      ) ;_ end of PROGN
      (SETQ goplt nil)
    ) ;_ end of IF
  ) ;_ end of foreach
;;;  (WRITE-LINE "(SETVAR \"PLQUIET\" 0)" fp1)
  (IF (SETQ plots_remain
             (IF (EQ allayplt "1")
               (PROGN
                 (IF debug_doslib
                   (PRINC "\nDOS_23A ")
                 ) ;_ end of IF
                 (DOS_DIR
                   (STRCAT plt_drv
                           (CADR split_fp)
                           "Plots\\"
                           frst_dir
                           (CADDR split_fp)
                           "*.plt.tif"
                   ) ;_ end of STRCAT
                   0
                 ) ;_ end of DOS_DIR
               ) ;_ end of PROGN
               (PROGN
                 (IF debug_doslib
                   (PRINC "\nDOS_23B ")
                 ) ;_ end of IF
                 (IF (OR oldplt1 oldplt2)
                   (APPEND (DOS_DIR oldplt1 0) (DOS_DIR oldplt2 0))
                 ) ;_ end of IF
               ) ;_ end of PROGN
             ) ;_ end of IF
      ) ;_ end of SETQ
    (PROGN
      (SETQ rem_plot_names
             ""
            rem_count 0
      ) ;_ end of SETQ
      (FOREACH n plots_remain
        (IF (>= rem_count 15)
          (IF (AND rem_plot_names
                   (> (STRLEN rem_plot_names) 3)
                   (EQ (SUBSTR rem_plot_names
                               (- (STRLEN rem_plot_names) 2)
                               3
                       ) ;_ end of SUBSTR
                       "..."
                   ) ;_ end of EQ
              ) ;_ end of AND
            nil
            (SETQ rem_plot_names
                   (STRCAT
                     rem_plot_names
                     "\n\t(and "
                     (ITOA
                       (- (LENGTH plots_remain) rem_count)
                     ) ;_ end of ITOA
                     " more)..."
                   ) ;_ end of STRCAT
            ) ;_ end of SETQ
          ) ;_ end of IF
          (SETQ rem_plot_names (STRCAT rem_plot_names "\n\t" n))
        ) ;_ end of IF
        (SETQ rem_count (1+ rem_count))
      ) ;_ end of foreach
      (IF (AND (NOT jstscr) (NOT (EQ allayplt "1")))
        (ALERT
          (STRCAT
            "These plot files were not deleted!\n" rem_plot_names
            "\n\nBatch Plot will fail if it tries to overwrite these plot files."
            "\nThe most common reason old plot files are not deleted is that"
            "\nanother program is currently accessing the plot file.") ;_ end of STRCAT
 ;_ end of STRCAT
 ;_ end of STRCAT
 ;_ end of STRCAT
 ;_ end of STRCAT
        ) ;_ end of ALERT
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (= pltcnt 1)
    (PRINC
      (STRCAT "\010Done! Ready to plot " (NTH 0 pltlst) ". ")
    ) ;_ end of princ
    (PRINC
      (STRCAT "\010Done! Ready to plot "
              (ITOA pltcnt)
              " drawings. "
      ) ;_ end of strcat
    ) ;_ end of princ
  ) ;_ end of if
  (IF (EQ qtdn "Yes")
    (WRITE-LINE "QUIT Y" fp1)
    (IF (EQ (LENGTH pltlst) 1)
      (WRITE-LINE
        "(if(setq ent (ssget \"X\" (LIST(CONS 410 (GETVAR \"CTAB\"))(CONS 2 \"pltstamp\"))))(entdel(ssname ent 0)))"
        fp1
      ) ;_ end of WRITE-LINE
      (IF (OR
            (EQ (STRCAT cdwg ".DWG") (FINDFILE (LAST pltlst)))
            (EQ cdwg (FINDFILE (LAST pltlst)))
            (EQ (SUBSTR cdwg (- (STRLEN cdwg) 6)) "UNNAMED")
          ) ;_ end of or
        (PROGN
          (WRITE-LINE
            "(setq ent (ssget \"X\" (LIST(CONS 2 \"pltstamp\"))))(if ent(entdel(ssname ent 0)))"
            fp1
          ) ;_ end of WRITE-LINE
        ) ;_ end of progn
        (PROGN
          (WRITE-LINE
            "(setq ent (ssget \"X\" (LIST(CONS 2 \"pltstamp\"))))(if ent(entdel(ssname ent 0)))"
            fp1
          ) ;_ end of WRITE-LINE
;;;          (WRITE-LINE
;;;            "(IF (EQ (GETVAR \"SDI\") 0) (COMMAND \".Close\" (IF (NOT (EQ (GETVAR \"DBMOD\") 0))\"No\" (PRINC)))(PRINC))"
;;;            fp1
;;;          ) ;_ end of WRITE-LINE
;;;          (WRITE-LINE ".OPEN" fp1)
;;;          (WRITE-LINE "(if(eq(getvar\"dbmod\")0)(princ)\"Y\")" fp1)
          (WRITE-LINE
            "(if myopen_fun nil (load \"myopen_fun\" \"\\nFile MYOPEN_FUN.LSP not loaded! \"))"
            fp1
          ) ;_ end of WRITE-LINE
          (IF (WCMATCH (STRCASE cdwg) "*.DWG")
            (PROGN
              (SETQ fnamew    (quotepaths (fourslash cdwg) T)
                    fourslist (APPEND fourslist (LIST (CONS "cdwg1" n)))
              ) ;_ end of SETQ
              (WRITE-LINE (STRCAT "(myopen_fun \"" fnamew "\")") fp1)
            ) ;_ end of PROGN
            (PROGN
              (SETQ fnamew    (quotepaths (STRCAT (fourslash cdwg) ".dwg") T)
                    fourslist (APPEND fourslist (LIST (CONS "cdwg2" n)))
              ) ;_ end of SETQ
              (WRITE-LINE (STRCAT "(myopen_fun \"" cdwg ".DWG\")") fp1)
            ) ;_ end of PROGN
          ) ;_ end of IF
;;;          (IF (WCMATCH (STRCASE cdwg) "*.DWG")
;;;            (WRITE-LINE (STRCAT "\"" cdwg "\"") fp1)
;;;            (WRITE-LINE (STRCAT "\"" cdwg ".DWG\"") fp1)
;;;          ) ;_ end of if
        ) ;_ end of progn
      ) ;_ end of if
    ) ;_ end of if
  )                                     ;if
  (IF (AND (/= dontfixdpi "1") (FINDFILE bat_fname))
    (PROGN
      (SETQ ivmsg1
             "\nIrfanview is a free, full featured image editing/conversion application downloadable from the internet. If Irfanview is available, it's command-line functions are used here in a DOS batch file to reset the constant 72dpi resolution of AutoCAD raster plots to the requested dpi resolution.\n"
      ) ;_ end of SETQ
      (IF (AND fp1 (< (ATOI (SUBSTR (GETVAR "ACADVER") 1 2)) 17))
        (PROGN
          (WRITE-LINE
            "(IF have_Irfanview NIL (LOAD \"have_irfanview\" \"\\nFile HAVE_IRFANVIEW.LSP not loaded! \"))"
            fp1
          ) ;_ end of WRITE-LINE
          (WRITE-LINE
            (STRCAT
              "(IF (have_Irfanview)(PROGN(PRINC ivmsg1)(PRINC)(STARTAPP \""
              (quotepaths (fourslash bat_fname) T)
              "\")))"
            ) ;_ end of STRCAT
            fp1
          ) ;_ end of WRITE-LINE
        ) ;_ end of PROGN
      ) ;_ end of IF
      (CLOSE bf1)
    ) ;_ end of PROGN
  ) ;_ end of if
  (IF fp1
    (CLOSE fp1)
  ) ;_ end of if
  (SETQ scrnm (STRCAT pltdir lognm "BPLOT2K"))
  (IF ukword
    nil
    (LOAD "ukword")
  ) ;_ end of if
  (SETQ scrnow (ukword 1
                       "Yes No"
                       (STRCAT "Begin batch plot script \""
                               scrnm
                               ".SCR\" now? (Yes or No)"
                       ) ;_ end of strcat
                       (IF scrnow
                         scrnow
                         "Yes"
                       ) ;_ end of if
               ) ;_ end of ukword
  ) ;_ end of setq
  (IF (AND plotr
           (OR (WCMATCH plotr "*8825*") (WCMATCH plotr "*8830*"))
           (EQ out_to "Fileout")
           (NOT jstscr)
      ) ;_ end of and
    (write-xds (IF frst_dir
                 frst_dir
                 "A\\"
               ) ;_ end of if
    ) ;_ end of write-xds
  ) ;_ end of if
  (IF (AND scrnm (EQ scrnow "Yes"))
    (COMMAND "_.script" scrnm)
    (PROGN
      (rstdir)
      (PRINC (STRCAT "\nUse the SCRIPT command to run "
                     scrnm
                     ".SCR when ready."
             ) ;_ end of strcat
      ) ;_ end of princ
    ) ;_ end of progn
  ) ;_ end of if
  (SETVAR "luprec" bplots2k_luprec)
  (SETVAR "cmdecho" bplots2k_cmdecho)
  (SETVAR "expert" bplots2k_expert)
  (SETVAR "filedia" bplots2k_filedia)
  (SETVAR "osmode" bplots2k_osmode)
  (GRAPHSCR)
  (SETQ *error* pre_bplots2k_error)
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN mkpage2 ()
  (SETQ page2 nil)
  (SETQ pgcnt 1)
  (IF (WCMATCH (STRCASE page1) "*#.#*X*#.#*")
    (PROGN
      (WHILE (NOT (WCMATCH (SUBSTR page1 pgcnt 1) "#"))
        (SETQ pgcnt (1+ pgcnt))
      ) ;_ end of while
      (SETQ pgcnt1 (1- pgcnt)
            pg2_1  (SUBSTR page1 1 (1- pgcnt))
                                        ; text part in front of size numbers
      ) ;_ end of SETQ
      (WHILE (OR (WCMATCH (SUBSTR page1 pgcnt 1) "#")
                 (WCMATCH (SUBSTR page1 pgcnt 1) ".")
             ) ;_ end of OR
        (SETQ pgcnt (1+ pgcnt))
      ) ;_ end of while
      (SETQ pgcnt2  (1- pgcnt)
            pg2_sz1 (READ (SUBSTR page1 pgcnt1 (- pgcnt pgcnt1)))
      ) ;_ end of SETQ
      (IF
        (EQ (TYPE pg2_sz1) 'real)
         (SETQ pg2_sza (RTOS pg2_sz1 2 2)
;;;               pg2_sz1 (RTOS (/ pg2_sz1 2.0) 2 2)
         ) ;_ end of SETQ)
         (SETQ pg2_sz1 "")
      ) ;_ end of IF
      (WHILE (WCMATCH (SUBSTR page1 pgcnt1) "*#X#*")
        (SETQ pgcnt1 (1+ pgcnt1))
      ) ;_ end of WHILE
      (IF
        (AND
          (EQ (STRCASE (SUBSTR page1 pgcnt1 1)) "X")
          (EQ (TYPE (READ (SUBSTR page1 (1+ pgcnt1) 4))) 'real)
        ) ;_ end of AND
         (PROGN
           (SETQ pgcnt2 pgcnt1)
           (WHILE (AND (WCMATCH (SUBSTR page1 pgcnt2) "*# *")
                       (NOT (WCMATCH (SUBSTR page1 pgcnt2 1) " "))
                  ) ;_ end of AND
             (SETQ pgcnt2 (1+ pgcnt2))
           ) ;_ end of WHILE
           (SETQ pg2_szb (SUBSTR page1 (1+ pgcnt1) (- (1- pgcnt2) pgcnt1))
;;;                pg2_sz2 (RTOS
;;;                          (/ (READ pg2_szb) 2.0)
;;;                          2
;;;                           2
;;;                        ) ;_ end of RTOS
                 pg2_3   (SUBSTR page1 (1+ pgcnt2))
           ) ;_ end of SETQ
           (SETQ pg2_sz2 ""
                 pg2_3 ""
           ) ;_ end of SETQ
         ) ;_ end of PROGN
      ) ;_ end of IF
;;;      (SETQ page2 (STRCAT pg2_1 pg2_sz1 "x" pg2_sz2 pg2_3))
      (IF (AND pg2_sza
               pg2_szb
               (EQ (TYPE pg2_sza) 'str)
               (EQ (TYPE pg2_szb) 'str)
          ) ;_ end of AND
        (SETQ frst_dir (STRCAT (RTOS (READ pg2_sza) 2 0)
                               "x"
                               (RTOS (READ pg2_szb) 2 0)
                               "\\"
                       ) ;_ end of STRCAT
;;;              scnd_dir (STRCAT (RTOS (READ pg2_sz1) 2 0)
;;;                               "x"
;;;                               (RTOS (READ pg2_sz2) 2 0)
;;;                               "\\"
;;;                       ) ;_ end of STRCAT
        ) ;_ end of SETQ
      ) ;_ end of IF
    ) ;_ end of PROGN
    (PROGN
      (WHILE (AND (/= (TYPE (READ (SUBSTR page1 pgcnt 1))) 'int)
                  (EQ (TYPE (SUBSTR page1 pgcnt 1)) 'str)
             ) ;_ end of and
        (SETQ pgcnt (1+ pgcnt))
      ) ;_ end of while
      (SETQ pgcnt1 (1- pgcnt)
            pg2_1  (SUBSTR page1 1 pgcnt1)
      ) ;_ end of SETQ
      (WHILE (EQ (TYPE (READ (SUBSTR page1 pgcnt 1))) 'int)
        (SETQ pgcnt (1+ pgcnt))
      ) ;_ end of while
      (SETQ pgcnt2  (1- pgcnt)
            pg2_sz1 (READ (SUBSTR page1 pgcnt1 (- pgcnt pgcnt1)))
      ) ;_ end of SETQ
      (IF (EQ (TYPE pg2_sz1) 'int)
        (SETQ pg2_sza (ITOA pg2_sz1)
;;;              pg2_sz1 (RTOS (/ pg2_sz1 2.0) 2 0)
        ) ;_ end of SETQ
        (SETQ pg2_sz1 "")
      ) ;_ end of IF
      (IF
        (AND
          (EQ (STRCASE (SUBSTR page1 (+ pgcnt1 3) 1)) "X")
          (EQ (TYPE (READ (SUBSTR page1 (+ pgcnt1 4) 2))) 'int)
        ) ;_ end of AND
         (SETQ pg2_szb (SUBSTR page1 (+ pgcnt1 4) 2)
;;;               pg2_sz2 (RTOS
;;;                         (/ (READ pg2_szb) 2.0)
;;;                         2
;;;                         0
;;;                       ) ;_ end of RTOS
               pg2_3   (SUBSTR page1 (+ pgcnt1 6))
         ) ;_ end of SETQ
         (SETQ pg2_sz2 ""
               pg2_3 ""
         ) ;_ end of SETQ
      ) ;_ end of IF
;;;      (SETQ page2 (STRCAT pg2_1 pg2_sz1 "x" pg2_sz2 pg2_3))
      (IF (AND pg2_sza
               pg2_szb
               (EQ (TYPE pg2_sza) 'str)
               (EQ (TYPE pg2_szb) 'str)
          ) ;_ end of AND
        (SETQ frst_dir (STRCAT pg2_sza "x" pg2_szb "\\")
;;;              scnd_dir (STRCAT pg2_sz1 "x" pg2_sz2 "\\")
        ) ;_ end of SETQ
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (MEMBER page2 setupslst)
    (SETQ found_pg2 T)
    (SETQ found_pg2 nil)
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN mkpltdirs ()
  (SETQ dwg_drv (CAR split_fp))
  (SETQ plt_dir (SUBSTR (CADR split_fp) 2))
  (SETQ strndx 1
        prvstrndx 1
        dir_lst nil
  ) ;_ end of SETQ
  (WHILE (WCMATCH plt_dir "*\\*")
    (WHILE
      (WCMATCH (SUBSTR plt_dir strndx) "*\\*")
       (SETQ strndx (1+ strndx))
    ) ;_ end of while
    (SETQ dir_lst (APPEND (LIST (SUBSTR plt_dir strndx)) dir_lst))
    (SETQ prevndx (- strndx 2))
    (SETQ strndx 1)
    (SETQ plt_dir (SUBSTR plt_dir 1 prevndx))
  ) ;_ end of while
  (IF (AND (/= (NTH 1 split_fp) "") (/= (NTH 1 split_fp) "\\"))
    (SETQ dir_lst (APPEND (LIST (SUBSTR plt_dir strndx)) dir_lst))
    (SETQ dir_lst nil)
  ) ;_ end of if
  (IF debug_doslib
    (PRINC "\nDOS_25 ")
  ) ;_ end of IF
  (DOS_DRIVE plt_drv)
  (DOS_CHDIR "\\")
  (FOREACH n dir_lst
    (DOS_MKDIR n)
    (DOS_CHDIR n)
  ) ;_ end of foreach
  (DOS_MKDIR "Plots")
  (DOS_CHDIR "Plots")
  (IF frst_dir
    nil
    (mkpage2)
  ) ;_ end of IF
  (DOS_MKDIR (IF frst_dir
               frst_dir
               "A"
             ) ;_ end of IF
  ) ;_ end of DOS_MKDIR
  (DOS_DRIVE dwg_drv)
  (DOS_CHDIR "\\")
  (DOS_CHDIR (NTH 1 split_fp))
  (IF debug_doslib
    (PRINC "\nDOS_25 ")
  ) ;_ end of IF
) ;_ end of defun
;;;********************************************************************
(DEFUN pst_scr ()
  (IF (AND pststr (/= pststr ""))
    (IF (EQ (SUBSTR pststr 1 8) "filename")
      (PROGN
        (SETQ pstfil (FINDFILE (SUBSTR pststr 10)))
        (IF pstfil
          (PROGN
            (SETQ opstf (OPEN pstfil "r"))
            (WHILE
              (SETQ pflin (READ-LINE opstf))
               (WRITE-LINE pflin fp1)
            ) ;_ end of while
            (CLOSE opstf)
          ) ;_ end of progn
        ) ;_ end of if
      ) ;_ end of progn
      (PROGN                            ;permits one leading <CR>
        (IF (WCMATCH pststr "\\n*")
          (PROGN
            (WRITE-LINE "" fp1)
            (WRITE-LINE (SUBSTR pststr 3) fp1)
          ) ;_ end of progn
          (WRITE-LINE pststr fp1)
        ) ;_ end of if
;;; THIS NEEDS WORK TO PERMIT MULTIPLE EMBEDDED <CR>s
;;;        (if (wcmatch pststr "*\n*")
;;;          (progn
;;;            (setq orig_pststr pststr
;;;                  pststrlen (strlen pststr)
;;;                  pstcnt 1
;;;            )
;;;            (while (wcmatch pststr "*\n*")
;;;              (setq pststr (substr pststr 1 (- pststrlen pstcnt)))
;;;            )
;;;          )
;;;          (write-line pststr fp1)
;;;        )
      ) ;_ end of progn
    ) ;_ end of if
  ) ;_ end of if
;;;THIS NEXT PROGN CALLS THE AUTOMATIC OR .BAT IRFANVIEW DPI FIX FOR TIFF PLOTS
;;;THEY ARE HERE BECAUSE THEY CANNOT RUN UNTIL AFTER THE PLOT IS WRITTEN (PLOTS FOR .BAT)
  (IF (OR jstscr (EQ allayplt "1"))
    NIL
  (PROGN
    (IF (OR
          dpiresstr
          (WCMATCH
            (STRCASE page1) "* ###DPI *"
          )
        )
;;;        (OR
;;;          (WCMATCH (STRCASE imgext) "TIF")
;;;          (WCMATCH (STRCASE imgext) "PNG")
;;;          (WCMATCH (STRCASE imgext) "JPG")
;;;        ) ;_ end of OR
      (IF (AND (NOT (WCMATCH (STRCASE plotr) "*SPOOL*"))
               (>=(ATOI(SUBSTR(GETVAR "ACADVER")1 2))17)
               pltdir
          )
        (PROGN
          (SETQ this_pltfn (fourslash this_pltfn) fourslist (APPEND fourslist (list (CONS "this_pltfn1" this_pltfn))))
        (WRITE-LINE
          (STRCAT
            "(autodpifix "             ;(autodpifix name dpiresstr ishalf nil)
            "(STRCAT "
            this_pltfn
;;;            "\" \"."
;;;            imgext
            "\") "
            "\""
            (COND
              (dpiresstr dpiresstr)
              ((WCMATCH (STRCASE page1) "* ###DPI *")
               (SETQ strcnt 1)
               (WHILE (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt) "###DPI *"))
                 (SETQ strcnt (1+ strcnt))
               )
               (SETQ thisdpistr (SUBSTR page1 strcnt 3)))
              (T "288")
            )
            "\""
            (IF (EQ halfdpi "1")
              " T"
              " NIL"
            ) ;_ end of IF
            (IF nolayout
              " T"
              " NIL"
            ) ;_ end of IF
            ")"
          ) ;_ end of STRCAT
          fp1
        ) ;_ end of WRITE-LINE
        )
        (PROGN
          (SETQ fourslist (APPEND fourslist (list (CONS "this_pltdir" pltdir))))
          (SETQ fourslist (APPEND fourslist (list (CONS "this_pltfn2" pltfn))))
        (WRITE-LINE
          (STRCAT
            "(put_dpibat \""             ;(put_dpibat lognm bplotscriptdir name dpiresstr ishalf)
            lognm
            "\" \""
            (fourslash this_pltdir)
            "\" "
            (fourslash this_pltfn)
            "\" \""
            (COND
              (dpiresstr dpiresstr)
              ((WCMATCH (STRCASE page1) "* ###DPI *")
               (SETQ strcnt 1)
               (WHILE (NOT (WCMATCH (SUBSTR (STRCASE page1) strcnt) "###DPI *"))
                 (SETQ strcnt (1+ strcnt))
               )
               (SETQ thisdpistr (SUBSTR page1 strcnt 3)))
              (T "288")
            )
            "\""
            (IF (EQ halfdpi "1")
              " T"
              " NIL"
            ) ;_ end of IF
            ")"
          ) ;_ end of STRCAT
          fp1
        ) ;_ end of WRITE-LINE
        )
      ) ;_ end of IF
    ) ;_ end of IF
  ) ;_ end of PROGN
    )
) ;_ end of defun
;;;********************************************************************
(DEFUN write-xds (pltlocn /)
  (IF pltlst
    (PROGN
      (IF debug_doslib
        (PRINC "\nDOS_26 ")
      ) ;_ end of IF
      (SETQ pltsplit (DOS_SPLITPATH (CAR pltlst)))
      (IF debug_doslib
        (PRINC "\nDOS_26 ")
      ) ;_ end of IF
      (IF (AND
            (SETQ xds-file
                   (OPEN
                     (STRCAT
                       plt_drv
                       (CADR pltsplit)
                       "Plots\\"
                       pltlocn
                       (CADDR pltsplit)
                       ".xds"
                     ) ;_ end of STRCAT
                     "w"
                   ) ;_ end of OPEN
            ) ;_ end of SETQ
            job_number
          ) ;_ end of AND
        (PROGN
          (WRITE-LINE "[JOB]" xds-file)
          (WRITE-LINE "VERSION=4" xds-file)
          (WRITE-LINE
            (STRCAT "NAME="
                    (ITOA (LENGTH pltlst))
                    " "
                    (SUBSTR pltlocn 1 (1- (STRLEN pltlocn)))
                    " Plots, "
                    (CADDR (DOS_SPLITPATH (CAR pltlst)))
                    " to "
                    (CADDR (DOS_SPLITPATH (LAST pltlst)))
            ) ;_ end of strcat
            xds-file
          ) ;_ end of write-line
          (WRITE-LINE
            (STRCAT "ACCOUNT=" (RTOS job_number 2 1))
            xds-file
          ) ;_ end of WRITE-LINE
          (WRITE-LINE "COPIES=1" xds-file)
          (WRITE-LINE "PRIORITY=5" xds-file)
          (WRITE-LINE "COLLATION=TRUE" xds-file)
          (WRITE-LINE "BANNER=FALSE" xds-file)
          (WRITE-LINE "MEDIAMISMATCH=SCALE" xds-file)
          (WRITE-LINE "PLOTNESTING=OFF" xds-file)
          (WRITE-LINE "PAGECOMPENABLE=FALSE" xds-file)
          (WRITE-LINE "PAGECOMPPAPER=ANSI_E" xds-file)
          (WRITE-LINE "PAGECOMPMEDIATYPE=ANY" xds-file)
          (WRITE-LINE "PAGECOMPMEDIASOURCE=AUTO" xds-file)
          (WRITE-LINE "FOLDER=BYPASS" xds-file)
          (WRITE-LINE "FOLDING=BYPASS" xds-file)
          (WRITE-LINE
            (STRCAT "FILECOUNT=" (RTOS (LENGTH pltlst) 2 0))
            xds-file
          ) ;_ end of WRITE-LINE
          (WRITE-LINE "" xds-file)
          (WRITE-LINE "[LABEL]" xds-file)
          (WRITE-LINE "LABELUSED=FALSE" xds-file)
          (WRITE-LINE "LABELSTRING=" xds-file)
          (WRITE-LINE "LABELFONT=HP Stick Font" xds-file)
          (WRITE-LINE "LABELSIZE=14" xds-file)
          (WRITE-LINE "LABELROTATE=90" xds-file)
          (WRITE-LINE "LABELSHADING=100" xds-file)
          (WRITE-LINE "LABELLOCX=TRAILING" xds-file)
          (WRITE-LINE "LABELABSX=0.0000" xds-file)
          (WRITE-LINE "LABELLOCY=BOTTOM" xds-file)
          (WRITE-LINE "LABELABSY=0.0000" xds-file)
          (WRITE-LINE "LABELUNITS=INCH" xds-file)
          (WRITE-LINE "" xds-file)
          (WRITE-LINE "[STAMP]" xds-file)
          (WRITE-LINE "VERSION=1" xds-file)
          (WRITE-LINE "STAMPUSED=FALSE" xds-file)
          (WRITE-LINE "RASTERID=" xds-file)
          (WRITE-LINE "RASTERSCALEMODE=RELATIVE" xds-file)
          (WRITE-LINE "RASTERSCALING=100" xds-file)
          (WRITE-LINE "RASTERROTATE=90" xds-file)
          (WRITE-LINE "RASTERLOCX=CENTER" xds-file)
          (WRITE-LINE "RASTERABSX=0.0000" xds-file)
          (WRITE-LINE "RASTERLOCY=CENTER" xds-file)
          (WRITE-LINE "RASTERABSY=0.0000" xds-file)
          (WRITE-LINE "STAMPUNITS=INCH" xds-file)
          (WRITE-LINE "" xds-file)
          (SETQ pltcnt 0)
          (FOREACH n pltlst
            (IF debug_doslib
              (PRINC "\nDOS_27 ")
            ) ;_ end of IF
            (SETQ xds_split (DOS_SPLITPATH n))
            (IF debug_doslib
              (PRINC "\nDOS_27 ")
            ) ;_ end of IF
            (WRITE-LINE
              (STRCAT "[FILE"
                      (COND
                        ((EQ pltcnt 0) "000")
                        ((< pltcnt 10) (STRCAT "00" (ITOA pltcnt)))
                        ((< pltcnt 100) (STRCAT "0" (ITOA pltcnt)))
                        ((< pltcnt 1000) (ITOA pltcnt))
                      ) ;_ end of COND
                      "]"
              ) ;_ end of strcat
              xds-file
            ) ;_ end of write-line
            (WRITE-LINE "VERSION=3" xds-file)
            (WRITE-LINE
              (IF (OR (WCMATCH (CADR split_fp) "* *")
                      (WCMATCH (CADDR split_fp) "* *")
                  ) ;_ end of OR
                (STRCAT "FILEPATH="
                        "\""
                        plt_drv
                        (CADR xds_split)
                        "Plots\\"
                        pltlocn
                        (CADDR xds_split)
                        "\""            ;".plt\""
                ) ;_ end of strcat
                (STRCAT "FILEPATH="
                        plt_drv
                        (CADR xds_split)
                        "Plots\\"
                        pltlocn
                        (CADDR xds_split)
                        "\""            ;".plt"
                ) ;_ end of strcat
              ) ;_ end of IF
              xds-file
            ) ;_ end of write-line
            (WRITE-LINE "PDL=AUTO" xds-file)
            (WRITE-LINE "MEDIASOURCE=AUTO" xds-file)
            (WRITE-LINE "MEDIASIZE=ANY" xds-file)
            (WRITE-LINE "MEDIATYPE=PAPER" xds-file)
            (WRITE-LINE "SCALINGTYPE=DISABLED" xds-file)
            (WRITE-LINE "SCALINGPERCENT=100" xds-file)
            (WRITE-LINE "AUTOROTATE=TRUE" xds-file)
            (WRITE-LINE "ROTATION=0" xds-file)
            (WRITE-LINE "JUSTTYPEX=CENTER" xds-file)
            (WRITE-LINE "JUSTDISTX=0.0000" xds-file)
            (WRITE-LINE "JUSTTYPEY=CENTER" xds-file)
            (WRITE-LINE "JUSTDISTY=0.0000" xds-file)
            (WRITE-LINE "JUSTUNITS=INCH" xds-file)
            (WRITE-LINE "MIRRORX=FALSE" xds-file)
            (WRITE-LINE "MIRRORY=FALSE" xds-file)
            (WRITE-LINE "" xds-file)
            (WRITE-LINE
              (STRCAT "[LABEL"
                      (COND
                        ((EQ pltcnt 0) "000")
                        ((< pltcnt 10) (STRCAT "00" (ITOA pltcnt)))
                        ((< pltcnt 100) (STRCAT "0" (ITOA pltcnt)))
                        ((< pltcnt 1000) (ITOA pltcnt))
                      ) ;_ end of COND
                      "]"
              ) ;_ end of strcat
              xds-file
            ) ;_ end of write-line
            (WRITE-LINE "LABELUSED=FALSE" xds-file)
            (WRITE-LINE "LABELSTRING=" xds-file)
            (WRITE-LINE "LABELFONT=HP Stick Font" xds-file)
            (WRITE-LINE "LABELSIZE=14" xds-file)
            (WRITE-LINE "LABELROTATE=90" xds-file)
            (WRITE-LINE "LABELSHADING=100" xds-file)
            (WRITE-LINE "LABELLOCX=TRAILING" xds-file)
            (WRITE-LINE "LABELABSX=0.0000" xds-file)
            (WRITE-LINE "LABELLOCY=BOTTOM" xds-file)
            (WRITE-LINE "LABELABSY=0.0000" xds-file)
            (WRITE-LINE "LABELUNITS=INCH" xds-file)
            (WRITE-LINE "" xds-file)
            (WRITE-LINE
              (STRCAT "[STAMP"
                      (COND
                        ((EQ pltcnt 0) "000")
                        ((< pltcnt 10) (STRCAT "00" (ITOA pltcnt)))
                        ((< pltcnt 100) (STRCAT "0" (ITOA pltcnt)))
                        ((< pltcnt 1000) (ITOA pltcnt))
                      ) ;_ end of COND
                      "]"
              ) ;_ end of strcat
              xds-file
            ) ;_ end of write-line
            (WRITE-LINE "VERSION=1" xds-file)
            (WRITE-LINE "STAMPUSED=FALSE" xds-file)
            (WRITE-LINE "RASTERID=" xds-file)
            (WRITE-LINE "RASTERSCALEMODE=RELATIVE" xds-file)
            (WRITE-LINE "RASTERSCALING=100" xds-file)
            (WRITE-LINE "RASTERROTATE=90" xds-file)
            (WRITE-LINE "RASTERLOCX=CENTER" xds-file)
            (WRITE-LINE "RASTERABSX=0.0000" xds-file)
            (WRITE-LINE "RASTERLOCY=CENTER" xds-file)
            (WRITE-LINE "RASTERABSY=0.0000" xds-file)
            (WRITE-LINE "STAMPUNITS=INCH" xds-file)
            (WRITE-LINE "" xds-file)
            (WRITE-LINE
              (STRCAT "[PAGECOMP"
                      (COND
                        ((EQ pltcnt 0) "000")
                        ((< pltcnt 10) (STRCAT "00" (ITOA pltcnt)))
                        ((< pltcnt 100) (STRCAT "0" (ITOA pltcnt)))
                        ((< pltcnt 1000) (ITOA pltcnt))
                      ) ;_ end of COND
                      "]"
              ) ;_ end of strcat
              xds-file
            ) ;_ end of write-line
            (WRITE-LINE "VERSION=1" xds-file)
            (WRITE-LINE "PAGECOMPSIZE=ANY" xds-file)
            (WRITE-LINE "PAGECOMPSCALE=FALSE" xds-file)
            (WRITE-LINE "PAGECOMPROTATE=0" xds-file)
            (WRITE-LINE "PAGECOMPPOSX=0.0000" xds-file)
            (WRITE-LINE "PAGECOMPPOSY=0.0000" xds-file)
            (WRITE-LINE "PAGECOMPUNITS=INCH" xds-file)
            (WRITE-LINE "" xds-file)
            (SETQ pltcnt (1+ pltcnt))
          ) ;_ end of foreach
          (CLOSE xds-file)
          (PRINC
            (STRCAT
              "\nXDS File "
              plt_drv
              (CADR pltsplit)
              "Plots\\"
              pltlocn
              (CADDR pltsplit)
              ".xds created! "
            ) ;_ end of STRCAT
          ) ;_ end of PRINC
          (PRINC)
        ) ;_ end of PROGN
        (PRINC "\nUnable to create XDS file! ")
      ) ;_ end of IF
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;********************************************************************
(DEFUN c:itt ()
  (SETQ laylist (DICTSEARCH (NAMEDOBJDICT) "ACAD_LAYOUT"))
  (SETQ index 0)
  (WHILE (AND (/= (CDR (NTH index laylist)) "Layout1")
              (/= (NTH index laylist) nil)
         ) ;_ end of and
    (SETQ index (+ index 1))
    (IF (NTH (+ index 1) laylist)
      (SETQ modellist (ENTGET (CDR (NTH (+ index 1) laylist))))
    ) ;_ end of if
  ) ;_ end of while
) ;_ end of defun
;;;********************************************************************
(DEFUN wait_spin ()
  (PRINC (STRCAT "\010" waitic))
  (PRINC)
  (COND
    ((AND (EQ waitic "|") (EQ ticsid 1)) (SETQ waitic "/"))
    ((EQ waitic "/")
     (SETQ waitic "-"
           ticsid 2
     ) ;_ end of setq
    )
    ((EQ waitic "-") (SETQ waitic "|"))
    ((AND (EQ waitic "|") (EQ ticsid 2)) (SETQ waitic "\\"))
    ((EQ waitic "\\")
     (SETQ waitic "|"
           ticsid 1
     ) ;_ end of setq
    )
  ) ;_ end of cond
) ;_ end of defun
;;;********************************************************************
(DEFUN c:curplts ()
  (SETQ curpltsfolder (STRCAT (GETVAR "dwgprefix") "Plots\\"))
  (IF debug_doslib
    (PRINC "\nDOS_28 ")
  ) ;_ end of IF
  (SETQ curplts_split (DOS_SPLITPATH curpltsfolder))
  (IF debug_doslib
    (PRINC "\nDOS_28 ")
  ) ;_ end of IF
;;;  (dos_drive (car curplts_split))
;;;  (dos_chdir "\\")
;;;  (dos_chdir curpltsfolder)
  (STARTAPP "explorer" curpltsfolder)
  (PRINC)
) ;_ end of defun
;;;********************************************************************
(DEFUN batlayplt (
;;;                  plot_device
;;;                  plot_paper_size
;;;                  plot_units
;;;                  plot_orientation
;;;                  plot_upside_down
;;;                  plot_area
;;;                  plot_view_name
;;;                  plot_window_llcor
;;;                  plot_window_urcor
;;;                  plot_scale
;;;                  plot_offset
;;;                  plot_with_style
;;;                  plot_table_file
;;;                  plot_std_answers
;;;                  plot_dwgfilepath
;;;                  plot_save_setup
                  / opnpre_fil preline_lst opnpst_fil pstline_lst)
  (SETVAR "CMDECHO" 1)
  (SETQ layout_count 0)
  (IF (OR
        (NOT
          (AND
;;;          plot_layout
            plot_device                 ;device
            plot_paper_size             ;paper size
            (IF (WCMATCH plotr "Adobe PDF")
              plot_units                ;units
              T
            ) ;_ end of IF
            plot_orientation            ;orientation
            plot_upside_down            ;upside down?
            plot_scale                  ;plot scale
            plot_offset                 ;plot offset
            plot_with_style             ;plot w/ plot styles?
            plot_table_file             ;style table file
            plot_with_lineweights       ;plot w/ plot lineweights?
            plot_scale_lineweights      ;scale lineweights with plot scale?
            plot_paper_first            ;plot paper space first?
            plot_hide_paper             ;hide paper space objects?
            plot_dwgfilepath            ;plot filename and path
            plot_save_setup             ;save to page setup?
            plot_proceed                ;proceed with plot?
          ) ;_ end of AND
        ) ;_ end of NOT
        debug_bplot2k
      ) ;_ end of OR
    (ALERT (STRCAT "plot_layout = "
                   (IF plot_layout
                     plot_layout
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_device = "
                   (IF plot_device
                     plot_device
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_paper_size = "
                   (IF plot_paper_size
                     plot_paper_size
                     "NIL"
                   ) ;_ end of IF
                   "\nbppaperwidth = "
                   (IF bppaperwidth
                     bppaperwidth
                     "NIL"
                   ) ;_ end of IF
                   "\nbppaperheight = "
                   (IF bppaperheight
                     bppaperheight
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_area = "
                   (IF plot_area
                     plot_area
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_window_llcor = "
                   (IF plot_window_llcor
                     plot_window_llcor
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_window_urcor = "
                   (IF plot_window_urcor
                     plot_window_urcor
                     "NIL"
                   ) ;_ end of IF
                   (IF (WCMATCH plotr "Adobe PDF")
                     (STRCAT "\nplot_units = "
                             (IF plot_units
                               plot_units
                               "NIL"
                             ) ;_ end of IF
                     ) ;_ end of STRCAT
                     ""
                   ) ;_ end of IF
                   "\nplot_orientation = "
                   (IF plot_orientation
                     plot_orientation
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_upside_down = "
                   (IF plot_upside_down
                     plot_upside_down
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_scale = "
                   (IF plot_scale
                     plot_scale
                     "NIL"
                   )                    ;plot scale
                   "\nplot_offset = "
                   (IF plot_offset
                     plot_offset
                     "NIL"
                   )                    ;plot offset
                   "\nplot_with_style = "
                   (IF plot_with_style
                     plot_with_style
                     "NIL"
                   )                    ;plot w/ plot styles?
                   "\nplot_table_file = "
                   (IF plot_table_file
                     plot_table_file
                     "NIL"
                   )                    ;style table file
                   "\nplot_with_lineweights = "
                   (IF plot_with_lineweights
                     plot_with_lineweights
                     "NIL"
                   )                    ;plot w/ plot lineweights?
                   "\nplot_scale_lineweights = "
                   (IF plot_scale_lineweights
                     plot_scale_lineweights
                     "NIL"
                   )                    ;scale lineweights with plot scale?
                   "\nplot_paper_first = "
                   (IF plot_paper_first
                     plot_paper_first
                     "NIL"
                   )                    ;plot paper space first?
                   "\nplot_hide_paper = "
                   (IF plot_hide_paper
                     plot_hide_paper
                     "NIL"
                   )                    ;hide paper space objects?
                   "\nplot_dwgfilepath = "
                   (IF plot_dwgfilepath
                     plot_dwgfilepath
                     "NIL"
                   ) ;_ end of IF
                   "\nplot_save_setup = "
                   (IF plot_save_setup
                     plot_save_setup
                     "NIL"
                   )                    ;save to page setup?
                   "\nplot_proceed = "
                   (IF plot_proceed
                     plot_proceed
                     "NIL"
                   )                    ;proceed with plot?
           ) ;_ end of STRCAT
    ) ;_ end of ALERT
  ) ;_ end of IF
  (IF (= include_plbl "1")
    (PROGN
      (IF c:lbl
        nil
        (LOAD "lbl" "\nFile LBL.LSP not loaded! ")
      ) ;_ end of if
    ) ;_ end of PROGN
  ) ;_ end of IF
  (if autodpifix nil (load "autodpifix"))
  (if check_for_doslib nil (load "check_for_doslib"))
  (check_for_doslib)
  (IF dlog nil (load "dlog"))(setq fstr "  TIFF Version 6 (CCITT G4 2D Compression) Plotted:  ")
  (IF update_title NIL (LOAD "update_title" "\nFile UPDATE_TITLE.LSP not loaded! "))
  (WHILE (< layout_count (LENGTH (LAYOUTLIST)))
    (SETQ plot_layout (NTH layout_count (LAYOUTLIST)))
    (SETVAR "CTAB" plot_layout)
    (c:lbl)
    (IF (AND update_title
             (OR (EQ (TYPE update_title) 'usubr)
                 (EQ (TYPE update_title) 'subr)
             ) ;_ end of OR
        ) ;_ end of AND
      (update_title)
    ) ;_ end of IF
    (IF (EQ force_wcs "1")
      (IF (EQ (GETVAR "WORLDUCS") 1)
        nil
        (COMMAND "UCS" "W")
      ) ;_ end of IF
    ) ;_ end of IF
    (IF debug_doslib
      (PRINC "\nDOS_29 ")
    ) ;_ end of IF
    (SETQ dwg_split_fp     (DOS_SPLITPATH
                             (STRCAT (GETVAR "dwgprefix") (GETVAR "dwgname"))
                           ) ;_ end of DOS_SPLITPATH
          plot_dwgfilepath
                           (IF (OR (WCMATCH (CADR dwg_split_fp) "* *")
                                   (WCMATCH (CADDR dwg_split_fp) "* *")
                               ) ;_ end of OR
                             (STRCAT "\""
                                     plt_drv
                                     (CADR dwg_split_fp)
                                     "Plots\\"
                                     (IF frst_dir
                                       frst_dir
                                       "A\\"
                                     ) ;_ end of IF
                                     (CADDR dwg_split_fp)
                                     "-"
                                     plot_layout
                                     "\"" ;".plt\""
                             ) ;_ end of strcat
                             (STRCAT plt_drv
                                     (CADR dwg_split_fp)
                                     "Plots\\"
                                     (IF frst_dir
                                       frst_dir
                                       "A\\"
                                     ) ;_ end of IF
                                     (CADDR dwg_split_fp)
                                     "-"
                                     plot_layout
                                     "" ;".plt"
                             ) ;_ end of strcat
                           ) ;_ end of IF
          plot_dwgfilepath_nolayout
                           (STRCAT plt_drv
                                   (CADR dwg_split_fp)
                                   "Plots\\"
                                   (IF frst_dir
                                     frst_dir
                                     "A\\"
                                   ) ;_ end of IF
                                   (CADDR dwg_split_fp)
                           ) ;_ end of strcat
    ) ;_ end of SETQ
    (IF debug_doslib
      (PRINC "\nDOS_29 ")
    ) ;_ end of IF
    (IF prefil
      (PROGN
        (SETQ preline_lst nil)
        (SETQ opnpre_fil (OPEN prefil "r"))
        (WHILE (SETQ this_line (READ-LINE opnpre_fil))
          (SETQ preline_lst (APPEND preline_lst (LIST this_line)))
        ) ;_ end of WHILE
        (CLOSE opnpre_fil)
        (FOREACH n preline_lst (EVAL (READ n)))
      ) ;_ end of PROGN
    ) ;_ end of IF
    (IF (NOT jstscr)
      (PROGN
        (DOS_DELETE plot_dwgfilepath)
        (IF (= include_plbl "1")
          (PROGN
            (IF c:plbl
              nil
              (LOAD "plbl" "\nFile PLBL.LSP not loaded! ")
            ) ;_ end of if
            (IF c:plbl
              (c:plbl)
            ) ;_ end of if
          ) ;_ end of PROGN
        ) ;_ end of IF
        (IF (WCMATCH (STRCASE plot_device) "*JPG*,*PNG*,*TIF*")
          (PROGN
            (IF imgext
              nil
              (COND
                ((WCMATCH (STRCASE plot_device) "*JPG*")
                 (SETQ imgext "jpg")
                )
                ((WCMATCH (STRCASE plot_device) "*PNG*")
                 (SETQ imgext "png")
                )
                ((WCMATCH (STRCASE plot_device) "*TIF*")
                 (SETQ imgext "tif")
                )
                (T (SETQ imgext "tif"))
              ) ;_ end of COND
            ) ;_ end of IF
;;;            (put_dpibat lognm pltdir ;lognm bplotscriptdir name dpiresstr ishalf
;;;              (STRCAT (SUBSTR plot_dwgfilepath
;;;                              2
;;;                              (- (STRLEN plot_dwgfilepath) 2)
;;;                      ) ;_ end of SUBSTR
;;;                      "."
;;;                      imgext
;;;              ) ;_ end of STRCAT
;;;              dpiresstr
;;;              (IF (EQ halfdpi "1") T)
;;;            ) ;_ end of put_dpibat
          ) ;_ end of PROGN
        ) ;_ end of IF
        (COMMAND ".-PLOT"
                 "Yes"
                 plot_layout            ;layout name
        ) ;_ end of COMMAND
        (COND
          ((WCMATCH (STRCASE plot_device) "*ADOBE PDF*")
           (COMMAND
             plot_device                ;device
             plot_paper_size            ;paper size
             plot_units                 ;units
             plot_orientation           ;orientation
             plot_upside_down           ;upside down?
            ) ;_ end of COMMAND
 ;_ end of COMMAND
 ;_ end of COMMAND
          )
          (T
           (COMMAND
             plot_device                ;device
             plot_paper_size            ;paper size
             plot_orientation           ;orientation
             plot_upside_down           ;upside down?
           ) ;_ end of COMMAND
          )
        ) ;_ end of COND
        (COND                           ;plot area [Display/Extents/Limits/View/Window]
          ((EQ plot_area "Display") (COMMAND "Display"))
          ((EQ plot_area "Extents") (COMMAND "Extents"))
          (
;;;           (AND
           (EQ plot_area "Limits")
;;;                (NOT (EQ bppaperwidth "10686.00"))
;;;                (NOT (EQ bppaperwidth "9792.00"))
;;;           ) ;_ end of AND
           (COMMAND "Window"
                    (GETVAR "limmin")   ;(solves random plot limits bug)
                    (GETVAR "limmax")
           ) ;_ end of COMMAND
          )
          ((EQ plot_area "View") (COMMAND "View" plot_view_name))
          ((OR (EQ plot_area "Window") (EQ bppaperwidth "10500.00"))
           (COMMAND "Window"
                    (IF (EQ (TYPE (READ plot_window_llcor)) 'LIST)
                      (EVAL (READ plot_window_llcor))
                      plot_window_llcor
                    ) ;_ end of IF
                    (IF (EQ (TYPE (READ plot_window_urcor)) 'LIST)
                      (EVAL (READ plot_window_urcor))
                      plot_window_urcor
                    ) ;_ end of IF
           ) ;_ end of COMMAND
          )
        ) ;_ end of COND
        (COMMAND plot_scale             ;plot scale
                 plot_offset            ;plot offset
                 plot_with_style        ;plot w/ plot styles?
                 plot_table_file        ;style table file
                 plot_with_lineweights  ;plot w/ plot lineweights?
                 plot_scale_lineweights ;scale lineweights with plot scale?
                 plot_paper_first       ;plot paper space first?
                 plot_hide_paper        ;hide paper space objects?
                 plot_dwgfilepath       ;plot filename and path
                 plot_save_setup        ;save to page setup?
                 plot_proceed           ;proceed with plot?
                ) ;_ end of COMMAND
 ;_ end of COMMAND
 ;_ end of COMMAND
        (if dlog (dlog))
        (autodpifix
          plot_dwgfilepath_nolayout
          (IF dpiresstr
            dpiresstr
            "288"
          )
          (IF (EQ halfdpi "1")
            " T"
            " NIL"
          ) ;_ end of IF
          (IF nolayout
            " T"
            " NIL"
          ) ;_ end of IF
        )
        (if
          (setq ent (ssget "X" (LIST(CONS 410 (GETVAR "CTAB"))(CONS 2 "pltstamp"))))
          (entdel(ssname ent 0))
        )
        (IF
          (SETQ ent
                 (SSGET
                   "X"
                   (LIST (CONS 410 (GETVAR "CTAB")) (CONS 2 "pltstamp"))
                 ) ;_ end of ssget
          ) ;_ end of setq
           (ENTDEL (SSNAME ent 0))
        ) ;_ end of if
      ) ;_ end of PROGN
    ) ;_ end of IF
    (IF pstfil
      (PROGN
        (SETQ pstline_lst nil)
        (SETQ opnpst_fil (OPEN pstfil "r"))
        (WHILE (SETQ this_line (READ-LINE opnpst_fil))
          (SETQ pstline_lst (APPEND pstline_lst (LIST this_line)))
        ) ;_ end of WHILE
        (CLOSE opnpst_fil)
        (FOREACH n pstline_lst (EVAL (READ n)))
      ) ;_ end of PROGN
    ) ;_ end of IF
    (SETQ layout_count (1+ layout_count))
  ) ;_ end of WHILE
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN put_dpibat (lognm bplotscriptdir name dpiresstr dohalfs /)
  (IF have_irfanview NIL (LOAD "have_irfanview" "\nFile HAVE_IRFANVIEW.LSP not loaded! "))
  (IF check_for_doslib NIL (LOAD "check_for_doslib" "\nFile CHECK_FOR_DOSLIB.LSP not loaded! "))
  (check_for_doslib)
  (IF (AND bat_fname (FINDFILE bat_fname))
    NIL
    (IF (> (STRLEN (STRCAT bplotscriptdir (IF (WCMATCH bplotscriptdir "*\\") "" "\\") lognm "ImageDPI.BAT")) 126)
      (SETQ
        bat_fname (STRCAT (DOS_SHORTPATH bplotscriptdir) (IF (WCMATCH bplotscriptdir "*\\") "" "\\") lognm "ImageDPI.BAT")
      ) ;_ end of SETQ
      (SETQ bat_fname (STRCAT bplotscriptdir (IF (WCMATCH bplotscriptdir "*\\") "" "\\") lognm "ImageDPI.BAT"))
    ) ;_ end of IF
  )
  (IF (AND bat_fname (have_irfanview))  ;Irfanview is a free, full featured image editing/conversion application downloadable from the internet
    (PROGN
      (SETQ bf1 (OPEN bat_fname "a"))
      (IF bf1
        (PROGN
          (IF DOS_PATHEXTENSION
            (SETQ this_plot_file (STRCAT (DOS_PATHEXTENSION name)(IF(EQ allayplt "1") "" (STRCAT "-" (GETVAR "ctab"))) ".tif"))
            (SETQ this_plot_file (STRCAT (pathextension name)(IF(EQ allayplt "1") "" (STRCAT "-" (GETVAR "ctab"))) ".tif"))
          )
        (WRITE-LINE
          (STRCAT
            "\""
            found_iv
            "\" \""
            this_plot_file
            "\" /dpi="
            (IF do_setdpi
              (STRCAT "(" dpiresstr "," dpiresstr ")")
              (IF dohalfs
                (STRCAT "("
                        (ITOA (* (ATOI dpiresstr) 2))
                        ","
                        (ITOA (* (ATOI dpiresstr) 2))
                        ")"
                ) ;_ end of STRCAT
                (STRCAT "(" dpiresstr "," dpiresstr ")")
              ) ;_ end of IF
            ) ;_ end of IF
            " /convert=\""
            this_plot_file
            "\""
          ) ;_ end of STRCAT
          bf1
        ) ;_ end of WRITE-LINE
          )
      ) ;_ end of IF
      (CLOSE bf1)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (PRINC)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN c:setdpi (/ do_setdpi)
  (SETQ old_dontfixdpi dontfixdpi)
  (SETQ dontfixdpi "0")
  (IF check_for_doslib
    nil
    (LOAD "check_for_doslib"
          "\nFile CHECK_FOR_DOSLIB.LSP not loaded! "
    ) ;_ end of LOAD
  ) ;_ end of IF
  (IF check_for_doslib
    (check_for_doslib)
  ) ;_ end of IF
  (SETQ old_bp2kerror *error*)
  (SETQ *error* bplot2k_error)
  (SETQ do_setdpi T)
  (SETQ princprfx (IF debug_princs
                    "[DEBUG]  "
                    ""
                  ) ;_ end of IF
  ) ;_ end of SETQ
  (IF prvplst
    (SETQ img_prvplst prvplst)
  ) ;_ end of IF
  (IF pltlst
    (SETQ img_pltlst pltlst)
  ) ;_ end of IF
  (IF pltndx
    (SETQ img_pltndx pltndx)
  ) ;_ end of IF
  (IF prvdpindx
    (SETQ pltndx prvdpindx)
  ) ;_ end of IF
  (IF princdebugstrs
    nil
    (LOAD "princdebugstrs"
          "\nFile PRINCDEBUGSTRS.LSP not loaded! "
    ) ;_ end of LOAD
  ) ;_ end of IF
  (IF princdebugstrs
    (princdebugstrs
      (LIST "Begin execution of SETDPI function.\n")
    ) ;_ end of princdebugstrs
  ) ;_ end of IF
  (SETQ
    dirini T
    caldir nil
    selndi nil
  ) ;_ end of setq
  (SETQ old_bp2kecho (GETVAR "CMDECHO"))
  (SETVAR "CMDECHO" 0)
  (SETQ old_bp2kexpert (GETVAR "expert"))
  (COND
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 12)
     (SETQ abort_bplot2k T)
;;;     (XLOAD "doslib12")
    )
                                        ;if AutoCAD Release 13, 
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 13)
     (SETQ abort_bplot2k T)
;;;     (XLOAD "doslib13" nil)
    )
                                        ;if AutoCAD Release 14, 
    ((= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 14)
     (SETQ abort_bplot2k T)
;;;     (ARXLOAD "doslib14")
    )
                                        ;if AutoCAD Release 2000, 
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 15)
          (NOT DOS_VER)
     ) ;_ end of and
     (ARXLOAD "doslib15")
    )
    ((AND (= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 16)
          (NOT DOS_VER)
     ) ;_ end of and
     (ARXLOAD "doslib16")
    )
    ((AND (>= (ATOI (SUBSTR (GETVAR "acadver") 1 2)) 17)
          (NOT DOS_VER)
     ) ;_ end of and
     (IF (WCMATCH (STRCASE (GETVAR "platform")) "*(X64)*")
       (ARXLOAD (STRCAT "doslib" (SUBSTR (GETVAR "acadver") 1 2) "x64"))
       (ARXLOAD "doslib" (SUBSTR (GETVAR "acadver") 1 2))
     ) ;_ end of IF
    )
  ) ;_ end of cond
  (IF abort_bplot2k
    nil
    (PROGN
      (IF ins_fname
        nil
        (SETQ ins_fname "0")
      ) ;_ end of IF
      (SETQ orgdrv (SUBSTR (GETVAR "dwgprefix") 1 2))
      (IF debug_doslib
        (PRINC "\nDOS_1 ")
      ) ;_ end of IF
      (DOS_DRIVE orgdrv)
      (IF debug_doslib
        (PRINC "\nDOS_1 ")
      ) ;_ end of IF
      (SETQ orgdir (GETVAR "dwgprefix"))
      (IF debug_doslib
        (PRINC "\nDOS_2 ")
      ) ;_ end of IF
      (DOS_CHDIR (SUBSTR orgdir 4))
      (IF debug_doslib
        (PRINC "\nDOS_2 ")
      ) ;_ end of IF
      (COND
        ((SETQ plotdirndx
                (MEMBER T
                        (SETQ stdplotdir
                               (MAPCAR
                                 '(LAMBDA (x)
                                    (WCMATCH (STRCASE x)
                                             "*\\PLOTS\\34X22\\*"
                                    ) ;_ end of WCMATCH
                                  ) ;_ end of LAMBDA
                                 (DOS_DIRTREE orgdir)
                               ) ;_ end of MAPCAR
                        ) ;_ end of SETQ
                ) ;_ end of MEMBER
         ) ;_ end of SETQ
         (SETQ
           imagedir (NTH (- (LENGTH stdplotdir) (LENGTH plotdirndx))
                         (DOS_DIRTREE orgdir)
                    ) ;_ end of NTH
         ) ;_ end of SETQ
        )
        ((SETQ plotdirndx
                (MEMBER T
                        (SETQ stdplotdir
                               (MAPCAR
                                 '(LAMBDA (x)
                                    (WCMATCH (STRCASE x)
                                             "*\\PLOTS\\##x##*"
                                    ) ;_ end of WCMATCH
                                  ) ;_ end of LAMBDA
                                 (DOS_DIRTREE orgdir)
                               ) ;_ end of MAPCAR
                        ) ;_ end of SETQ
                ) ;_ end of MEMBER
         ) ;_ end of SETQ
         (SETQ
           imagedir (NTH (- (LENGTH stdplotdir) (LENGTH plotdirndx))
                         (DOS_DIRTREE orgdir)
                    ) ;_ end of NTH
         ) ;_ end of SETQ
        )
        (T (SETQ imagedir orgdir))
      ) ;_ end of COND
      (SETQ dirstr (STRCAT "Selection path: " imagedir)
            olddir dirstr
      ) ;_ end of setq
      (IF debug_doslib
        (PRINC "\nDOS_3 ")
      ) ;_ end of IF
      (SETQ jpg_flst (DOS_DIR (STRCAT imagedir "*.jpg")))
      (SETQ png_flst (DOS_DIR (STRCAT imagedir "*.png")))
      (SETQ tif_flst (DOS_DIR (STRCAT imagedir "*.tif")))
      (SETQ d_flst (APPEND jpg_flst png_flst tif_flst))
      (SETQ ddirs (DOS_SUBDIR imagedir))
      (IF debug_doslib
        (PRINC "\nDOS_3 ")
      ) ;_ end of IF
      (IF (EQ (SUBSTR dirstr (1- (STRLEN dirstr))) ":\\")
        (IF ddirs
          nil
          (SETQ ddirs (LIST ""))
        ) ;_ end of if
        (IF ddirs
          (IF (MEMBER ".." ddirs)
            nil
            (SETQ ddirs (APPEND (LIST "..") ddirs))
          ) ;_ end of if
          (SETQ ddirs (LIST ".."))
        ) ;_ end of if
      ) ;_ end of if
      (IF debug_doslib
        (PRINC "\nDOS_4 ")
      ) ;_ end of IF
      (SETQ ddrvs (DOS_DRIVES))
      (IF debug_doslib
        (PRINC "\nDOS_4 ")
      ) ;_ end of IF
      (IF (MEMBER "A:" ddrvs)
        (SETQ ddrvs (CDR (MEMBER "A:" ddrvs)))
      ) ;_ end of if
      (IF (MEMBER "B:" ddrvs)
        (SETQ ddrvs (CDR (MEMBER "B:" ddrvs)))
      ) ;_ end of if
      (SETQ num (LOAD_DIALOG "bplot2k"))
      (NEW_DIALOG "setdpi" num)
      (SET_TILE "dirtxt" dirstr)
      (drvlst)
      (START_LIST "file_drv")
      (MAPCAR 'ADD_LIST avdrvs)
      (END_LIST)
      (setfdrv)
      (sortfiles)
      (dpimodes)
      (IF fulldpi
        nil
        (SETQ fulldpi "0")
      ) ;_ end of IF
      (SET_TILE "fulldpi" fulldpi)
      (IF halfdpi
        nil
        (SETQ halfdpi "1")
      ) ;_ end of IF
      (SET_TILE "halfdpi" halfdpi)
      (IF (EQ fulldpi "1")
        (SETQ dpiresstr "288")
      ) ;_ end of IF
      (IF (EQ halfdpi "1")
        (SETQ dpiresstr "576")
      ) ;_ end of IF
      (SET_TILE "selnum" "0 images selected for setting dpi:")
      (MODE_TILE "file_drv" 0)
      (MODE_TILE "ins_fname" 1)
      (SETQ curdwg (GETVAR "dwgname"))
      (SETQ curpfx (GETVAR "dwgprefix"))
      (IF debug_doslib
        (PRINC "\nDOS_5 ")
      ) ;_ end of IF
      (SETQ spltpat (DOS_SPLITPATH curdwg))
      (IF debug_doslib
        (PRINC "\nDOS_5 ")
      ) ;_ end of IF
      (IF dos_win
        (IF (EQ (dos_win) "WINNT")
          (SETQ nt_true T)
          (SETQ nt_true nil)
        ) ;_ end of if
        (IF DOS_VER
          (IF (EQ (DOS_VER) "Windows NT Workstation 4.0")
            (SETQ nt_true T)
            (SETQ nt_true nil)
          ) ;_ end of if
          (SETQ nt_true nil)
        ) ;_ end of if
      ) ;_ end of if
      (MODE_TILE "fedit" 2)
      (ACTION_TILE "dirs" "(setq caldir $reason)(dirlst)")
      (ACTION_TILE
        "fedit"
        "(setq pltndx NIL)(if(eq $reason 2)nil(progn(bplot2k_key_search nil)(chkdpi)))"
                                        ;Was (bplot2k_key_search out_filn)
      ) ;_ end of action_tile
      (ACTION_TILE
        "files"
        "(setq pltndx (get_tile \"files\"))(chkfil pltlst)(chkdpi)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "halfdpi"
        "(SETQ dpiresstr \"576\" setotherdpi \"0\" fulldpi (GET_TILE\"fulldpi\"))(dpimodes)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "fulldpi"
        "(SETQ dpiresstr \"288\" setotherdpi \"0\" halfdpi (GET_TILE\"halfdpi\"))(dpimodes)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "setotherdpi"
        "(SETQ setotherdpi (GET_TILE\"setotherdpi\")  halfdpi \"0\" fulldpi \"0\")(dpimodes)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "anydpi"
        "(SETQ anydpi (GET_TILE\"anydpi\") setotherdpi \"1\")(dpimodes)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "selall"
        "(set_tile\"fedit\"\"*\")(bplot2k_key_search out_filn)(chkdpi)"
      ) ;_ end of action_tile
      (ACTION_TILE
        "clear"
        "(setq dpilst nil)(setq selndi \"\")(setremdpi)(set_tile\"selall\"\"\")(set_tile\"error\"\"\")"
                                        ;did include (set_tile\"fedit\"\"\")
      ) ;_ end of action_tile
      (ACTION_TILE
        "file_drv"
        "(SETQ fildrv(NTH(READ(GET_TILE\"file_drv\"))avdrvs))(setfdrv)"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE "remove" "(setremdpi)")
      (ACTION_TILE "reverse" "(revsel)")
      (ACTION_TILE
        "filsel"
        "(setq selndi (get_tile \"filsel\"))(setone)"
      ) ;_ end of action_tile
      (ACTION_TILE "savelst" "(savepltlst)")
      (ACTION_TILE "restorelst" "(restorepltlst)")
      (ACTION_TILE "indexlst" "(indexpltlst)")
      (ACTION_TILE
        "ins_fname"
        "(SETQ ins_fname (GET_TILE \"ins_fname\"))"
      ) ;_ end of ACTION_TILE
      (ACTION_TILE
        "accept"
        "(setq prvdpilst dpilst pltndx(get_tile\"files\"))(dclst dpilst)(setq dpi_loc (done_dialog 1))"
      ) ;_ end of action_tile
      (ACTION_TILE
        "cancel"
        "(setq prvdpilst dpilst pltlst nil filst nil)(rstdir)(setq dpi_loc (done_dialog 0))"
      ) ;_ end of action_tile
      (ACTION_TILE
        "help"
        "(browser_help \"Bplot2K\")"
      ) ;_ end of action_tile
      (dirlst)
      (chkdpi)
      (IF prvdpilst
        (PROGN
          (SET_TILE "selnum"
                    (STRCAT (ITOA (LENGTH prvdpilst))
                            " images selected for setting dpi:"
                    ) ;_ end of strcat
          ) ;_ end of set_tile
          (SETQ dpilst prvdpilst)
          (START_LIST "filsel")
          (MAPCAR 'ADD_LIST dpilst)
          (END_LIST)
        ) ;_ end of PROGN
      ) ;_ end of IF
      (SETQ done_dpi (START_DIALOG))
      (SETQ errtxt nil)
      (IF (AND (EQ done_dpi 1)
               dpilst
               dpiresstr
               (EQ (TYPE (READ dpiresstr)) 'int)
          ) ;_ end of AND
        (PROGN
          (IF autodpifix NIL (LOAD "autodpifix" "\nFile AUTODPIFIX.LSP not loaded! "))
          (FOREACH n dpilst
            (PRINC (STRCAT "Set DPI=" (IF (EQ halfdpi "1")(ITOA(* 2 (IF dpiresstr (ATOI dpiresstr) 288)))(ITOA(IF dpiresstr (ATOI dpiresstr) 288))) " for " n))
            (PRINC "\n")
            (PRINC)
            (autodpifix n dpiresstr (IF (EQ halfdpi "1") T NIL) T)
          )
        ) ;_ end of PROGN
        (PROGN
          (IF (EQ done_dpi 0)
            (PROGN
              (PRINC "\nSetDPI dialog cancelled. ")
              (SETQ pltndx nil)
            ) ;_ end of progn
            (PRINC "\nNo files selected for dpi setting. ")
          ) ;_ end of if
          (rstdir)
        ) ;_ end of progn
      ) ;_ end of if
      (UNLOAD_DIALOG num)
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF old_bp2kecho
    (SETVAR "CMDECHO" old_bp2kecho)
  ) ;_ end of IF
  (IF old_bp2kexpert
    (SETVAR "expert" old_bp2kexpert)
  ) ;_ end of IF
  (IF princdebugstrs
    (princdebugstrs
      (LIST "End execution of SETDPI function.\n")
    ) ;_ end of princdebugstrs
  ) ;_ end of IF
  (SETQ princprfx
         (COND
           ((AND princprfx (WCMATCH princprfx "`[DEBUG`]   *"))
            (SUBSTR princprfx 1 (- (STRLEN princprfx) 2))
           )
           (debug_princs "[DEBUG]  ")
           (T "")
         ) ;_ end of COND
  ) ;_ end of SETQ
  (IF img_prvplst
    (SETQ prvplst img_prvplst)
  ) ;_ end of IF
  (IF img_pltlst
    (SETQ pltlst img_pltlst)
  ) ;_ end of IF
  (IF img_pltndx
    (SETQ pltndx img_pltndx)
  ) ;_ end of IF
  (SETQ dontfixdpi old_dontfixdpi)
  (PRINC)
  (SETQ *error* old_bp2kerror)
  (PRINC)
) ;_ end of defun
;;;****************************************************************************
(DEFUN dpimodes ()
  (IF
    (EQ setotherdpi "1")
     (PROGN
       (SET_TILE "halfdpi" "0")
       (SET_TILE "fulldpi" "0")
       (MODE_TILE "halfdpi" 1)
       (MODE_TILE "fulldpi" 1)
       (SETQ halfdpi "0")
       (SETQ fulldpi "0")
       (IF (NOT
             (EQ (TYPE (READ (SETQ thisdpi (GET_TILE "anydpi")))) 'int)
           ) ;_ end of NOT
         (PROGN
           (SET_TILE "error" "Enter an integer value for DPI")
           (SET_TILE "anydpi" "")
         ) ;_ end of PROGN
         (SETQ dpiresstr thisdpi)
       ) ;_ end of IF
     ) ;_ end of PROGN
     (PROGN
       (MODE_TILE "halfdpi" 0)
       (MODE_TILE "fulldpi" 0)
     ) ;_ end of PROGN
  ) ;_ end of IF
  (IF (EQ halfdpi "1")
    (PROGN
      (SET_TILE "setotherdpi" "0")
;;;      (SET_TILE "halfdpi" "1")
      (SETQ setotherdpi
             "0"
            fulldpi "0"
      ) ;_ end of SETQ
      (SETQ dpiresstr "576")
    ) ;_ end of PROGN
  ) ;_ end of IF
  (IF
    (EQ fulldpi "1")
     (PROGN
       (SET_TILE "setotherdpi" "0")
;;;      (SET_TILE "fulldpi" "1")
       (SETQ setotherdpi
              "0"
             halfdpi "0"
       ) ;_ end of SETQ
       (SETQ dpiresstr "288")
     ) ;_ end of PROGN
  ) ;_ end of IF
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN chkdpi ()
  (SETQ imagedir (SUBSTR dirstr 17))
;;;  (chkfil dpilst)
  (SETQ dpilst pltlst)
;;;  (setq pltlst dpilst)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN setremdpi ()
  (setrem dpilst)
  (SETQ dpilst pltlst)
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN fixdpimode ()
  (COND
    ((EQ dontfixdpi "1")
     (PROGN
       (MODE_TILE "fixdpi" 0)
     ) ;_ end of PROGN
     (PROGN
       (MODE_TILE "fixdpi" 1)
     ) ;_ end of PROGN
    )
    ((EQ dontfixdpi "0")
     (PROGN
       (MODE_TILE "fixdpi" 1)
     ) ;_ end of PROGN
     (PROGN
       (MODE_TILE "fixdpi" 0)
     ) ;_ end of PROGN
    )
    ((AND page1 (WCMATCH (STRCASE page1) "*TIF*,*JPG*,*PNG*"))
     (MODE_TILE "dontfixdpi" 0)
    )
    (T
     (MODE_TILE "dontfixdpi" 0)
     (MODE_TILE "fixdpi" 0)
     (SET_TILE "dontfixdpi" "0")
;;;    (SET_TILE "fixdpi" "0")
    )
  ) ;_ end of COND
) ;_ end of DEFUN
;;;****************************************************************************
(DEFUN pathextension (filename / )
  (WHILE (AND (WCMATCH filename "*`.*")(NOT (WCMATCH filename "*`.")))
    (SETQ filename (SUBSTR filename 1 (1- (STRLEN filename))))
  )
  (IF (WCMATCH filename "*`.")
    (SETQ filename (SUBSTR filename 1 (1- (STRLEN filename))))
    (SETQ filename filename)
  )
)
;;;****************************************************************************
(DEFUN fourslash (fsfname /);converts path strings to "four backslash" format for writing to external files as "double backslash" path strings
  (COND
;;;    ((NOT fsfname) (SETQ dwg_str ""));this line added because some "script plot all layouts" in 2004 were generating an error
;;;    ;on a (fourslash fsfname) function call because fsfname was nil.  The addition eliminated the error but likely needs to be
;;;    ;fixed so that the function call will return a qualified path.
    ((WCMATCH fsfname "*\\\\*")
      (SETQ dwg_tokens (DOS_STRTOKENS fsfname "\\\\"))
      (SETQ dwg_str (STRCAT (CAR dwg_tokens) (EVAL (CONS 'STRCAT (MAPCAR '(LAMBDA (x) (STRCAT "\\\\" x)) (CDR dwg_tokens)))))))
    ((WCMATCH fsfname "*\\*")
      (SETQ dwg_tokens (DOS_STRTOKENS fsfname "\\"))
      (SETQ dwg_str (STRCAT (CAR dwg_tokens) (EVAL (CONS 'STRCAT (MAPCAR '(LAMBDA (x) (STRCAT "\\\\" x)) (CDR dwg_tokens)))))))
    ((WCMATCH fsfname "*/*")
      (SETQ dwg_tokens (DOS_STRTOKENS fsfname "/"))
      (SETQ dwg_str (STRCAT (CAR dwg_tokens) (EVAL (CONS 'STRCAT (MAPCAR '(LAMBDA (x) (STRCAT "\\\\" x)) (CDR dwg_tokens)))))))
  )
)
;;;****************************************************************************
(DEFUN fore2back (fn /);converts path strings from "forward slash" format to "double backslash" format
  (IF (WCMATCH fn "*/*")
    (PROGN
      (SETQ dwg_tokens (DOS_STRTOKENS fn "/"))
      (SETQ dwg_str (STRCAT (CAR dwg_tokens) (EVAL (CONS 'STRCAT (MAPCAR '(LAMBDA (x) (STRCAT "\\" x)) (CDR dwg_tokens))))))
    )
  ) ;_ end of IF
) ;_ end of DEFUN
;;;****************************************************************************
(PRINC)

 ;|Visual LISP Format Options (72 2 40 2 T "end of " 60 9 2 1 0 nil T nil T)
 ***Don't add text below the comment!***|;
